@@ -67,7 +67,7 @@ Account::Account()
    savePassword_(false),
    shakeNudge_(true),
    showAllowedContacts_(false),
-   showChatUserPicture_(false),
+   showChatUserPicture_(true),
    showContactEmail_(false),
    showContactListBird_(true),
    showEmail_(true),
@@ -120,7 +120,7 @@ Account::~Account()
     delete msnObject_;
 
 #ifdef KMESSDEBUG_ACCOUNT_GENERAL
-  kDebug() << "DESTROYED. [handle=" << handle_ << "]";
+  kmDebug() << "DESTROYED. [handle=" << handle_ << "]";
 #endif
 }
 
@@ -130,7 +130,7 @@ Account::~Account()
 void Account::copyAccount( const Account *account )
 {
 #ifdef KMESSDEBUG_ACCOUNT_GENERAL
-  kDebug() << "Copying account data...";
+  kmDebug() << "Copying account data...";
 #endif
 
   // This method is used to clone the settings of an Account to the CurrentAccount,
@@ -788,7 +788,7 @@ void Account::readProperties( const QString &handle )
   savePassword_                  = profileGroup.readEntry( "savePassword",                 false       );
   shakeNudge_                    = profileGroup.readEntry( "shakeNudge",                   true        );
   showAllowedContacts_           = profileGroup.readEntry( "showAllowed",                  false       );
-  showChatUserPicture_           = profileGroup.readEntry( "showChatUserPicture",          false       );
+  showChatUserPicture_           = profileGroup.readEntry( "showChatUserPicture",          true        );
   showContactEmail_              = profileGroup.readEntry( "showContactEmail",             false       );
   showContactListBird_           = profileGroup.readEntry( "showContactListBird",          true        );
   showEmail_                     = profileGroup.readEntry( "showEmail",                    true        );
@@ -821,7 +821,7 @@ void Account::readProperties( const QString &handle )
   dirty_        = false;
 
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-  kDebug() << "Resetting 'dirty' to false.";
+  kmDebug() << "Resetting 'dirty' to false.";
 #endif
 
   // If a chat style is removed, fall back to the default.
@@ -831,7 +831,7 @@ void Account::readProperties( const QString &handle )
   if( KGlobal::dirs()->findResource( "data", "kmess/styles/" + chatStyle_ + '/' + chatStyle_ + ".xsl" ).isEmpty() )
   {
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-    kDebug() << "Auto-corrected chat & setting, setting 'dirty' to true.";
+    kmDebug() << "Auto-corrected chat & setting, setting 'dirty' to true.";
 #endif
 
     // Fall back to our new default.
@@ -849,12 +849,12 @@ void Account::saveProperties()
   // Protect against unwanted usage
   if( guestAccount_ )
   {
-    kWarning() << "Application attempted to save a guest account!";
+    kmWarning() << "Application attempted to save a guest account!";
     return;
   }
   if( deleted_ )
   {
-    kWarning() << "Application attempted to save the deleted account again!";
+    kmWarning() << "Application attempted to save the deleted account again!";
     return;
   }
 
@@ -864,7 +864,7 @@ void Account::saveProperties()
   if ( dirty_ )
   {
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-    kDebug() << "Account " << handle_ << " is 'dirty', save properties.";
+    kmDebug() << "Account " << handle_ << " is 'dirty', save properties.";
 #endif
 
     // Write new settings
@@ -941,7 +941,7 @@ void Account::saveProperties()
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
   else
   {
-    kDebug() << "Account " << handle_ << " is NOT 'dirty', don't save properties.";
+    kmDebug() << "Account " << handle_ << " is NOT 'dirty', don't save properties.";
   }
 #endif
 
@@ -988,7 +988,7 @@ void Account::setContactListOptions( bool showNowListening, bool showContactEmai
   if( showNowListening_ != showNowListening )
   {
 #ifdef KMESSDEBUG_ACCOUNT_GENERAL
-    kDebug() << "Now listening settings changed, notifying listeners.";
+    kmDebug() << "Now listening settings changed, notifying listeners.";
 #endif
 
     showNowListening_ = showNowListening;
@@ -997,7 +997,7 @@ void Account::setContactListOptions( bool showNowListening, bool showContactEmai
 
   dirty_ = true;
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-    kDebug() << "Setting 'dirty' to true.";
+    kmDebug() << "Setting 'dirty' to true.";
 #endif
 }
 
@@ -1011,7 +1011,7 @@ void Account::setAutoreplyMessage( const QString& autoreplyMessage)
     autoreplyMessage_ = autoreplyMessage;
     dirty_ = true;
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-    kDebug() << "Setting 'dirty' to true.";
+    kmDebug() << "Setting 'dirty' to true.";
 #endif
   }
 }
@@ -1079,7 +1079,7 @@ void Account::setAutoreplyMessage( const QString& autoreplyMessage)
   dirty_ = true;
 
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-    kDebug() << "Setting 'dirty' to true.";
+    kmDebug() << "Setting 'dirty' to true.";
 #endif
 }
 
@@ -1107,7 +1107,7 @@ void Account::setChatLoggingInformation( bool saveChats, bool saveChatsToFile, A
   dirty_ = true;
 
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-  kDebug() << "Setting 'dirty' to true.";
+  kmDebug() << "Setting 'dirty' to true.";
 #endif
 }
 
@@ -1123,7 +1123,7 @@ void Account::setContactListDisplayMode( ContactListDisplayMode displayMode )
     emit changedViewMode();
     dirty_ = true;
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-    kDebug() << "Setting 'dirty' to true.";
+    kmDebug() << "Setting 'dirty' to true.";
 #endif
   }
 }
@@ -1142,7 +1142,7 @@ void Account::setEmailInformation( bool showEmail, bool showOtherFolders )
     emit changedEmailDisplaySettings();
     dirty_ = true;
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-    kDebug() << "Setting 'dirty' to true.";
+    kmDebug() << "Setting 'dirty' to true.";
 #endif
   }
 }
@@ -1171,7 +1171,7 @@ void Account::setFont( const QFont& font )
     emit changedFontSettings();
     dirty_ = true;
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-    kDebug() << "Setting 'dirty' to true.";
+    kmDebug() << "Setting 'dirty' to true.";
 #endif
   }
 }
@@ -1187,7 +1187,7 @@ void Account::setFontColor( const QString& fontColor )
     emit changedFontSettings();
     dirty_ = true;
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-    kDebug() << "Setting 'dirty' to true.";
+    kmDebug() << "Setting 'dirty' to true.";
 #endif
   }
 }
@@ -1216,7 +1216,7 @@ void Account::setFontInformation( const QFont& font, const QString &fontColor, c
   dirty_ = true;
 
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-    kDebug() << "Setting 'dirty' to true.";
+    kmDebug() << "Setting 'dirty' to true.";
 #endif
 }
 
@@ -1237,7 +1237,7 @@ void Account::setEmoticonStyle( const QString& emoticonStyle )
     // Tell the account settings changed and need to be saved
     dirty_ = true;
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-    kDebug() << "Setting 'dirty' to true.";
+    kmDebug() << "Setting 'dirty' to true.";
 #endif
   }
 }
@@ -1258,7 +1258,7 @@ void Account::setFriendlyName(const QString& newName)
   dirty_ = true;
 
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-  kDebug() << "Setting 'dirty' to true.";
+  kmDebug() << "Setting 'dirty' to true.";
 #endif
 }
 
@@ -1290,7 +1290,7 @@ void Account::setInitialStatus( Status status )
   dirty_ = true;
 
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-  kDebug() << "Setting 'dirty' to true.";
+  kmDebug() << "Setting 'dirty' to true.";
 #endif
 }
 
@@ -1311,7 +1311,7 @@ void Account::setListPictureSize( int mode )
   dirty_ = true;
 
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-  kDebug() << "Setting 'dirty' to true.";
+  kmDebug() << "Setting 'dirty' to true.";
 #endif
 }
 
@@ -1351,7 +1351,7 @@ void Account::setLoginInformation( QString handle, QString friendlyName, QString
   dirty_ = true;
 
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-  kDebug() << "Setting 'dirty' to true.";
+  kmDebug() << "Setting 'dirty' to true.";
 #endif
 }
 
@@ -1379,7 +1379,7 @@ void Account::setPersonalMessage(const QString& newMessage)
   dirty_ = true;
 
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-  kDebug() << "Setting 'dirty' to true.";
+  kmDebug() << "Setting 'dirty' to true.";
 #endif
 }
 
@@ -1401,7 +1401,7 @@ void Account::setPicturePath( const QString& picturePath )
   dirty_ = true;
 
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-  kDebug() << "Setting 'dirty' to true.";
+  kmDebug() << "Setting 'dirty' to true.";
 #endif
 }
 
@@ -1420,7 +1420,7 @@ void Account::setOriginalPicturePath( const QString& picturePath )
   dirty_ = true;
 
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-  kDebug() << "Setting 'dirty' to true.";
+  kmDebug() << "Setting 'dirty' to true.";
 #endif
 }
 
@@ -1448,7 +1448,7 @@ void Account::setSavePassword( bool savePassword )
   dirty_ = true;
 
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-  kDebug() << "Setting 'dirty' to true.";
+  kmDebug() << "Setting 'dirty' to true.";
 #endif
 }
 
@@ -1463,7 +1463,7 @@ void Account::setShowAllowedContacts( bool showAllowedContacts )
     emit changedDisplaySettings();
     dirty_ = true;
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-    kDebug() << "Setting 'dirty' to true.";
+    kmDebug() << "Setting 'dirty' to true.";
 #endif
   }
 }
@@ -1483,7 +1483,7 @@ void Account::setShowChatUserPicture( bool showChatUserPicture )
 
   dirty_ = true;
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-  kDebug() << "Setting 'dirty' to true.";
+  kmDebug() << "Setting 'dirty' to true.";
 #endif
 
 }
@@ -1503,7 +1503,7 @@ void Account::setShowContactListBird( bool showBird )
 
   dirty_ = true;
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-  kDebug() << "Setting 'dirty' to true.";
+  kmDebug() << "Setting 'dirty' to true.";
 #endif
 
 }
@@ -1523,7 +1523,7 @@ void Account::setShowEmptyGroups( bool showEmptyGroups )
 
   dirty_ = true;
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-  kDebug() << "Setting 'dirty' to true.";
+  kmDebug() << "Setting 'dirty' to true.";
 #endif
 }
 
@@ -1541,7 +1541,7 @@ void Account::setShowHistoryBox( bool showHistoryBox )
   dirty_ = true;
 
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-  kDebug() << "Setting 'dirty' to true.";
+  kmDebug() << "Setting 'dirty' to true.";
 #endif
 }
 
@@ -1554,7 +1554,7 @@ void Account::setShowNowListening( bool showNowListening )
   emit changedNowListeningSettings();
 
 #ifdef KMESSDEBUG_ACCOUNT_GENERAL
-  kDebug() << "Setting 'showNowListening' to " << showNowListening;
+  kmDebug() << "Setting 'showNowListening' to " << showNowListening;
 #endif
 }
 
@@ -1569,7 +1569,7 @@ void Account::setShowOfflineContacts( bool showOfflineContacts )
     emit changedDisplaySettings();
     dirty_ = true;
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-    kDebug() << "Setting 'dirty' to true.";
+    kmDebug() << "Setting 'dirty' to true.";
 #endif
   }
 }
@@ -1585,7 +1585,7 @@ void Account::setShowRemovedContacts( bool showRemovedContacts )
     emit changedDisplaySettings();
     dirty_ = true;
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-    kDebug() << "Setting 'dirty' to true.";
+    kmDebug() << "Setting 'dirty' to true.";
 #endif
   }
 }
@@ -1604,7 +1604,7 @@ void Account::setShowSearchBar( bool showSearchBar )
   dirty_ = true;
 
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-  kDebug() << "Setting 'dirty' to true.";
+  kmDebug() << "Setting 'dirty' to true.";
 #endif
 }
 
@@ -1622,7 +1622,7 @@ void Account::setShowSessionInfo( bool showSessionInfo )
   dirty_ = true;
 
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-  kDebug() << "Setting 'dirty' to true.";
+  kmDebug() << "Setting 'dirty' to true.";
 #endif
 }
 
@@ -1654,7 +1654,7 @@ void Account::setStatusOptions( bool useIdleTimer, int idleTime, bool hideNotifi
 
   dirty_ = true;
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-  kDebug() << "Setting 'dirty' to true.";
+  kmDebug() << "Setting 'dirty' to true.";
 #endif
 }
 
@@ -1684,7 +1684,7 @@ void Account::setUseAutologin( bool useAutologin)
     useAutologin_ = useAutologin;
     dirty_ = true;
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-    kDebug() << "Setting 'dirty' to true.";
+    kmDebug() << "Setting 'dirty' to true.";
 #endif
   }
 }
@@ -1697,7 +1697,7 @@ void Account::setUseEmoticons( bool useEmoticons)
   useEmoticons_ = useEmoticons;
   dirty_ = true;
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-    kDebug() << "Setting 'dirty' to true.";
+    kmDebug() << "Setting 'dirty' to true.";
 #endif
   emit changedChatStyleSettings();
 }
@@ -1726,7 +1726,7 @@ void Account::setShowPicture( bool showPicture )
   updateMsnObject();
 
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
-  kDebug() << "Setting 'dirty' to true.";
+  kmDebug() << "Setting 'dirty' to true.";
 #endif
 }
 
@@ -1752,13 +1752,13 @@ void Account::updateMsnObject()
   if( picturePath != displayPicturePath_ )
   {
 #ifdef KMESSDEBUG_ACCOUNT_MSNOBJECT
-    kDebug() << "Replacing picture" << displayPicturePath_ << "with" << picturePath;
+    kmDebug() << "Replacing picture" << displayPicturePath_ << "with" << picturePath;
 #endif
     displayPicturePath_ = picturePath;
   }
 
 #ifdef KMESSDEBUG_ACCOUNT_MSNOBJECT
-  kDebug() << "Show the picture?" << showPicture_ << "- Set picture path:" << displayPicturePath_;
+  kmDebug() << "Show the picture?" << showPicture_ << "- Set picture path:" << displayPicturePath_;
 #endif
 
   if ( showPicture_ )
@@ -1774,7 +1774,7 @@ void Account::updateMsnObject()
     }
     else
     {
-      kWarning() << "Picture could not be loaded: " << displayPicturePath_;
+      kmWarning() << "Picture could not be loaded: " << displayPicturePath_;
     }
   }
 
@@ -1782,7 +1782,7 @@ void Account::updateMsnObject()
   if( oldMsnString != newMsnString )
   {
 #ifdef KMESSDEBUG_ACCOUNT_MSNOBJECT
-    kDebug() << "result is: '" << newMsnString << "'";
+    kmDebug() << "result is: '" << newMsnString << "'";
 #endif
     emit changedMsnObject();
   }
