@@ -57,8 +57,7 @@ class Account : public QObject
     /// Available chat exporting formats
     enum ChatExportFormat
     {
-      EXPORT_XML    /// Export the chat to XML
-    , EXPORT_HTML   /// Export the chat to HTML
+      EXPORT_HTML   /// Export the chat to HTML
     , EXPORT_TEXT   /// Export the chat to text
     };
     // Contact List view organization constants
