@@ -66,7 +66,7 @@ AccountsManager::~AccountsManager()
   delete passwordManager_;
 
 #ifdef KMESSDEBUG_ACCOUNTSMANAGER
-  kDebug() << "DESTROYED.";
+  kmDebug() << "DESTROYED.";
 #endif
 }
 
@@ -79,7 +79,7 @@ void AccountsManager::addAccount( Account *account )
   accounts_.append( account );
 
 #ifdef KMESSDEBUG_ACCOUNTSMANAGER
-  kDebug() << "New account created:" << account->getHandle() << ".";
+  kmDebug() << "New account created:" << account->getHandle() << ".";
 #endif
 
   emit accountAdded( account );
@@ -98,7 +98,7 @@ void AccountsManager::changeAccount( Account *account, QString oldHandle, QStrin
   if( getAccountByHandle( oldHandle ) == 0 )
   {
 #ifdef KMESSDEBUG_ACCOUNTSMANAGER
-    kDebug() << "Saving settings for new account" << newHandle;
+    kmDebug() << "Saving settings for new account" << newHandle;
 #endif
 
     // Add the account to the account list.
@@ -107,7 +107,7 @@ void AccountsManager::changeAccount( Account *account, QString oldHandle, QStrin
 #ifdef KMESSDEBUG_ACCOUNTSMANAGER
   else
   {
-    kDebug() << "Saving settings for " << oldHandle;
+    kmDebug() << "Saving settings for " << oldHandle;
   }
 #endif
 
@@ -127,7 +127,7 @@ void AccountsManager::changeAccount( Account *account, QString oldHandle, QStrin
   if( oldHandle != newHandle )
   {
 #ifdef KMESSDEBUG_ACCOUNTSMANAGER
-    kDebug() << "Moving account dir from" << oldHandle << "to" << newHandle;
+    kmDebug() << "Moving account dir from" << oldHandle << "to" << newHandle;
 #endif
 
     QString accountsPath( KMessConfig::instance()->getAccountsDirectory() );
@@ -136,12 +136,12 @@ void AccountsManager::changeAccount( Account *account, QString oldHandle, QStrin
 
     if( accountsDir.exists( newHandle ) )
     {
-      kWarning() << "Destination account directory" << newHandle << "already exists!";
+      kmWarning() << "Destination account directory" << newHandle << "already exists!";
     }
 
     if( accountsDir.rename( oldHandle, newHandle ) )
     {
-      kWarning() << "Unable to move account directory" << oldHandle << "to" << newHandle << "!";
+      kmWarning() << "Unable to move account directory" << oldHandle << "to" << newHandle << "!";
     }
   }
 
@@ -160,7 +160,7 @@ bool AccountsManager::contains( Account *account ) const
 {
   if( account == CurrentAccount::instance() )
   {
-    kWarning() << "Called contains() on the current account!";
+    kmWarning() << "Called contains() on the current account!";
     return true;
   }
 
@@ -183,19 +183,19 @@ void AccountsManager::deleteAccount( Account *account )
   &&  CurrentAccount::instance()->getHandle() == handle )
   {
 #ifdef KMESSDEBUG_ACCOUNTSMANAGER
-    kDebug() << "Cannot delete current account:" << handle;
+    kmDebug() << "Cannot delete current account:" << handle;
 #endif
     return;
   }
 
 #ifdef KMESSDEBUG_ACCOUNTSMANAGER
-  kDebug() << "Deleting account for " << handle << ".";
+  kmDebug() << "Deleting account for " << handle << ".";
 #endif
 
   // Remove the account from the list of accounts
   if( accounts_.removeAll( account ) == 0 )
   {
-    kWarning() << "Account" << handle << "not found in collection!";
+    kmWarning() << "Account" << handle << "not found in collection!";
   }
 
   // Delete the account directory
@@ -255,7 +255,7 @@ void AccountsManager::initializePasswordManager( bool block )
   if( passwordManager_ != 0 )
   {
 #ifdef KMESSDEBUG_ACCOUNTSMANAGER_KWALLET
-    kDebug() << "KWallet is already initialized.";
+    kmDebug() << "KWallet is already initialized.";
 #endif
     return;
   }
@@ -321,7 +321,7 @@ void AccountsManager::savePasswords( bool block )
   if( passwordsToWrite )
   {
 #ifdef KMESSDEBUG_ACCOUNTSMANAGER_KWALLET
-    kDebug() << "There were passwords to be updated, scheduling an update.";
+    kmDebug() << "There were passwords to be updated, scheduling an update.";
 #endif
     doPasswordWrite_ = true;
     initializePasswordManager( block );
@@ -329,7 +329,7 @@ void AccountsManager::savePasswords( bool block )
 #ifdef KMESSDEBUG_ACCOUNTSMANAGER_KWALLET
   else
   {
-    kDebug() << "There were no passwords to be updated, skipping save request.";
+    kmDebug() << "There were no passwords to be updated, skipping save request.";
   }
 #endif
 }
@@ -344,7 +344,7 @@ void AccountsManager::slotWalletOpen( bool success )
     ( passwordManager_ != 0 && ! passwordManager_->isOpen() ) )
   {
 #ifdef KMESSDEBUG_ACCOUNTSMANAGER_KWALLET
-    kDebug() << "Wallet opening failed, falling back to plain text passwords.";
+    kmDebug() << "Wallet opening failed, falling back to plain text passwords.";
 #endif
 
     delete passwordManager_;
@@ -366,7 +366,7 @@ void AccountsManager::slotWalletOpen( bool success )
       const QStringList passwordAccountList( passwordGroup.keyList() );
 
 #ifdef KMESSDEBUG_ACCOUNTSMANAGER_KWALLET
-      kDebug() << "Reading passwords from plain-text storage instead of KWallet!";
+      kmDebug() << "Reading passwords from plain-text storage instead of KWallet!";
 #endif
 
       // Read the passwords from the KMess config file
@@ -382,7 +382,7 @@ void AccountsManager::slotWalletOpen( bool success )
         }
 
 #ifdef KMESSDEBUG_ACCOUNTSMANAGER_KWALLET
-        kDebug() << "Password have been read for account: " << accountHandle;
+        kmDebug() << "Password have been read for account: " << accountHandle;
 #endif
 
         QString password = passwordGroup.readEntry( accountHandle, QString() );
@@ -403,7 +403,7 @@ void AccountsManager::slotWalletOpen( bool success )
         }
 
 #ifdef KMESSDEBUG_ACCOUNTSMANAGER_KWALLET
-        kDebug() << "Password have been read for account: " << account->getHandle();
+        kmDebug() << "Password have been read for account: " << account->getHandle();
 #endif
 
         account->setPassword( password );
@@ -419,7 +419,7 @@ void AccountsManager::slotWalletOpen( bool success )
   {
     if( passwordManager_ == 0 )
     {
-      kWarning() << "KWallet is not available: saving passwords in plain text.";
+      kmWarning() << "KWallet is not available: saving passwords in plain text.";
 
       KConfigGroup passwordGroup( KMessConfig::instance()->getGlobalConfig( "Passwords" ) );
 
@@ -435,7 +435,7 @@ void AccountsManager::slotWalletOpen( bool success )
           if( account->getSavePassword() == false || account->getPassword().isEmpty() )
           {
 #ifdef KMESSDEBUG_ACCOUNTSMANAGER_KWALLET
-            kDebug() << "Password for account" << handle << "removed.";
+            kmDebug() << "Password for account" << handle << "removed.";
 #endif
 
             account->setSavedPassword( "" );
@@ -449,7 +449,7 @@ void AccountsManager::slotWalletOpen( bool success )
         passwordGroup.writeEntry( handle, account->getPassword() );
 
 #ifdef KMESSDEBUG_ACCOUNTSMANAGER_KWALLET
-        kDebug() << "Password for account" << handle << "saved.";
+        kmDebug() << "Password for account" << handle << "saved.";
 #endif
       }
     }
@@ -465,7 +465,7 @@ void AccountsManager::slotWalletOpen( bool success )
         if( savePassword == false && passwordManager_->hasEntry( handle ) )
         {
 #ifdef KMESSDEBUG_ACCOUNTSMANAGER_KWALLET
-          kDebug() << "Removing account" << handle << "from wallet";
+          kmDebug() << "Removing account" << handle << "from wallet";
 #endif
 
           account->setSavedPassword( "" );
@@ -477,7 +477,7 @@ void AccountsManager::slotWalletOpen( bool success )
               && passwordManager_->writePassword( handle, account->getPassword() ) != 0 )
         {
 #ifdef KMESSDEBUG_ACCOUNTSMANAGER_KWALLET
-          kDebug() << "Couldn't store password for account" << handle;
+          kmDebug() << "Couldn't store password for account" << handle;
 #endif
           account->setSavedPassword( "" );
           continue;
@@ -519,7 +519,7 @@ void AccountsManager::setupPasswordManager()
   if( ! passwordManager_->setFolder( "KMess" ) )
   {
 #ifdef KMESSDEBUG_ACCOUNTSMANAGER_KWALLET
-    kWarning() << "Setting KWallet folder failed!";
+    kmWarning() << "Setting KWallet folder failed!";
 #endif
 
     delete passwordManager_;
@@ -553,7 +553,7 @@ void AccountsManager::setupPasswordManager()
     // There are some accounts passwords. Ask the user
     if( validAccounts.count() > 0 )
     {
-      kWarning() << "Insecure account passwords found for accounts: " << validAccounts;
+      kmWarning() << "Insecure account passwords found for accounts: " << validAccounts;
 
       int res = KMessageBox::questionYesNoCancel( 0,
                                                   i18n( "<html>Some insecurely stored account passwords have been found.<br />"
@@ -581,7 +581,7 @@ void AccountsManager::setupPasswordManager()
           // Import passwords to the wallet, and remove the plaintext ones
 
 #ifdef KMESSDEBUG_ACCOUNTSMANAGER_KWALLET
-          kDebug() << "Importing plaintext passwords to the wallet.";
+          kmDebug() << "Importing plaintext passwords to the wallet.";
 #endif
           foreach( const QString &accountHandle, passwordAccountList )
           {
@@ -591,7 +591,7 @@ void AccountsManager::setupPasswordManager()
               passwordManager_->writePassword( accountHandle, passwordGroup.readEntry( accountHandle, QString() ) );
               passwordGroup.deleteEntry( accountHandle );
 #ifdef KMESSDEBUG_ACCOUNTSMANAGER_KWALLET
-              kDebug() << "Imported password for account:" << accountHandle;
+              kmDebug() << "Imported password for account:" << accountHandle;
 #endif
             }
           }
@@ -601,12 +601,12 @@ void AccountsManager::setupPasswordManager()
           // Only delete the plain text passwords
 
 #ifdef KMESSDEBUG_ACCOUNTSMANAGER_KWALLET
-          kDebug() << "Deleting plain text account passwords.";
+          kmDebug() << "Deleting plain text account passwords.";
 #endif
           foreach( const QString &accountHandle, passwordAccountList )
           {
 #ifdef KMESSDEBUG_ACCOUNTSMANAGER_KWALLET
-            kDebug() << "Deleting plaintext password for account:" << accountHandle;
+            kmDebug() << "Deleting plaintext password for account:" << accountHandle;
 #endif
             passwordGroup.deleteEntry( accountHandle );
           }
@@ -616,7 +616,7 @@ void AccountsManager::setupPasswordManager()
           // Do nothing (useful if you wish to postpone the decision)
 
 #ifdef KMESSDEBUG_ACCOUNTSMANAGER_KWALLET
-            kDebug() << "No action against plaintext passwords will be taken now.";
+            kmDebug() << "No action against plaintext passwords will be taken now.";
 #endif
           break;
       }
@@ -624,7 +624,7 @@ void AccountsManager::setupPasswordManager()
   }
 
 #ifdef KMESSDEBUG_ACCOUNTSMANAGER_KWALLET
-  kDebug() << "KWallet successfully opened.";
+  kmDebug() << "KWallet successfully opened.";
 #endif
 }
 
@@ -674,7 +674,7 @@ void AccountsManager::showAccountSettings( Account *account, QWidget *parentWind
   if( ! account )
   {
 #ifdef KMESSDEBUG_ACCOUNTSMANAGER
-    kDebug() << "Opening settings for a new account";
+    kmDebug() << "Opening settings for a new account";
 #endif
 
     // Create an account to store the profile information
@@ -687,7 +687,7 @@ void AccountsManager::showAccountSettings( Account *account, QWidget *parentWind
 #ifdef KMESSDEBUG_ACCOUNTSMANAGER
   else
   {
-    kDebug() << "Opening settings for " << account->getHandle();
+    kmDebug() << "Opening settings for " << account->getHandle();
   }
 #endif
 
