@@ -28,6 +28,8 @@
 #include "../kmessapplication.h"
 #include "../kmessdebug.h"
 #include "../kmess.h"
+#include "chathistorymanager.h"
+#include "chathistorywriter.h"
 #include "chatmessageview.h"
 #include "chatwindow.h"
 #include "contactswidget.h"
@@ -56,6 +58,7 @@ Chat::Chat( QWidget *parent )
 : ChatView( parent )
 , firstMessage_( true )
 , initialized_( false )
+, logWriter_( 0 )
 , msnSwitchboardConnection_( 0 )
 {
   hide();
@@ -73,7 +76,7 @@ Chat::Chat( QWidget *parent )
 Chat::~Chat()
 {
 #ifdef KMESSDEBUG_CHAT_GENERAL
-  kDebug() << "DESTROYED.";
+  kmDebug() << "DESTROYED.";
 #endif
 }
 
@@ -165,7 +168,7 @@ void Chat::contactLeft( ContactBase *contact, bool isChatIdle )
   const QStringList participants ( getParticipants() );
 
 #ifdef KMESSDEBUG_CHAT_GENERAL
-  kDebug() << "contact '" << handle << "' has left" << (isChatIdle ? " due to inactivity" : "") << ".";
+  kmDebug() << "contact '" << handle << "' has left" << (isChatIdle ? " due to inactivity" : "") << ".";
 #endif
 
   // A contact has left the chat.
@@ -231,8 +234,8 @@ void Chat::contactTyping( ContactBase *contact, bool forceExpiration )
   }
 
 #ifdef KMESSDEBUG_CHAT_TYPING_MESSAGES
-  kDebug() << "Called with forceExpiration=" << forceExpiration << ", handle=" << handle << ", friendlyName=" << friendlyName;
-  kDebug() << "Current list:" << typingContactsNames_.keys();
+  kmDebug() << "Called with forceExpiration=" << forceExpiration << ", handle=" << handle << ", friendlyName=" << friendlyName;
+  kmDebug() << "Current list:" << typingContactsNames_.keys();
 #endif
 
   // Do not add anything to the list if the friendly name is empty
@@ -244,7 +247,7 @@ void Chat::contactTyping( ContactBase *contact, bool forceExpiration )
     if( typingContactsNames_.contains( handle ) )
     {
 #ifdef KMESSDEBUG_CHAT_TYPING_MESSAGES
-      kDebug() << "Removing" << handle << "from the list.";
+      kmDebug() << "Removing" << handle << "from the list.";
 #endif
       typingContactsNames_.remove( handle );
       typingContactsTimes_.remove( handle );
@@ -254,7 +257,7 @@ void Chat::contactTyping( ContactBase *contact, bool forceExpiration )
     if( ! forceExpiration )
     {
 #ifdef KMESSDEBUG_CHAT_TYPING_MESSAGES
-      kDebug() << "Adding" << handle << "to the list.";
+      kmDebug() << "Adding" << handle << "to the list.";
 #endif
       // Add this contact to the list of contacts which are typing, and record when it has started writing
       startTime.start();
@@ -264,7 +267,7 @@ void Chat::contactTyping( ContactBase *contact, bool forceExpiration )
 #ifdef KMESSDEBUG_CHAT_TYPING_MESSAGES
     else
     {
-      kDebug() << "Removal from the list was forced.";
+      kmDebug() << "Removal from the list was forced.";
     }
 #endif
   }
@@ -280,7 +283,7 @@ void Chat::contactTyping( ContactBase *contact, bool forceExpiration )
     if( secsTo >= CHAT_TYPING_EXPIRATION_TIME )
     {
 #ifdef KMESSDEBUG_CHAT_TYPING_MESSAGES
-      kDebug() << "Removing" << handle << "from the list due to expiration.";
+      kmDebug() << "Removing" << handle << "from the list due to expiration.";
 #endif
       typingContactsNames_.remove( it.key() );
       typingContactsTimes_.remove( it.key() );
@@ -294,7 +297,7 @@ void Chat::contactTyping( ContactBase *contact, bool forceExpiration )
   }
 
 #ifdef KMESSDEBUG_CHAT_TYPING_MESSAGES
-  kDebug() << "List after cleanup and update:" << typingContactsNames_.keys();
+  kmDebug() << "List after cleanup and update:" << typingContactsNames_.keys();
 #endif
 
   // The more time passes from the last update, the more we get close to the next update
@@ -304,7 +307,7 @@ void Chat::contactTyping( ContactBase *contact, bool forceExpiration )
   }
 
 #ifdef KMESSDEBUG_CHAT_TYPING_MESSAGES
-  kDebug() << "Next update in" << nextUpdate << "seconds.";
+  kmDebug() << "Next update in" << nextUpdate << "seconds.";
 #endif
 
   // Update the user interface
@@ -318,7 +321,7 @@ void Chat::contactTyping( ContactBase *contact, bool forceExpiration )
   }
 
 #ifdef KMESSDEBUG_CHAT_TYPING_MESSAGES
-  kDebug() << "emitting signal from:" << this;
+  kmDebug() << "emitting signal from:" << this;
 #endif
 
   // Let the other window components update, too
@@ -457,13 +460,13 @@ bool Chat::initialize( MsnSwitchboardConnection *switchboardConnection )
 {
   if ( initialized_ )
   {
-    kDebug() << "already initialized.";
+    kmDebug() << "already initialized.";
     return false;
   }
 
   if( ! ChatView::initialize() )
   {
-    kDebug() << "Couldn't setup the chat view widget.";
+    kmDebug() << "Couldn't setup the chat view widget.";
     return false;
   }
 
@@ -533,7 +536,7 @@ bool Chat::isContactInChat( const QString &handle, bool isExclusiveChatWithConta
   const QStringList participants( getParticipants() );
 
 #ifdef KMESSDEBUG_CHAT_CONTACTS
-  kDebug() << "Is" << handle << "in chat" << this << "?"
+  kmDebug() << "Is" << handle << "in chat" << this << "?"
            << "1-on-1 required?" << isExclusiveChatWithContact
            << "Participants:" << participants
            << "Has switchboard?" << ( msnSwitchboardConnection_ != 0 )
@@ -555,7 +558,7 @@ bool Chat::isContactInChat( const QString &handle, bool isExclusiveChatWithConta
   }
 
 #ifdef KMESSDEBUG_CHAT_CONTACTS
-  kDebug() << "Returning" << check;
+  kmDebug() << "Returning" << check;
 #endif
 
   return check;
@@ -567,14 +570,17 @@ bool Chat::isContactInChat( const QString &handle, bool isExclusiveChatWithConta
 void Chat::queryClose()
 {
 #ifdef KMESSDEBUG_CHAT_GENERAL
-  kDebug() << "Saving chat log";
+  kmDebug() << "Saving chat log";
 #endif
 
+  // Hide it now, to increase responsiveness
+  hide();
+
   // Notify ChatMaster
   emit closing( this );
 
-  // Save the chat
-  saveChatAutomatically();
+  // Save the chat logs
+  endChatLogging();
 
   /**
    * TODO: Uncomment this part: it needs a _reliable_ method to check whether there are running file
@@ -612,12 +618,15 @@ void Chat::queryClose()
 // The application is exiting
 void Chat::queryExit()
 {
+  // Hide it now, to increase responsiveness
+  hide();
+
 #ifdef KMESSDEBUG_CHAT_GENERAL
-  kDebug() << "Saving chat log";
+  kmDebug() << "Saving chat log";
 #endif
 
   // Just save the chat before going down
-  saveChatAutomatically();
+  endChatLogging();
 }
 
 
@@ -626,8 +635,8 @@ void Chat::queryExit()
 void Chat::receivedMessage(const ChatMessage &message)
 {
 #ifdef KMESSDEBUG_CHAT_GENERAL
-  kDebug() << "Displaying message, internal type=" << message.getType();
-  kDebug() << "First message = " << firstMessage_ << ".";
+  kmDebug() << "Displaying message, internal type=" << message.getType();
+  kmDebug() << "First message = " << firstMessage_ << ".";
 #endif
 
   showMessage( message );
@@ -654,7 +663,7 @@ void Chat::receivedMessage(const ChatMessage &message)
     // Send an auto away message every two minutes (if the contact keeps writing)
 
 #ifdef KMESSDEBUG_CHAT_GENERAL
-    kDebug() << "Sending auto reply to chat message.";
+    kmDebug() << "Sending auto reply to chat message.";
 #endif
 
     QString awayMessage( i18nc( "Automatic reply message",
@@ -697,44 +706,40 @@ void Chat::receivedMessage(const ChatMessage &message)
 
 
 /**
- * Save the chat if needed.
- *
- * The boolean argument should not be used, as it's used to recurse once when
- * the chat should also be saved to an external file.
+ * End the chat log.
  */
-void Chat::saveChatAutomatically( bool saveExternalFile )
+void Chat::endChatLogging()
 {
-  // Check if "save chats" is enabled
-  if( ! currentAccount_->getSaveChats() )
+  kmDebug() << "Ending chat logging";
+
+  // End the log writing session, if any
+  delete logWriter_;
+  logWriter_ = 0;
+
+  if( ! currentAccount_->getSaveChatsToFile() )
   {
 #ifdef KMESSDEBUG_CHAT_GENERAL
-    kDebug() << "User has save chats disabled, not saving chat.";
+    kmDebug() << "User has disabled exporting chats to file. Canceling.";
 #endif
     return;
   }
 
+
   // Check if the message area is empty, we won't save empty chats
   if( isEmpty() )
   {
 #ifdef KMESSDEBUG_CHAT_GENERAL
-    kDebug() << "Message area is empty, not saving chat.";
+    kmDebug() << "Message area is empty, not exporting chat.";
 #endif
     return;
   }
 
-#ifdef KMESSDEBUG_CHAT_GENERAL
-  if( ! saveExternalFile )
-  {
-    kDebug() << "Automatically saving the XML log file.";
-  }
-  else
-  {
-    kDebug() << "Automatically saving the external log file.";
-  }
-#endif
+  KMessApplication *kmessApp = static_cast<KMessApplication*>( kapp );
+  bool canDoUserInteraction = ! kmessApp->quitSelected(); // Not if we're exiting
 
   QDir    dir;
-  QString fileName, extension;
+  QString fileName;
+  QString extension;
   Account::ChatExportFormat format;
 
   // Set the base file name, same for all logs
@@ -749,68 +754,49 @@ void Chat::saveChatAutomatically( bool saveExternalFile )
     fileName = participants.first();
   }
 
-  if( ! saveExternalFile )
+  dir.setPath( currentAccount_->getSaveChatPath() );
+  format = currentAccount_->getSaveChatsFormat();
+  switch( format )
   {
-    extension = "xml";
-    format = Account::EXPORT_XML;
-    dir.setPath( KMessConfig::instance()->getAccountDirectory( currentAccount_->getHandle() )
-               + "/chatlogs" );
+    case Account::EXPORT_TEXT:
+      extension = "txt";
+      break;
+    case Account::EXPORT_HTML:
+      extension = "html";
+      break;
+    default:
+      kmWarning() << "Extension is unknown for save format" << format << "! Using \"html\".";
+      extension = "html";
+      format = Account::EXPORT_HTML;
+      break;
   }
-  else
+
+  const QString year ( startDate_.toString( "yyyy" ) );
+  const QString month( startDate_.toString( "MM"   ) );
+  const QString day  ( startDate_.toString( "dd"   ) );
+
+  // Determine the path where to save the log file
+  switch( currentAccount_->getSavedChatDirectoryStructure() )
   {
-    dir.setPath( currentAccount_->getSaveChatPath() );
-    format = currentAccount_->getSaveChatsFormat();
-    switch( format )
-    {
-      case Account::EXPORT_TEXT:
-        extension = "txt";
-        break;
-      case Account::EXPORT_HTML:
-        extension = "html";
-        break;
-      default:
-        kWarning() << "Extension is unknown for save format" << format << "! Using \"html\".";
-        extension = "html";
-        format = Account::EXPORT_HTML;
-        break;
-    }
+    // Save as <logs-path>/yyyy/contactemail.ext
+    case Account::BYYEAR:
+      dir.setPath( dir.absolutePath() + "/" + year );
+      break;
 
-    const QString year ( startDate_.toString( "yyyy" ) );
-    const QString month( startDate_.toString( "MM"   ) );
-    const QString day  ( startDate_.toString( "dd"   ) );
+    // Save as <logs-path>/yyyy/mm/contactemail.ext
+    case Account::BYMONTH:
+      dir.setPath( dir.absolutePath() + "/" + year + "/" + month );
+      break;
 
-    // Determine the path where to save the log file
-    switch( currentAccount_->getSavedChatDirectoryStructure() )
-    {
-      // Save as <logs-path>/yyyy/contactemail.ext
-      case Account::BYYEAR:
-        if( ! dir.exists( year  ) ) dir.mkdir( year  );
-        dir.cd( year  );
-        break;
+    // Save as <logs-path>/yyyy/mm/dd/contactemail.ext
+    case Account::BYDAY:
+      dir.setPath( dir.absolutePath() + "/" + year + "/" + month + "/" + day );
+      break;
 
-      // Save as <logs-path>/yyyy/mm/contactemail.ext
-      case Account::BYMONTH:
-        if( ! dir.exists( year  ) ) dir.mkdir( year  );
-        dir.cd( year  );
-        if( ! dir.exists( month ) ) dir.mkdir( month );
-        dir.cd( month );
-        break;
-
-      // Save as <logs-path>/yyyy/mm/dd/contactemail.ext
-      case Account::BYDAY:
-        if( ! dir.exists( year  ) ) dir.mkdir( year  );
-        dir.cd( year  );
-        if( ! dir.exists( month ) ) dir.mkdir( month );
-        dir.cd( month );
-        if( ! dir.exists( day   ) ) dir.mkdir( day   );
-        dir.cd( day   );
-        break;
-
-      // Save as <logs-path>/contactemail.ext
-      case Account::SINGLEDIRECTORY:
-      default:
-        break;
-    }
+    // Save as <logs-path>/contactemail.ext
+    case Account::SINGLEDIRECTORY:
+    default:
+      break;
   }
 
   // Try creating the directory if it doesn't exist
@@ -820,90 +806,71 @@ void Chat::saveChatAutomatically( bool saveExternalFile )
   }
   if( ! dir.exists() ) // It couldn't be created
   {
-    KMessApplication *kmessApp = static_cast<KMessApplication*>( kapp );
-    if( ! kmessApp->quitSelected() )
+    // Always warn via debug log, and also via a messagebox if we're not exiting
+    kmWarning() << "Unable to save the chat log. The base directory" << dir.absolutePath() << "doesn't exist and could not be created.";
+
+    if( canDoUserInteraction )
     {
       KMessageBox::sorry( getChatWindow(),
-                          i18n( "<html>KMess could not save the log for this chat:<br />"
-                                "The chat logs directory, &quot;%1&quot;, does not exist.</html>",
+                          i18n( "<html>KMess could not save the log for the chat with &quot;%1&quot;:<br />"
+                                "The chat logs directory, &quot;%2&quot;, does not exist.</html>",
+                                currentAccount_->getContactFriendlyNameByHandle( participants.first() ),
                                 dir.absolutePath() ) );
     }
-    // TODO: show a KDE save file dialog
-
-    // Always warn via debug log, too
-    kWarning() << "Unable to save the chat log. The base directory" << dir.absolutePath() << "doesn't exist.";
     return;
   }
 
-  int fileNumber = 0;
-  QString fileCount;
-  QString savePath( dir.absolutePath() + "/" );
+  // Obtain the file path to be used to export the chat
+  QFile logFile;
+  QFileInfo fileInfo;
+  QString lastFile;
+  QString nextFile( KMessShared::nextSequentialFile( dir.absolutePath(), fileName, extension, lastFile ) );
 
-  // We need to get the current (last) logging file; if it's not too big we'll append
-  // to it; if it is too big or there is no current/last logging file, we'll create a new one.
-  bool lastFileExists = KMessShared::selectNextFile( savePath, fileName, fileCount, extension, fileNumber );
+  fileInfo.setFile( lastFile );
 
-  // this is the last file as pointed to by selectNextFile; lastFileExists should be the same as file.exists()
-  QFile file( savePath + fileName + fileCount + "." + extension );
-
-  // There are log files already for this contact: verify if we can
-  // append to the last one: logs should not be too big (2MB max)
-  if( lastFileExists && file.size() > Chat::MAX_LOG_FILE_SIZE )
+  // Where there already is a log file for this contact, verify if we can
+  // append to it. Log files should not be too big
+  if( lastFile.isEmpty() || ! fileInfo.isWritable() ||  fileInfo.size() > MAX_LOG_FILE_SIZE )
   {
 #ifdef KMESSDEBUG_CHAT_GENERAL
-    kDebug() << "Last file" << file.fileName() << "is too big, creating a new file";
-#endif
-    // so automatically choose the next file name.
-    file.setFileName( savePath + fileName + "." + QString::number( fileNumber ) + "." + extension );
-  }
-
-  // if lastFileExists == false. then the base file is available for writing.
-  // use it.
-
-#ifdef KMESSDEBUG_CHAT_GENERAL
-  kDebug() << "Saving to chat log file:" << file.fileName();
-#endif
-
-  // Save the chat in the format requested by the user
-  if( ! saveChatToFile( file.fileName(), format,
-                        false, /* Don't overwrite */
-                        false  /* No user interaction */ ) )
-  {
-    // If saving fails (due to a corrupted file for example) try to save the chat
-    // with the next available file name
-
-    // Possible race condition but we'll take it: since we can assume the
-    // returned file above was indeed the last file, the next file must be
-    // nonexistant, so we use that as a new file now
-
-    // Another thing is that if we were *already* creating a new file and the
-    // save failed, we will try to save to the same file yet again. However,
-    // when saving to a new file already fails, whatever we do it probably
-    // won't work with a different filename either.
-    // TODO: make this more robust.
-
-    file.setFileName( savePath + fileName + "." + QString::number( fileNumber ) + "." + extension );
-    kWarning() << "Save failed. Trying next file name=" << file.fileName();
-
-    // Try to save it again, this time warning the user if it fails once more
-    if( ! saveChatToFile( file.fileName(), format, false, true ) )
+    if( lastFile.isEmpty() )
     {
-      kWarning() << "Second save failed too.";
+      kmDebug() << "No file to append to, creating a new file:" << nextFile;
     }
-#ifdef KMESSDEBUG_CHAT_GENERAL
     else
     {
-      kDebug() << "Second save attempt succeeded.";
+      kmDebug() << "Last file" << lastFile << "cannot be used, creating a new file:" << nextFile;
     }
+#endif
+    fileInfo.setFile( nextFile );
+  }
+  else
+  {
+#ifdef KMESSDEBUG_CHAT_GENERAL
+    kmDebug() << "Appending to last chat log file:" << lastFile;
 #endif
   }
 
-  if( saveExternalFile == false && currentAccount_->getSaveChatsToFile() )
+  // Save the chat in the format requested by the user
+  if( ! saveChatToFile( fileInfo.absoluteFilePath(),
+                        format,
+                        false, /* Don't overwrite */
+                        canDoUserInteraction  /* No user interaction */ ) )
   {
-#ifdef KMESSDEBUG_CHAT_GENERAL
-    kDebug() << "Done, saving external file too...";
-#endif
-    saveChatAutomatically( true );
+    kmWarning() << "Exporting chat log to file" << fileInfo.absoluteFilePath() << "failed!";
+
+    // Try again with a new file if we were trying to append to the last one
+    if( fileInfo.absoluteFilePath() == lastFile )
+    {
+      fileInfo.setFile( nextFile );
+      if( ! saveChatToFile( fileInfo.absoluteFilePath(),
+                            format,
+                            false, /* Don't overwrite */
+                            canDoUserInteraction  /* No user interaction */ ) )
+      {
+        kmWarning() << "Second attempt at exporting chat log to file" << fileInfo.absoluteFilePath() << "failed!";
+      }
+    }
   }
 }
 
@@ -939,6 +906,20 @@ void Chat::sendInkMessage( InkFormat format, const QByteArray &inkData )
 
 
 
+// Reimplemented from ChatView to support logging
+void Chat::showMessage( const ChatMessage& message )
+{
+  // Log the message
+  if( currentAccount_->getSaveChats() && logWriter_ )
+  {
+    logWriter_->logMessage( message );
+  }
+
+  ChatView::showMessage( message );
+}
+
+
+
 // Send an "user is typing" message to the contacts
 void Chat::sendTypingMessage()
 {
@@ -981,6 +962,12 @@ void Chat::sendWink( const MsnObject &msnObject )
                        notificationText + winkHtml, // Add the actual wink after the message
                        QString() );
   showMessage( message );
+
+  // Log the message
+  if( currentAccount_->getSaveChats() && logWriter_ )
+  {
+    logWriter_->logMessage( message );
+  }
 }
 
 
@@ -1036,11 +1023,11 @@ void Chat::setSwitchboardConnection( MsnSwitchboardConnection *newConnection )
 #ifdef KMESSDEBUG_CHAT_GENERAL
   if( msnSwitchboardConnection_ == 0 )
   {
-    kDebug() << "Switchboard was not set up.";
+    kmDebug() << "Switchboard was not set up.";
   }
   else
   {
-    kDebug() << "Switchboard was "
+    kmDebug() << "Switchboard was "
               << ( msnSwitchboardConnection_ == newConnection ? "already set" : "different" ) << "." << endl;
   }
 #endif
@@ -1053,7 +1040,7 @@ void Chat::setSwitchboardConnection( MsnSwitchboardConnection *newConnection )
       const QStringList participants( getParticipants() );
 
 #ifdef KMESSDEBUG_CHAT_GENERAL
-      kDebug() << "Removing old switchboard's participants from the chat:" << participants;
+      kmDebug() << "Removing old switchboard's participants from the chat:" << participants;
 #endif
       foreach( const QString &handle, participants )
       {
@@ -1122,7 +1109,7 @@ void Chat::setSwitchboardConnection( MsnSwitchboardConnection *newConnection )
   // Add to the contacts widget all the contacts that are present in the new switchboard
   const QStringList participants( getParticipants() );
 #ifdef KMESSDEBUG_CHAT_GENERAL
-  kDebug() << "Adding new switchboard's participants to the chat:" << participants;
+  kmDebug() << "Adding new switchboard's participants to the chat:" << participants;
 #endif
   foreach( const QString &handle, participants )
   {
@@ -1237,7 +1224,7 @@ void Chat::showWarning( MsnSwitchboardConnection::WarningType type, ContactBase
 void Chat::showWink( const QString &handle, const QString &filename, const QString &animationName )
 {
 #ifdef KMESSDEBUG_CHAT_GENERAL
-  kDebug() << "Processing received wink data.";
+  kmDebug() << "Processing received wink data.";
 #endif
 
   QString message;
@@ -1277,7 +1264,7 @@ void Chat::showWink( const QString &handle, const QString &filename, const QStri
   // Test whether the file exists, before cabextract fails.
   if( ! QFile::exists( filename ) )
   {
-    kWarning() << "file not found: " << filename << "!";
+    kmWarning() << "file not found: " << filename << "!";
     return;
   }
 
@@ -1397,7 +1384,7 @@ void Chat::slotContactChangedStatus()
   if( ! isContactInChat( contact->getHandle(), false ) )
   {
 #ifdef KMESSDEBUG_CHAT_GENERAL
-    kDebug() << "Received a status change signal from a contact not in chat!";
+    kmDebug() << "Received a status change signal from a contact not in chat!";
 #endif
     return;
   }
@@ -1448,7 +1435,7 @@ void Chat::slotContactChangedStatus()
 void Chat::slotReceivedNudge( ContactBase *contact )
 {
 #ifdef KMESSDEBUG_CHAT_GENERAL
-  kDebug() << "Received a nudge.";
+  kmDebug() << "Received a nudge.";
 #endif
 
   // Get friendly name
@@ -1481,7 +1468,7 @@ void Chat::slotSendingFailed( const QString &handle, const MimeMessage &message
   QString friendlyName;
 
 #ifdef KMESSDEBUG_CHAT_GENERAL
-  kDebug() << "Showing a sending failure notice.";
+  kmDebug() << "Showing a sending failure notice.";
 #endif
 
   // It's possible that a message could not be delivered to any of the contacts in chat:
@@ -1512,7 +1499,7 @@ void Chat::slotSendingFailed( const QString &handle, const MimeMessage &message
                               friendlyName );
         break;
       default: // Unsupported datacast?!
-        kWarning() << "Failed sending datacast message: no sending failure chat message available!";
+        kmWarning() << "Failed sending datacast message: no sending failure chat message available!";
         return;
     }
   }
@@ -1540,7 +1527,7 @@ void Chat::slotSendingFailed( const QString &handle, const MimeMessage &message
   else
   {
 #ifdef KMESSDEBUG_CHAT_GENERAL
-    kDebug() << "Not displaying a sending failure notice for messages of type" << contentType;
+    kmDebug() << "Not displaying a sending failure notice for messages of type" << contentType;
 #endif
     return;
   }
@@ -1567,20 +1554,20 @@ void Chat::startFileTransfer( QList<QUrl> fileList )
   if( handle.isEmpty() )
   {
 #ifdef KMESSDEBUG_CHAT_FILETRANSFER
-    kDebug() << "Unable to find a contact to send files to. Aborting.";
+    kmDebug() << "Unable to find a contact to send files to. Aborting.";
 #endif
     return;
   }
 
 #ifdef KMESSDEBUG_CHAT_FILETRANSFER
-  kDebug() << "File list contents:" << fileList;
-  kDebug() << "Chosen handle:" << handle;
+  kmDebug() << "File list contents:" << fileList;
+  kmDebug() << "Chosen handle:" << handle;
 #endif
 
   if( fileList.isEmpty() )
   {
 #ifdef KMESSDEBUG_CHAT_FILETRANSFER
-    kDebug() << "Asking for a file to send";
+    kmDebug() << "Asking for a file to send";
 #endif
 
     // If no file names were given, ask for a filename
@@ -1603,14 +1590,14 @@ void Chat::startFileTransfer( QList<QUrl> fileList )
     if( ! localFileUrl.isLocalFile() )
     {
 #ifdef KMESSDEBUG_CHAT_FILETRANSFER
-      kDebug() << "Not a local file, copying it locally.";
+      kmDebug() << "Not a local file, copying it locally.";
 #endif
       // Download the remote file to a temporary folder
       QString localFilePath;
       if( ! KIO::NetAccess::download( fileUrl, localFilePath, this ) )
       {
 #ifdef KMESSDEBUG_CHAT_FILETRANSFER
-        kDebug() << "Copy failed.";
+        kmDebug() << "Copy failed.";
 #endif
         // Show a message to the user
         showMessage( ChatMessage( ChatMessage::TYPE_SYSTEM,
@@ -1628,7 +1615,7 @@ void Chat::startFileTransfer( QList<QUrl> fileList )
     }
 
 #ifdef KMESSDEBUG_CHAT_FILETRANSFER
-    kDebug() << "Original file URL:" << fileUrl << "-- Local file URL:" << localFileUrl;
+    kmDebug() << "Original file URL:" << fileUrl << "-- Local file URL:" << localFileUrl;
 #endif
 
     // Ask the ChatMaster to initiate the file transfer. If there are multiple contacts
@@ -1685,20 +1672,20 @@ void Chat::startChat()
   if( KMESS_NULL(msnSwitchboardConnection_) )
   {
 #ifdef KMESSDEBUG_CHAT_GENERAL
-    kWarning() << "Tried to open a chat without a switchboard!";
+    kmWarning() << "Tried to open a chat without a switchboard!";
 #endif
     return;
   }
 
 #ifdef KMESSDEBUG_CHAT_GENERAL
-  kDebug() << "Opening a chat of type:" << ( msnSwitchboardConnection_->isInactive() ? "Offline" : "Active" );
+  kmDebug() << "Opening a chat of type:" << ( msnSwitchboardConnection_->isInactive() ? "Offline" : "Active" );
 #endif
 
   // Add the participant contacts to the chat, even if they're offline
   const QStringList participants( msnSwitchboardConnection_->getContactsInChat() );
 
 #ifdef KMESSDEBUG_CHAT_GENERAL
-  kDebug() << "Adding initial chat participants to the chat:" << participants;
+  kmDebug() << "Adding initial chat participants to the chat:" << participants;
 #endif
 
   foreach( const QString &handle, participants )
@@ -1711,14 +1698,43 @@ void Chat::startChat()
     contactsWidget_->contactJoined( contact );
   }
 
+  if( participants.isEmpty() )
+  {
+    kmWarning() << "The list of participants is empty!";
+    return;
+  }
+
+
+  const QString handle( participants.first() );
+
+  // Show the last recorded conversation, if any is present
+  if( participants.count() == 1 )
+  {
+    QString lastChat( ChatHistoryManager::lastChatLog( handle ) );
+    if( ! lastChat.isEmpty() )
+    {
+#ifdef KMESSDEBUG_CHAT_GENERAL
+      kmDebug() << "Adding last chat log into the chat window";
+#endif
+
+      setContents( lastChat );
+    }
+  }
+
+  // Start up the log writer
+  if( currentAccount_->getSaveChats() )
+  {
+    logWriter_ = ChatHistoryManager::getWriter( handle );
+  }
+
   // if this is an offline chat, inform the user.
   if( getParticipants().size() == 1 && msnSwitchboardConnection_->isInactive() )
   {
-    ContactBase *contact = currentAccount_->getContactByHandle( getParticipants().first() );
+    ContactBase *contact = currentAccount_->getContactByHandle( handle );
     if( contact && contact->isOffline() )
     {
 #ifdef KMESSDEBUG_CHAT_GENERAL
-      kDebug() << "Initial chat participant " << contact->getHandle() << " is offline; pretending the contact joined";
+      kmDebug() << "Initial chat participant" << handle << "is offline; pretending the contact joined";
 #endif
       contactJoined( contact, true );
 
@@ -1726,10 +1742,12 @@ void Chat::startChat()
                                     ChatMessage::CONTENT_SYSTEM_NOTICE,
                                     false,
                                     i18n( "%1 is currently offline. Any messages you send will be delivered the next time he or she logs in.",
-                                          contact->getFriendlyName( STRING_CLEANED_ESCAPED ) ),
-                                    contact->getHandle() ) );
+                                    contact->getFriendlyName( STRING_CLEANED_ESCAPED ) ),
+                                    handle ) );
     }
   }
+
+  scrollToBottom( true /* forced scrolling */ );
 }
 
 
