@@ -69,7 +69,7 @@ ChatMaster::~ChatMaster()
   disconnected();
 
   // Delete all open windows
-  kDebug() << chatWindows_;
+  kmDebug() << chatWindows_;
   qDeleteAll( chatWindows_ );
   chatWindows_.clear();
 
@@ -78,7 +78,7 @@ ChatMaster::~ChatMaster()
   pendingMimeMessages_.clear();
 
 #ifdef KMESSDEBUG_CHATMASTER
-  kDebug() << "DESTROYED.";
+  kmDebug() << "DESTROYED.";
 #endif
 }
 
@@ -94,7 +94,7 @@ void ChatMaster::connected()
   }
 
 #ifdef KMESSDEBUG_CHATMASTER
-  kDebug() << "Trying reactivation of" << chats_.count() << "open chats.";
+  kmDebug() << "Trying reactivation of" << chats_.count() << "open chats.";
 #endif
 
   QList<ChatWindow*> windowsList;
@@ -119,13 +119,13 @@ void ChatMaster::connected()
     const QStringList participants( chat->getParticipants() );
 
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "Reactivating chat:" << participants;
+    kmDebug() << "Reactivating chat:" << participants;
 #endif
 
     // Check if the participants list is empty: if so, there's something fishy going on.
     if( participants.isEmpty() )
     {
-      kWarning() << "Tried to reactivate chat with no contacts - has a window?" << ( chat->getChatWindow() != 0 );
+      kmWarning() << "Tried to reactivate chat with no contacts - has a window?" << ( chat->getChatWindow() != 0 );
       chat->getChatWindow()->removeChatTab( chat );
       continue;
     }
@@ -134,7 +134,7 @@ void ChatMaster::connected()
     if( participants.count() > 1 )
     {
 #ifdef KMESSDEBUG_CHATMASTER
-      kDebug() << "This is a group chat, skipping it.";
+      kmDebug() << "This is a group chat, skipping it.";
 #endif
       continue;
     }
@@ -145,14 +145,14 @@ void ChatMaster::connected()
     if( currentAccount_->getContactByHandle( handle ) == 0 )
     {
 #ifdef KMESSDEBUG_CHATMASTER
-      kDebug() << "This chat is with a non-listed contact, closing it.";
+      kmDebug() << "This chat is with a non-listed contact, closing it.";
 #endif
       chat->getChatWindow()->removeChatTab( chat );
       continue;
     }
 
 #ifdef KMESSDEBUG_CHATMASTER
-      kDebug() << "Reactivating chat with listed contact:" << handle;
+      kmDebug() << "Reactivating chat with listed contact:" << handle;
 #endif
 
     // Create a new switchboard, setting it as empty but with an hint about
@@ -192,7 +192,7 @@ void ChatMaster::disconnected()
   if( ! chatWindows_.isEmpty() )
   {
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "Disabling" << chatWindows_.count() << "open chat windows.";
+    kmDebug() << "Disabling" << chatWindows_.count() << "open chat windows.";
 #endif
 
     // Go through all the chats
@@ -207,7 +207,7 @@ void ChatMaster::disconnected()
   if( ! switchboardConnections_.isEmpty() )
   {
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "Closing" << switchboardConnections_.count() << "open switchboards.";
+    kmDebug() << "Closing" << switchboardConnections_.count() << "open switchboards.";
 #endif
 
     // give each switchboard a chance to close properly.
@@ -220,7 +220,7 @@ void ChatMaster::disconnected()
   if( ! chats_.isEmpty() )
   {
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "Closing" << chats_.count() << "open chats.";
+    kmDebug() << "Closing" << chats_.count() << "open chats.";
 #endif
 
     // Go through all the chats and disable them
@@ -247,7 +247,7 @@ void ChatMaster::connecting()
   }
 
 #ifdef KMESSDEBUG_CHATMASTER
-  kDebug() << "Disabling reconnect button of" << chats_.count() << "open chats.";
+  kmDebug() << "Disabling reconnect button of" << chats_.count() << "open chats.";
 #endif
 
   QList<ChatWindow*> windowsList;
@@ -274,7 +274,7 @@ void ChatMaster::connecting()
 void ChatMaster::forwardRequestNewSwitchboard( QString handle )
 {
 #ifdef KMESSDEBUG_CHATMASTER
-  kDebug() << "Forwarding the new switchboard request signal for "
+  kmDebug() << "Forwarding the new switchboard request signal for "
             << handle << "." << endl;
 #endif
 
@@ -324,7 +324,7 @@ ApplicationList * ChatMaster::getApplicationList(const QString &handle)
 
   if( handle == currentAccount_->getHandle() )
   {
-    kWarning() << "Cannot start applications with yourself.";
+    kmWarning() << "Cannot start applications with yourself.";
     return 0;
   }
 
@@ -337,7 +337,7 @@ ApplicationList * ChatMaster::getApplicationList(const QString &handle)
   {
     // Create object if it wasn't created yet for this contact.
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "Creating application list for contact " << handle;
+    kmDebug() << "Creating application list for contact " << handle;
 #endif
     appList = contact->createApplicationList();
 
@@ -481,7 +481,7 @@ bool ChatMaster::initialize()
 {
   if ( initialized_ )
   {
-    kDebug() << "Already initialized.";
+    kmDebug() << "Already initialized.";
     return false;
   }
 
@@ -527,7 +527,7 @@ void ChatMaster::requestChat( QString handle )
   // Forbid chatting with yourself
   if( handle == currentAccount_->getHandle() )
   {
-    kWarning() << "Cannot chat with yourself.";
+    kmWarning() << "Cannot chat with yourself.";
     return;
   }
 
@@ -554,7 +554,7 @@ void ChatMaster::requestChat( QString handle )
     connectionType = ChatInformation::CONNECTION_OFFLINE;
 
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "Starting an offline chat with " << handle;
+    kmDebug() << "Starting an offline chat with " << handle;
 #endif
   }
   else
@@ -563,7 +563,7 @@ void ChatMaster::requestChat( QString handle )
     connectionType = ChatInformation::CONNECTION_CHAT;
 
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "Requesting a switchboard to chat with " << handle;
+    kmDebug() << "Requesting a switchboard to chat with " << handle;
 #endif
   }
 
@@ -588,7 +588,7 @@ void ChatMaster::requestChat( QString handle )
 void ChatMaster::slotChatClosing( Chat *chat )
 {
 #ifdef KMESSDEBUG_CHATMASTER
-  kDebug() << "Marking chat as closing.";
+  kmDebug() << "Marking chat as closing.";
 #endif
 
   // Make sure this chat window don't receive new messages.
@@ -608,7 +608,7 @@ void ChatMaster::slotChatClosing( Chat *chat )
 void ChatMaster::slotChatDestroyed( QObject *chatObject )
 {
 #ifdef KMESSDEBUG_CHATMASTER
-  kDebug() << "Removing chat from list.";
+  kmDebug() << "Removing chat from list.";
 #endif
 
   // Remove from the list
@@ -623,7 +623,7 @@ void ChatMaster::slotChatDestroyed( QObject *chatObject )
 void ChatMaster::slotChatWindowDestroyed(QObject *chatWindow)
 {
 #ifdef KMESSDEBUG_CHATMASTER
-  kDebug() << "Removing chat window from list.";
+  kmDebug() << "Removing chat window from list.";
 #endif
 
   // Remove from the list
@@ -638,7 +638,7 @@ void ChatMaster::slotChatWindowDestroyed(QObject *chatWindow)
 void ChatMaster::slotConnectApplication(Application *application)
 {
 #ifdef KMESSDEBUG_CHATMASTER
-  kDebug() << "Connecting application signals.";
+  kmDebug() << "Connecting application signals.";
 #endif
 
   connect( application, SIGNAL(       applicationMessage(const ChatMessage&)            ),
@@ -652,7 +652,7 @@ void ChatMaster::slotConnectApplication(Application *application)
     if( qobject_cast<InkTransferP2P*>( application ) != 0 )
     {
 #ifdef KMESSDEBUG_CHATMASTER
-      kDebug() << "Connecting additional signals for InkTransferP2P.";
+      kmDebug() << "Connecting additional signals for InkTransferP2P.";
 #endif
 
       connect( application, SIGNAL(       inkReceived(const QString&,const QString&,InkFormat) ),
@@ -660,7 +660,7 @@ void ChatMaster::slotConnectApplication(Application *application)
     }
     else
     {
-      kWarning() << "Unknown datacast application: " << application->metaObject()->className();
+      kmWarning() << "Unknown datacast application: " << application->metaObject()->className();
     }
   }
 }
@@ -671,7 +671,7 @@ void ChatMaster::slotConnectApplication(Application *application)
 void ChatMaster::queueMessage( const MimeMessage &message, const QString &handle, bool privateChatRequired )
 {
 #ifdef KMESSDEBUG_CHATMASTER
-  kDebug() << "Adding message for '" << handle << "' to the queue "
+  kmDebug() << "Adding message for '" << handle << "' to the queue "
             << "(size=" << ( pendingMimeMessages_.count() + 1 ) << ")." << endl;
 #endif
   // NOTE: Store these pending in ApplicationList class instead?
@@ -696,7 +696,7 @@ void ChatMaster::raiseChat( Chat *chat, bool force )
   if( chat == 0 || ! chats_.contains( chat ) )
   {
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "Invalid raising request received; chat is probably already closed.";
+    kmDebug() << "Invalid raising request received; chat is probably already closed.";
 #endif
     return;
   }
@@ -705,7 +705,7 @@ void ChatMaster::raiseChat( Chat *chat, bool force )
   if( chatWindow == 0 || ! chatWindows_.contains( chatWindow ) )
   {
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "Invalid raising request received; chat is probably already closed.";
+    kmDebug() << "Invalid raising request received; chat is probably already closed.";
 #endif
     return;
   }
@@ -713,7 +713,7 @@ void ChatMaster::raiseChat( Chat *chat, bool force )
   if( chatWindow->isVisible() && ! force )
   {
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "Window has focus already.";
+    kmDebug() << "Window has focus already.";
 #endif
     return;
   }
@@ -730,7 +730,7 @@ void ChatMaster::raiseChat( Chat *chat, bool force )
   if( ! force )
   {
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "Showing minimized window.";
+    kmDebug() << "Showing minimized window.";
 #endif
     // Required for new chats
     chatWindow->showMinimized();
@@ -743,21 +743,21 @@ void ChatMaster::raiseChat( Chat *chat, bool force )
   // Notify about the new window and force it to show and receive focus. Only use upon user request.
 
 #ifdef KMESSDEBUG_CHATMASTER
-  kDebug() << "Forcing window raise.";
+  kmDebug() << "Forcing window raise.";
 #endif
 
   // Show the chat's window
   if( chatWindow->isMinimized() )
   {
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "Window was minimized, showing it.";
+    kmDebug() << "Window was minimized, showing it.";
 #endif
     chatWindow->showNormal();
   }
   else
   {
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "Window was not minimized, showing it again.";
+    kmDebug() << "Window was not minimized, showing it again.";
 #endif
     chatWindow->show();
   }
@@ -789,7 +789,7 @@ void ChatMaster::raiseChat( Chat *chat, bool force )
 void ChatMaster::sendPendingMimeMessages( const QString &handle, MsnSwitchboardConnection *connection )
 {
 #ifdef KMESSDEBUG_CHATMASTER
-  kDebug() << "Sending pending messages for contact " << handle << ", if any.";
+  kmDebug() << "Sending pending messages for contact " << handle << ", if any.";
 #endif
 
   QList<PendingMimeMessage*> sentMessages;
@@ -809,7 +809,7 @@ void ChatMaster::sendPendingMimeMessages( const QString &handle, MsnSwitchboardC
     if( pendingMimeMessage->privateChatRequired && ! isPrivateChat )
     {
 #ifdef KMESSDEBUG_CHATMASTER
-      kDebug() << "Switchboard is not a private chat, keeping message in queue.";
+      kmDebug() << "Switchboard is not a private chat, keeping message in queue.";
 #endif
 
       // Get next message
@@ -820,7 +820,7 @@ void ChatMaster::sendPendingMimeMessages( const QString &handle, MsnSwitchboardC
     if( connection->isBusy() )
     {
 #ifdef KMESSDEBUG_CHATMASTER
-      kDebug() << "Switchboard is busy again, keeping remaining messages in the queue.";
+      kmDebug() << "Switchboard is busy again, keeping remaining messages in the queue.";
 #endif
       goto cleanup_return;
     }
@@ -830,7 +830,7 @@ void ChatMaster::sendPendingMimeMessages( const QString &handle, MsnSwitchboardC
     {
       // getContactsInChat() may be empty, don't re-invite the last contact to deviver the message
 #ifdef KMESSDEBUG_CHATMASTER
-      kDebug() << "Switchboard is not connected or contact left chat, keeping remaining messages in the queue.";
+      kmDebug() << "Switchboard is not connected or contact left chat, keeping remaining messages in the queue.";
 #endif
       goto cleanup_return;
     }
@@ -856,13 +856,13 @@ cleanup_return:
 void ChatMaster::showSpecialMessage( const ChatMessage &message, const MsnSwitchboardConnection *switchboardChat )
 {
 #ifdef KMESSDEBUG_CHATMASTER
-  kDebug() << "Delivering application/ink/OIM chat message to chat window.";
+  kmDebug() << "Delivering application/ink/OIM chat message to chat window.";
 #endif
 
   const QString &handle = message.getContactHandle();
 
 #ifdef KMESSDEBUG_CHATMASTER
-  kDebug() << "Message info, Contact: " << handle << " - Message body: '" << message.getBody() << "' - "
+  kmDebug() << "Message info, Contact: " << handle << " - Message body: '" << message.getBody() << "' - "
               "Message type: " << message.getType() << " - Message class: " << message.getContentsClass() << "." << endl;
 #endif
 
@@ -880,7 +880,7 @@ void ChatMaster::showSpecialMessage( const ChatMessage &message, const MsnSwitch
   if( chat != 0 )
   {
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "Delivering message.";
+    kmDebug() << "Delivering message.";
 #endif
 
     // The chat window is currently closing
@@ -890,12 +890,12 @@ void ChatMaster::showSpecialMessage( const ChatMessage &message, const MsnSwitch
       {
         // TODO: Sometimes, you close a window when the other contact sends a new message, and you lose it.
         // Maybe it's possible to avoid the loss, for example with a notification balloon to notify of the message.
-        kWarning() << "Chat window is closing, suppressing message '" << message.getBody() << "' from '" << handle << "'.";
+        kmWarning() << "Chat window is closing, suppressing message '" << message.getBody() << "' from '" << handle << "'.";
       }
 #ifdef KMESSDEBUG_CHATMASTER
       else
       {
-        kDebug() << "Chat window is closing, suppressing message.";
+        kmDebug() << "Chat window is closing, suppressing message.";
       }
 #endif
 
@@ -916,13 +916,13 @@ void ChatMaster::showSpecialMessage( const ChatMessage &message, const MsnSwitch
     case ChatMessage::CONTENT_NOTIFICATION_WINK:
     case ChatMessage::CONTENT_APP_INVITE:
 #ifdef KMESSDEBUG_CHATMASTER
-      kDebug() << "Message is important, delivering it.";
+      kmDebug() << "Message is important, delivering it.";
 #endif
       break;
 
     default:
 #ifdef KMESSDEBUG_CHATMASTER
-      kDebug() << "Message is not important, will be ignored.";
+      kmDebug() << "Message is not important, will be ignored.";
 #endif
       return;
   }
@@ -938,7 +938,7 @@ void ChatMaster::showSpecialMessage( const ChatMessage &message, const MsnSwitch
     if( switchboard == 0 )
     {
 #ifdef KMESSDEBUG_CHATMASTER
-      kDebug() << "Could not create an offline switchboard.";
+      kmDebug() << "Could not create an offline switchboard.";
 #endif
       return;
     }
@@ -949,7 +949,7 @@ void ChatMaster::showSpecialMessage( const ChatMessage &message, const MsnSwitch
   if( chat == 0 )
   {
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "Could not create a chat window.";
+    kmDebug() << "Could not create a chat window.";
 #endif
     return;
   }
@@ -1013,7 +1013,7 @@ void ChatMaster::showMsnObject( const QString &handle, const MsnObject &msnObjec
       // handle background transfers
 
     default:
-      kWarning() << "Unable to handle MsnObject pictures of type '" << msnObject.getType() << "'.";
+      kmWarning() << "Unable to handle MsnObject pictures of type '" << msnObject.getType() << "'.";
   }
 }
 
@@ -1041,7 +1041,7 @@ void ChatMaster::slotContactChangedMsnObject( Contact *contact )
   {
     contact->getExtension()->setContactPicturePath( currentAccount_->getPicturePath() );
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "Updated user's own display picture";
+    kmDebug() << "Updated user's own display picture";
 #endif
     return;
   }
@@ -1052,7 +1052,7 @@ void ChatMaster::slotContactChangedMsnObject( Contact *contact )
   if( contact->getMsnObject() == 0 )
   {
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "Contact '" << handle << "' removed its MSN object";
+    kmDebug() << "Contact '" << handle << "' removed its MSN object";
 #endif
 
     contact->getExtension()->setContactPicturePath( QString::null );
@@ -1069,7 +1069,7 @@ void ChatMaster::slotContactChangedMsnObject( Contact *contact )
     if( ! imageInvalid && msnObject.verifyFile( objectFileName ) )
     {
 #ifdef KMESSDEBUG_CHATMASTER
-      kDebug() << "Picture for '" << handle << "' is already downloaded.";
+      kmDebug() << "Picture for '" << handle << "' is already downloaded.";
 #endif
 
       contact->getExtension()->setContactPicturePath( objectFileName );
@@ -1078,7 +1078,7 @@ void ChatMaster::slotContactChangedMsnObject( Contact *contact )
     else
     {
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "Picture for '" << handle
+    kmDebug() << "Picture for '" << handle
               << "' is already downloaded, but corrupt "
               << ( imageInvalid ? "(detected by QImageReader)" : "(detected by MsnObject)" )
               << ", deleting it: '" << objectFileName << "'" << endl;
@@ -1089,7 +1089,7 @@ void ChatMaster::slotContactChangedMsnObject( Contact *contact )
       if( contact->getExtension()->getContactPicturePath() == objectFileName )
       {
 #ifdef KMESSDEBUG_CHATMASTER
-        kWarning() << "Corrupt picture was already set, "
+        kmWarning() << "Corrupt picture was already set, "
                     << "resetting contact picture." << endl;
 #endif
         contact->getExtension()->setContactPicturePath( QString::null );
@@ -1103,7 +1103,7 @@ void ChatMaster::slotContactChangedMsnObject( Contact *contact )
   if( switchboard != 0 )
   {
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "Contact '" << handle << "' changed its MSN object.";
+    kmDebug() << "Contact '" << handle << "' changed its MSN object.";
 #endif
 
     // Automatically decides which switchboard is the best to use,
@@ -1118,7 +1118,7 @@ void ChatMaster::slotContactChangedMsnObject( Contact *contact )
   // since that may change between this point and the timedUpdate() call.
 
 #ifdef KMESSDEBUG_CHATMASTER
-  kDebug() << "Contact '" << handle << "' changed its MSN object, queueing a request for it.";
+  kmDebug() << "Contact '" << handle << "' changed its MSN object, queueing a request for it.";
 #endif
 
   // Request the contact's msnobject
@@ -1147,13 +1147,13 @@ void ChatMaster::slotContactJoinedChat( ContactBase *contact )
     {
       // Contact joined chat conversation with multiple partipipants, ignore this.
 #ifdef KMESSDEBUG_CHATMASTER
-      kDebug() << "Contact '" << handle << "' joined multi-chat, not sending pending messages.";
+      kmDebug() << "Contact '" << handle << "' joined multi-chat, not sending pending messages.";
 #endif
     }
     else
     {
 #ifdef KMESSDEBUG_CHATMASTER
-      kDebug() << "Contact '" << handle << "' joined chat, checking for pending messages.";
+      kmDebug() << "Contact '" << handle << "' joined chat, checking for pending messages.";
 #endif
 
       // Send the messages
@@ -1185,7 +1185,7 @@ void ChatMaster::slotContactJoinedChat( ContactBase *contact )
 void ChatMaster::slotDeliverAppCommand(QString cookie, QString handle, QString command)
 {
 #ifdef KMESSDEBUG_CHATMASTER
-  kDebug() << "Delivering application command.";
+  kmDebug() << "Delivering application command.";
 #endif
 
   Application *app = 0;
@@ -1203,7 +1203,7 @@ void ChatMaster::slotDeliverAppCommand(QString cookie, QString handle, QString c
   // App not found.
   if( app == 0 )
   {
-    kWarning() << "Application not found to deliver user command (contact=" << contact << ", command=" << command << ").";
+    kmWarning() << "Application not found to deliver user command (contact=" << contact << ", command=" << command << ").";
     return;
   }
 
@@ -1231,7 +1231,7 @@ void ChatMaster::slotDeliverAppCommand(QString cookie, QString handle, QString c
 void ChatMaster::slotDeliverMimeMessage(const MimeMessage &message, const QString &handle, bool privateChatRequired)
 {
 #ifdef KMESSDEBUG_CHATMASTER
-  kDebug() << "Delivering application message for '" << handle << "' to switchboard.";
+  kmDebug() << "Delivering application message for '" << handle << "' to switchboard.";
 #endif
 #ifdef KMESSTEST
   QString contentType( message.getValue("Content-Type") );
@@ -1252,7 +1252,7 @@ void ChatMaster::slotDeliverMimeMessage(const MimeMessage &message, const QStrin
     {
       // Connection has unacked messages, keep waiting until the switchboard is ready to send
 #ifdef KMESSDEBUG_CHATMASTER
-      kDebug() << "Switchboard is currently busy, queueing message until the switchboard is ready to send.";
+      kmDebug() << "Switchboard is currently busy, queueing message until the switchboard is ready to send.";
 #endif
       queueMessage( message, handle, privateChatRequired );
 
@@ -1272,7 +1272,7 @@ void ChatMaster::slotDeliverMimeMessage(const MimeMessage &message, const QStrin
   else
   {
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "No switchboard available to deliver message,"
+    kmDebug() << "No switchboard available to deliver message,"
               << " requesting chat and queueing message " << (pendingMimeMessages_.count() + 1) << "." << endl;
 #endif
 
@@ -1289,8 +1289,8 @@ void ChatMaster::slotGotInkMessage( const QString &ink, const QString &contactHa
 #ifdef KMESSDEBUG_SWITCHBOARD_GENERAL
   switch( format )
   {
-    case FORMAT_ISF: kDebug() << "Parsing ISF ink message"; break;
-    case FORMAT_GIF: kDebug() << "Parsing GIF ink message"; break;
+    case FORMAT_ISF: kmDebug() << "Parsing ISF ink message"; break;
+    case FORMAT_GIF: kmDebug() << "Parsing GIF ink message"; break;
   }
 #endif
 
@@ -1328,8 +1328,8 @@ void ChatMaster::slotGotInkMessage( const QString &ink, const QString &contactHa
   QRegExp inkChars( "([^A-Za-z0-9:+/=])" );
   if( ! inkData.startsWith( "base64:" ) || inkChars.indexIn( inkData ) != -1 )
   {
-    kWarning() << "Received invalid ink message from" << contactHandle << ", found char 0x" << QString::number( inkChars.cap(1)[0].unicode(), 16 ) << "at position" << inkChars.pos(1);
-    kWarning() << "Ink data dump:" << inkData;
+    kmWarning() << "Received invalid ink message from" << contactHandle << ", found char 0x" << QString::number( inkChars.cap(1)[0].unicode(), 16 ) << "at position" << inkChars.pos(1);
+    kmWarning() << "Ink data dump:" << inkData;
 
     showSpecialMessage( ChatMessage( ChatMessage::TYPE_SYSTEM,
                                      ChatMessage::CONTENT_SYSTEM_ERROR,
@@ -1464,7 +1464,7 @@ void ChatMaster::slotGotMsnObject(const QString &msnObjectData, const QString &h
 void ChatMaster::slotMsnObjectReceived(const QString &handle, const MsnObject &msnObject)
 {
 #ifdef KMESSDEBUG_CHATMASTER
-  kDebug() << "Received msn object from: " << handle << ".";
+  kmDebug() << "Received msn object from: " << handle << ".";
 #endif
 
   Chat *chat = 0;
@@ -1477,7 +1477,7 @@ void ChatMaster::slotMsnObjectReceived(const QString &handle, const MsnObject &m
     if( chat != 0 && ! chats_.contains( chat ) )
     {
 #ifdef KMESSDEBUG_CHATMASTER
-      kDebug() << "Original chat not found for received MSNObject "
+      kmDebug() << "Original chat not found for received MSNObject "
                 << "(objecttype=" << msnObject.getType()
                 << " contact="    << handle << ")." << endl;
 #endif
@@ -1497,7 +1497,7 @@ void ChatMaster::slotSwitchboardReady()
   if( pendingMimeMessages_.isEmpty() )
   {
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "A switchboard is ready to send more messages, no messages pending.";
+    kmDebug() << "A switchboard is ready to send more messages, no messages pending.";
 #endif
     return;
   }
@@ -1511,7 +1511,7 @@ void ChatMaster::slotSwitchboardReady()
   bool isPrivateChat          = (contacts.size() < 2);
 
 #ifdef KMESSDEBUG_CHATMASTER
-  kDebug() << "A switchboard is ready to send more messages, " << pendingMimeMessages_.count() << " messages pending.";
+  kmDebug() << "A switchboard is ready to send more messages, " << pendingMimeMessages_.count() << " messages pending.";
 #endif
 
   // Send all pending messages
@@ -1523,7 +1523,7 @@ void ChatMaster::slotSwitchboardReady()
   if( ! pendingMimeMessages_.isEmpty() )
   {
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "Switchboard is busy again, not notifying applications.";
+    kmDebug() << "Switchboard is busy again, not notifying applications.";
 #endif
     return;
   }
@@ -1597,7 +1597,7 @@ MsnSwitchboardConnection *ChatMaster::startSwitchboard( const ChatInformation &c
   const QString &handle = chatInfo.getContactHandle();
 
 #ifdef KMESSDEBUG_CHATMASTER
-  kDebug() << "Starting new switchboard session with" << handle;
+  kmDebug() << "Starting new switchboard session with" << handle;
 #endif
 
   /**
@@ -1614,7 +1614,7 @@ MsnSwitchboardConnection *ChatMaster::startSwitchboard( const ChatInformation &c
   if( chatInfo.getType() == ChatInformation::CONNECTION_REFRESH )
   {
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "Finding the session to refresh.";
+    kmDebug() << "Finding the session to refresh.";
 #endif
     foreach( MsnSwitchboardConnection *currentSwitchboard, switchboardConnections_ )
     {
@@ -1622,7 +1622,7 @@ MsnSwitchboardConnection *ChatMaster::startSwitchboard( const ChatInformation &c
       &&  currentSwitchboard->isWaiting() )
       {
 #ifdef KMESSDEBUG_CHATMASTER
-        kDebug() << "Session found, it will be refreshed.";
+        kmDebug() << "Session found, it will be refreshed.";
 #endif
         switchboard = currentSwitchboard;
         break;
@@ -1631,7 +1631,7 @@ MsnSwitchboardConnection *ChatMaster::startSwitchboard( const ChatInformation &c
 
     if( switchboard == 0 )
     {
-      kWarning() << "Unable to find which session requested a refresh.";
+      kmWarning() << "Unable to find which session requested a refresh.";
       return 0;
     }
   }
@@ -1640,7 +1640,7 @@ MsnSwitchboardConnection *ChatMaster::startSwitchboard( const ChatInformation &c
     switchboard = createSwitchboardConnection();
     if( KMESS_NULL(switchboard) ) return 0;
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "Creating new session.";
+    kmDebug() << "Creating new session.";
 #endif
   }
 
@@ -1697,7 +1697,7 @@ Chat *ChatMaster::createChat( MsnSwitchboardConnection *switchboard, bool reques
   if( newChat != 0 )
   {
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "A chat with contacts"
+    kmDebug() << "A chat with contacts"
               << switchboard->getContactsInChat().join(",") << "already exists, raising it." << endl;
 #endif
 
@@ -1724,14 +1724,14 @@ Chat *ChatMaster::createChat( MsnSwitchboardConnection *switchboard, bool reques
 
   if( newChat == 0 )
   {
-    kDebug() << "Couldn't create a new chat tab.";
+    kmDebug() << "Couldn't create a new chat tab.";
     return 0;
   }
 
   // Initialize it
   if( ! newChat->initialize( switchboard ) )
   {
-    kDebug() << "Couldn't initialize the chat tab.";
+    kmDebug() << "Couldn't initialize the chat tab.";
     return 0;
   }
 
@@ -1742,7 +1742,7 @@ Chat *ChatMaster::createChat( MsnSwitchboardConnection *switchboard, bool reques
   newChat = newChatWindow->addChatTab( newChat, switchboard->getUserStartedChat() );
   if( newChat == 0 )
   {
-    kWarning() << "Couldn't add the initial chat.";
+    kmWarning() << "Couldn't add the initial chat.";
     return 0;
   }
 
@@ -1799,7 +1799,7 @@ ChatWindow *ChatMaster::createChatWindow( Chat *chat )
 
   // Create the new chat window
 #ifdef KMESSDEBUG_CHATMASTER
-  kDebug() << "No existing chat window, creating new.";
+  kmDebug() << "No existing chat window, creating new.";
 #endif
   // Create the window: it should have no parent, so it will be displayed in the taskbar for Windows.
   window = new ChatWindow();
@@ -1807,7 +1807,7 @@ ChatWindow *ChatMaster::createChatWindow( Chat *chat )
   // Bail out if the window could not be initialized
   if( ! window->initialize() )
   {
-    kWarning() << "Couldn't initialize the new chat window!";
+    kmWarning() << "Couldn't initialize the new chat window!";
     return 0;
   }
 
@@ -1831,7 +1831,7 @@ MsnSwitchboardConnection *ChatMaster::createSwitchboardConnection( MsnSwitchboar
   MsnSwitchboardConnection *switchboard;
 
 #ifdef KMESSDEBUG_CHATMASTER
-  kDebug() << "Creating a new switchboard connection.";
+  kmDebug() << "Creating a new switchboard connection.";
 #endif
 
   // Initialize the switchboard connection
@@ -1845,7 +1845,7 @@ MsnSwitchboardConnection *ChatMaster::createSwitchboardConnection( MsnSwitchboar
   }
   if( ! switchboard || ! switchboard->initialize( handle ) )
   {
-    kWarning() << "Couldn't initialize switchboard connection.";
+    kmWarning() << "Couldn't initialize switchboard connection.";
     delete switchboard;
     return 0;
   }
@@ -1890,7 +1890,7 @@ void ChatMaster::startFileTransfer( const QString &handle, const QString &filena
   MsnSwitchboardConnection *connection = getContactSwitchboardConnection( handle, true );
   if( ! connection || ( contact && contact->isOffline() && connection->isInactive() ) )
   {
-//     kWarning() << "Attempted to start a file transfer with an offline contact!";
+//     kmWarning() << "Attempted to start a file transfer with an offline contact!";
     return;
   }
 
@@ -1899,11 +1899,11 @@ void ChatMaster::startFileTransfer( const QString &handle, const QString &filena
     // This should be so rare that it justifies a warning message.
     if( contact == 0 )
     {
-      kWarning() << "Contact" << handle << "object not found, using old MIME invitations because P2P might not be supported.";
+      kmWarning() << "Contact" << handle << "object not found, using old MIME invitations because P2P might not be supported.";
     }
     else
     {
-      kWarning() << "Contact" << handle << "does not support P2P transfers, using old MIME invitations instead.";
+      kmWarning() << "Contact" << handle << "does not support P2P transfers, using old MIME invitations instead.";
     }
 
     // The contact only supports file transfer the old way
@@ -1913,7 +1913,7 @@ void ChatMaster::startFileTransfer( const QString &handle, const QString &filena
   }
 
 #if CHATMASTER_SEND_FILES_MSNFTP
-  kWarning() << "Sending files is forced over MSNFTP for debugging, using old MIME invitations.";
+  kmWarning() << "Sending files is forced over MSNFTP for debugging, using old MIME invitations.";
   MimeApplication *app = new FileTransfer(handle, filename);
   startApplication(app);
 #else
@@ -1958,7 +1958,7 @@ void ChatMaster::startMsnObjectDownload( const QString &handle, const MsnObject
   if( appList->hasMsnObjectTransfer(*msnObject) )
   {
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "object is already being downloaded, not sending a second invite.";
+    kmDebug() << "object is already being downloaded, not sending a second invite.";
 #endif
     return;
   }
@@ -1974,7 +1974,7 @@ void ChatMaster::startMsnObjectDownload( const QString &handle, const MsnObject
     if( imageCorrupt || ! msnObject->verifyFile( objectFileName ) )
     {
 #ifdef KMESSDEBUG_CHATMASTER
-      kDebug() << "Cached MsnObject is corrupt "
+      kmDebug() << "Cached MsnObject is corrupt "
                 << ( imageCorrupt ? "(detected by QImage)" : "(detected by MsnObject)" )
                 << ", deleting it: '" << objectFileName << "'" << endl;
 #endif
@@ -1987,7 +1987,7 @@ void ChatMaster::startMsnObjectDownload( const QString &handle, const MsnObject
   if( fileExists )
   {
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "Contact MsnObject is already in cache.";
+    kmDebug() << "Contact MsnObject is already in cache.";
 #endif
 
     // Already have it, handle processing in a generic way.
@@ -1997,7 +1997,7 @@ void ChatMaster::startMsnObjectDownload( const QString &handle, const MsnObject
   else
   {
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "Starting MsnObject download (type=" << msnObject->getType() << ").";
+    kmDebug() << "Starting MsnObject download (type=" << msnObject->getType() << ").";
 #endif
 
     // Create and initialize the application.
@@ -2029,7 +2029,7 @@ void ChatMaster::timedUpdate()
   }
 
 #ifdef KMESSDEBUG_CHATMASTER
-  kDebug() << "handling timed events.";
+  kmDebug() << "handling timed events.";
 #endif
 
   // See if there are pictures to download.
@@ -2043,7 +2043,7 @@ void ChatMaster::timedUpdate()
     pendingDisplayPictures_.removeAll( handle );
 
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "see if the display picture of '" << handle << "' should  be downloaded.";
+    kmDebug() << "see if the display picture of '" << handle << "' should  be downloaded.";
 #endif
 
     // See if the picture was already downloaded somehow (e.g. user opened a chat)
@@ -2054,7 +2054,7 @@ void ChatMaster::timedUpdate()
     if( contact == 0 )
     {
 #ifdef KMESSDEBUG_CHATMASTER
-      kDebug() << "contact not found, was it removed?";
+      kmDebug() << "contact not found, was it removed?";
 #endif
       continue;
     }
@@ -2063,7 +2063,7 @@ void ChatMaster::timedUpdate()
     if( contact->isOffline() )
     {
 #ifdef KMESSDEBUG_CHATMASTER
-      kDebug() << "contact is no longer online.";
+      kmDebug() << "contact is no longer online.";
 #endif
       continue;
     }
@@ -2073,7 +2073,7 @@ void ChatMaster::timedUpdate()
     if( contact->isBlocked() )
     {
 #ifdef KMESSDEBUG_CHATMASTER
-      kDebug() << "contact is blocked.";
+      kmDebug() << "contact is blocked.";
 #endif
       continue;
     }
@@ -2083,7 +2083,7 @@ void ChatMaster::timedUpdate()
     if( msnObject == 0 )
     {
 #ifdef KMESSDEBUG_CHATMASTER
-      kDebug() << "MsnObject has been reset.";
+      kmDebug() << "MsnObject has been reset.";
 #endif
       continue;
     }
@@ -2095,7 +2095,7 @@ void ChatMaster::timedUpdate()
     &&  msnObject->verifyFile( objectFileName ) )
     {
 #ifdef KMESSDEBUG_CHATMASTER
-      kDebug() << "Picture is already downloaded.";
+      kmDebug() << "Picture is already downloaded.";
 #endif
       continue;
     }
@@ -2109,7 +2109,7 @@ void ChatMaster::timedUpdate()
     // Made the debug output easier to understand.
     if( ! contact->hasApplicationList() )
     {
-      kDebug() << "Picture is not available, creating application list.";
+      kmDebug() << "Picture is not available, creating application list.";
     }
 #endif
 
@@ -2121,7 +2121,7 @@ void ChatMaster::timedUpdate()
     if( appList->hasMsnObjectTransfer( *msnObject ) )
     {
 #ifdef KMESSDEBUG_CHATMASTER
-      kDebug() << "transfer for the picture is already active.";
+      kmDebug() << "transfer for the picture is already active.";
 #endif
       continue;
     }
@@ -2131,7 +2131,7 @@ void ChatMaster::timedUpdate()
     // Download the picture.
 
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "Picture is not available, starting switchboard connection to download it.";
+    kmDebug() << "Picture is not available, starting switchboard connection to download it.";
 #endif
 
     // Start a chat to download the picture.
@@ -2149,20 +2149,20 @@ void ChatMaster::updateChatGrouping()
   if( currentAccount_->getTabbedChatMode() == chatTabbedMode_ )
   {
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "Chat grouping mode not changed, nothing to update";
+    kmDebug() << "Chat grouping mode not changed, nothing to update";
 #endif
     return;
   }
 
 #ifdef KMESSDEBUG_CHATMASTER
-  kDebug() << "Updating Chat grouping";
+  kmDebug() << "Updating Chat grouping";
 #endif
   chatTabbedMode_ = currentAccount_->getTabbedChatMode();
 
   if( chatWindows_.empty() )
   {
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "No ChatWindows, nothing to update";
+    kmDebug() << "No ChatWindows, nothing to update";
 #endif
     return;
   }
@@ -2178,7 +2178,7 @@ void ChatMaster::updateChatGrouping()
     if( window == 0)
     {
 #ifdef KMESSDEBUG_CHATMASTER
-      kDebug() << "No suited window found for chat" << chat;
+      kmDebug() << "No suited window found for chat" << chat;
 #endif
 
       ChatWindow* newChatWindow = createChatWindow( chat);
@@ -2192,7 +2192,7 @@ void ChatMaster::updateChatGrouping()
     else if( window != currentWindow )
     {
 #ifdef KMESSDEBUG_CHATMASTER
-      kDebug() << "Moving chat" << chat << "to other window" << window;
+      kmDebug() << "Moving chat" << chat << "to other window" << window;
 #endif
 
       window->addChatTab( chat, false );
@@ -2216,7 +2216,7 @@ ChatWindow *ChatMaster::findWindowForChat( Chat *chat )
   if( ! chatWindows_.empty() )
   {
 #ifdef KMESSDEBUG_CHATMASTER
-    kDebug() << "At least one chat window is already open: checking the tabbed chatting settings.";
+    kmDebug() << "At least one chat window is already open: checking the tabbed chatting settings.";
 #endif
 
     if( currentAccount->getTabbedChatMode() == 0 ) // Always group in tabs
@@ -2224,13 +2224,13 @@ ChatWindow *ChatMaster::findWindowForChat( Chat *chat )
       // Pick the last open chat window
       window = chatWindows_.last();
 #ifdef KMESSDEBUG_CHATMASTER
-      kDebug() << "Always group in tabs. Picking the last created window.";
+      kmDebug() << "Always group in tabs. Picking the last created window.";
 #endif
     }
     else if( currentAccount->getTabbedChatMode() == 1 ) // Group tabs by initial contact's group
     {
 #ifdef KMESSDEBUG_CHATMASTER
-      kDebug() << "Group in tabs by contact group. Choosing a window.";
+      kmDebug() << "Group in tabs by contact group. Choosing a window.";
 #endif
       QString handle( chat->getSwitchboardConnection()->getFirstContact() );
       Contact *contact = currentAccount->getContactList()->getContactByHandle( handle );
@@ -2239,7 +2239,7 @@ ChatWindow *ChatMaster::findWindowForChat( Chat *chat )
       {
         QString group( contact->getGroupIds().first() );
 #ifdef KMESSDEBUG_CHATMASTER
-        kDebug() << "Searching chats for one whose first contact is in the same group as the new one's.";
+        kmDebug() << "Searching chats for one whose first contact is in the same group as the new one's.";
 #endif
         foreach( Chat *chatItem, chats_ )
         {
@@ -2250,7 +2250,7 @@ ChatWindow *ChatMaster::findWindowForChat( Chat *chat )
           && contact->getGroupIds().first() == group )
           {
 #ifdef KMESSDEBUG_CHATMASTER
-            kDebug() << "Match found!";
+            kmDebug() << "Match found!";
 #endif
             window = chatItem->getChatWindow();
 
