@@ -65,6 +65,8 @@ ChatMessageView::ChatMessageView( QWidget *parentWidget, QObject *parent )
   // Connect signals for browsing
   connect( browserExtension(), SIGNAL(  openUrlRequestDelayed(const KUrl&,const KParts::OpenUrlArguments&,const KParts::BrowserArguments&) ),
            this,               SIGNAL(         openUrlRequest(const KUrl&) ) );
+  connect( this,               SIGNAL(              completed()            ),
+           this,               SLOT  (     scrollChatToBottom()            ) );
 
   // Make sure this widget can't get any focus.
   view()->setFocusPolicy( Qt::NoFocus );
@@ -112,7 +114,7 @@ ChatMessageView::~ChatMessageView()
 void ChatMessageView::addedEmoticon( QString shortcut )
 {
 #ifdef KMESSDEBUG_CHATMESSAGEVIEW
-  kDebug() << "Replacing add emoticon links with shortcut '" << shortcut << "'.";
+  kmDebug() << "Replacing add emoticon links with shortcut '" << shortcut << "'.";
 #endif
 
   // The shortcut in emoticon links is url-encoded, convert the original one to match it
@@ -137,7 +139,7 @@ void ChatMessageView::addedEmoticon( QString shortcut )
     if( link.isNull() || ! link.isHTMLElement() )
     {
 #ifdef KMESSDEBUG_CHATMESSAGEVIEW
-      kDebug() << "Link null, skipping.";
+      kmDebug() << "Link null, skipping.";
 #endif
       continue;
     }
@@ -149,7 +151,7 @@ void ChatMessageView::addedEmoticon( QString shortcut )
     if( parent.isNull() )
     {
 #ifdef KMESSDEBUG_CHATMESSAGEVIEW
-      kDebug() << "Parent null, skipping.";
+      kmDebug() << "Parent null, skipping.";
 #endif
       continue;
     }
@@ -157,7 +159,7 @@ void ChatMessageView::addedEmoticon( QString shortcut )
     if( image.isNull() )
     {
 #ifdef KMESSDEBUG_CHATMESSAGEVIEW
-      kDebug() << "Image null, skipping.";
+      kmDebug() << "Image null, skipping.";
 #endif
       continue;
     }
@@ -166,6 +168,23 @@ void ChatMessageView::addedEmoticon( QString shortcut )
   }
 }
 
+void ChatMessageView::addXml( QString xmlString )
+{
+  // Create new HTML node
+  DOM::HTMLElement newNode = document().createElement( "div" );
+  newNode.setInnerHTML( chatStyle_->convertXmlMessageList( xmlString ) );
+
+  DOM::HTMLElement messageRoot = htmlDocument().getElementById( "messageRoot" );
+  if( messageRoot.isNull() )
+  {
+    messageRoot = htmlDocument().body();
+  }
+  messageRoot.appendChild( document().createTextNode("\n") );
+  messageRoot.appendChild( newNode );
+  messageRoot.appendChild( document().createTextNode("\n") );
+
+  isEmpty_ = false;
+}
 
 
 // Add the given html to the chat browser and scroll to the end
@@ -224,6 +243,11 @@ void ChatMessageView::clearView( bool clearHistory )
 // Return the HTML source of the page.
 QString ChatMessageView::getHistory( Account::ChatExportFormat format, bool append, QString &appendPoint )
 {
+  if( chatMessages_.isEmpty() )
+  {
+    return QString();
+  }
+
   QString chatHistory;
   QString handle( chatMessages_.first()->getContactHandle() );
   uint date  ( chatMessages_.first()->getDateTime().toTime_t() );
@@ -240,104 +264,6 @@ QString ChatMessageView::getHistory( Account::ChatExportFormat format, bool appe
 
   switch( format )
   {
-    case Account::EXPORT_XML:
-    {
-      // Convert every message in the history to XML
-      // TODO - Make this extremely slow process faster by caching the chat's XML.
-      QList<ChatMessage*> groupedMessages;
-      QListIterator<ChatMessage*> it( chatMessages_ );
-
-      while( it.hasNext() )
-      {
-        ChatMessage *chatMessage = it.next();
-
-        // Chat messages from the same person are always grouped together
-        if( chatMessage->isNormalMessage() )
-        {
-          if( groupedMessages.isEmpty() )
-          {
-            groupedMessages.append( chatMessage );
-            continue;
-          }
-
-          ChatMessage *lastContactMessage = groupedMessages.last();
-
-          // Check for contact handle and message type, so offline messages won't be
-          // grouped with normal incoming messages.
-          if( lastContactMessage->getContactHandle() == chatMessage->getContactHandle()
-          &&  lastContactMessage->getType()          == chatMessage->getType() )
-          {
-            groupedMessages.append( chatMessage );
-            continue;
-          }
-        }
-
-        // There are messages to flush
-        if( ! groupedMessages.isEmpty() )
-        {
-          // Do not add message groups with only one message
-          if( groupedMessages.count() > 1 )
-          {
-            chatHistory += "<messagegroup>\n";
-            foreach( ChatMessage *groupMessage, groupedMessages )
-            {
-              chatHistory += chatStyle_->convertMessageToXml( *groupMessage, true );
-            }
-            chatHistory += "</messagegroup>\n";
-          }
-          else
-          {
-            chatHistory += chatStyle_->convertMessageToXml( *( groupedMessages.first() ), true );
-          }
-            groupedMessages.clear();
-        }
-
-        // All chat messages are grouped, special messages never are
-        if( chatMessage->isNormalMessage() )
-        {
-          groupedMessages.append( chatMessage );
-        }
-        else
-        {
-          chatHistory += chatStyle_->convertMessageToXml( *chatMessage, true );
-        }
-      }
-
-      // Flush the last group of messages, if any
-      if( ! groupedMessages.isEmpty() )
-      {
-        chatHistory += "<messagegroup>\n";
-        foreach( ChatMessage *groupMessage, groupedMessages )
-        {
-          chatHistory += chatStyle_->convertMessageToXml( *groupMessage, true );
-        }
-        chatHistory += "</messagegroup>\n";
-      }
-
-      chatHistory = "\n<conversation timestamp=\"" + QString::number( date ) + "\">\n" + chatHistory + "</conversation>\n";
-
-      // we've changed it at line 2 of this method.
-      // we MUST change it back here otherwise the style tag written 
-      // below could be incorrect!
-      chatStyle_->setAllowEmoticonLinks( oldAllowEmoticonLinks );
-
-      if( append )
-      {
-        // Tell the caller where this chat should be inserted
-        appendPoint = "</messageRoot>";
-
-        return chatHistory;
-      }
-
-      // Not appending: also add a root element to the history
-      return "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n"
-             "<?xml-stylesheet type=\"text/xsl\" href=\"file://" + chatStyle_->getStyleSheet() + "\" media=\"all\" ?>\n"
-             "<!-- " + getStyleTag() + " -->\n"
-             "<messageRoot xmlns:xsl=\"http://www.w3.org/1999/XSL/Transform\">\n"
-             + chatHistory +
-             "\n</messageRoot>\n";
-    }
-
     case Account::EXPORT_HTML:
     {
       chatHistory += "\n<div class=\"conversation\">"
@@ -369,7 +295,7 @@ QString ChatMessageView::getHistory( Account::ChatExportFormat format, bool appe
       DOM::HTMLElement messageRoot( copy.getElementById( "messageRoot" ) );
       if( messageRoot.isNull() )
       {
-        kWarning() << "Current style does not define the 'messageRoot' element!";
+        kmWarning() << "Current style does not define the 'messageRoot' element!";
         chatStyle_->setAllowEmoticonLinks( oldAllowEmoticonLinks );
         return chatHistory;
       }
@@ -438,7 +364,7 @@ QString ChatMessageView::getHistory( Account::ChatExportFormat format, bool appe
     }
 
     default:
-      kWarning() << "Invalid export format: code" << format;
+      kmWarning() << "Invalid export format: code" << format;
       break;
   }
 
@@ -575,7 +501,7 @@ QString ChatMessageView::rebuildHistory( bool fullHistory )
 void ChatMessageView::removeCustomEmoticon( const QString &shortcut )
 {
 #ifdef KMESSDEBUG_CHATMESSAGEVIEW
-  kDebug() << "Deleting emoticons with shortcut:" << shortcut;
+  kmDebug() << "Deleting emoticons with shortcut:" << shortcut;
 #endif
 #ifdef KMESSTEST
   KMESS_ASSERT( ! shortcut.isEmpty() );
@@ -611,7 +537,7 @@ void ChatMessageView::removeCustomEmoticon( const QString &shortcut )
     if( img.isNull() )
     {
 #ifdef KMESSDEBUG_CHATMESSAGEVIEW
-      kDebug() << "Skipped null element.";
+      kmDebug() << "Skipped null element.";
 #endif
       continue;
     }
@@ -622,7 +548,7 @@ void ChatMessageView::removeCustomEmoticon( const QString &shortcut )
     if( altAttribute != shortcut && altAttribute != originalShortcut )
     {
 #ifdef KMESSDEBUG_CHATMESSAGEVIEW
-      kDebug() << "Skipped element:" << img.getAttribute("alt").string() << "while searching for" << originalShortcut;
+      kmDebug() << "Skipped element:" << img.getAttribute("alt").string() << "while searching for" << originalShortcut;
 #endif
       continue;
     }
@@ -659,7 +585,7 @@ void ChatMessageView::replaceLastMessage(const QString &text)
   DOM::HTMLElement lastNode( htmlDocument().getElementById( lastId ) );
   if( lastNode.isNull() || ! lastNode.isHTMLElement() )
   {
-    kWarning() << "message block with id" + lastId + "not found, appending message instead.";
+    kmWarning() << "message block with id" + lastId + "not found, appending message instead.";
     addHtmlMessage( text );
     return;
   }
@@ -678,8 +604,21 @@ void ChatMessageView::scrollChat( bool forward, bool fast )
 
 
 
-// Scroll to the bottom of the chat browser
+// Force scrolling to the bottom of the chat browser
 void ChatMessageView::scrollChatToBottom()
+{
+  int contentsHeight = view()->contentsHeight();
+  view()->scrollBy( 0, contentsHeight );
+
+#ifdef KMESSDEBUG_CHATMESSAGEVIEW
+  kmDebug() << "Scrolled view down.";
+#endif
+}
+
+
+
+// Scroll to the bottom of the chat browser if needed
+void ChatMessageView::scrollChatToBottomGently()
 {
   int contentsHeight = view()->contentsHeight();
   int visibleHeight = view()->visibleHeight();
@@ -691,6 +630,10 @@ void ChatMessageView::scrollChatToBottom()
   }
 
   view()->scrollBy( 0, contentsHeight );
+
+#ifdef KMESSDEBUG_CHATMESSAGEVIEW
+  kmDebug() << "Scrolled view down.";
+#endif
 }
 
 
@@ -768,7 +711,7 @@ void ChatMessageView::setHtml( const QString &newHtmlBody )
     DOM::HTMLElement messageRoot = document().getElementById( "messageRoot" );
     if( messageRoot.isNull() )
     {
-      kWarning() << "Chat style does not define the 'messageRoot' element!";
+      kmWarning() << "Chat style does not define the 'messageRoot' element!";
       messageRoot = htmlDocument().body();
     }
     messageRoot.setInnerHTML( "\n" + newHtmlBody + "\n" );
@@ -801,7 +744,7 @@ void ChatMessageView::showMessage( const ChatMessage &message )
     &&  lastChatMessage->getContactHandle() == message.getContactHandle() )
     {
 #ifdef KMESSDEBUG_CHATMESSAGEVIEW
-      kDebug() << "Not showing presence message for the same contact again.";
+      kmDebug() << "Not showing presence message for the same contact again.";
 #endif
       return;
     }
@@ -842,7 +785,7 @@ void ChatMessageView::showMessage( const ChatMessage &message )
   if( lastContactMessages_.count() > 1 )
   {
 #ifdef KMESSDEBUG_CHATMESSAGEVIEW
-    kDebug() << "replacing last contact message with new contents.";
+    kmDebug() << "replacing last contact message with new contents.";
 #endif
 
     messageHtml = chatStyle_->convertMessageList(lastContactMessages_);
@@ -851,7 +794,7 @@ void ChatMessageView::showMessage( const ChatMessage &message )
   else
   {
 #ifdef KMESSDEBUG_CHATMESSAGEVIEW
-    kDebug() << "appending new message.";
+    kmDebug() << "appending new message.";
 #endif
 
     messageHtml = chatStyle_->convertMessage( *chatMessage );
@@ -883,7 +826,7 @@ void ChatMessageView::showMessage( const ChatMessage &message )
 
   // Call the scroll function a bit later,
   // so Qt/kde get a chance to update the height before the scrolling starts.
-  QTimer::singleShot( 50, this, SLOT( scrollChatToBottom() ) );
+  QTimer::singleShot( 50, this, SLOT( scrollChatToBottomGently() ) );
 }
 
 
@@ -913,7 +856,7 @@ void ChatMessageView::updateApplicationMessage( const QString &messageId, const
 void ChatMessageView::updateChatStyle()
 {
 #ifdef KMESSDEBUG_CHATMESSAGEVIEW
-  kDebug() << "updating style.";
+  kmDebug() << "updating style.";
 #endif
 
   if(KMESS_NULL(chatStyle_))      return;
@@ -935,7 +878,7 @@ void ChatMessageView::updateChatStyle()
   &&  currentAccount_->getEmoticonStyle()         == chatStyle_->getEmoticonStyle() )
   {
 #ifdef KMESSDEBUG_CHATMESSAGEVIEW
-    kDebug() << "Update not needed.";
+    kmDebug() << "Update not needed.";
 #endif
     return;
   }
@@ -967,7 +910,7 @@ void ChatMessageView::updateChatStyle()
 
   // Call the scroll function a bit later,
   // so Qt/kde get a chance to update the height before the scrolling starts.
-  QTimer::singleShot( 50, this, SLOT( scrollChatToBottom() ) );
+  QTimer::singleShot( 50, this, SLOT( scrollChatToBottomGently() ) );
 }
 
 
@@ -977,7 +920,7 @@ void ChatMessageView::updateCustomEmoticon( const QString &code, const QString &
                                             const QString &handle )
 {
 #ifdef KMESSDEBUG_CHATMESSAGEVIEW
-  kDebug() << "Replacing emoticon '" << code << "' with '" << replacement << "' for '" << handle << "'";
+  kmDebug() << "Replacing emoticon '" << code << "' with '" << replacement << "' for '" << handle << "'";
 #endif
 #ifdef KMESSTEST
   KMESS_ASSERT( ! code.isEmpty() );
@@ -988,7 +931,7 @@ void ChatMessageView::updateCustomEmoticon( const QString &code, const QString &
   // Check for empty replacements.
   if( replacement.isEmpty() )
   {
-    kWarning() << "can't update custom emoticon, replacement not found (contact=" << handle << ").";
+    kmWarning() << "can't update custom emoticon, replacement not found (contact=" << handle << ").";
     return;
   }
 
@@ -1000,7 +943,7 @@ void ChatMessageView::updateCustomEmoticon( const QString &code, const QString &
   foreach( const QString &tag, pendingEmoticonTags_ )
   {
 #ifdef KMESSDEBUG_CHATMESSAGEVIEW
-    kDebug() << "Checking DOM element '" << tag << "'";
+    kmDebug() << "Checking DOM element '" << tag << "'";
 #endif
 
     // Check if the element is valid
@@ -1008,7 +951,7 @@ void ChatMessageView::updateCustomEmoticon( const QString &code, const QString &
     if( img.isNull() )
     {
 #ifdef KMESSDEBUG_CHATMESSAGEVIEW
-      kDebug() << "Skipped null element.";
+      kmDebug() << "Skipped null element.";
 #endif
       continue;
     }
@@ -1027,7 +970,7 @@ void ChatMessageView::updateCustomEmoticon( const QString &code, const QString &
     if( img.isNull() || imageAltText != code )
     {
 #ifdef KMESSDEBUG_CHATMESSAGEVIEW
-      kDebug() << "Skipped invalid element (searched '" << code << "', found '" << imageAltText << "').";
+      kmDebug() << "Skipped invalid element (searched '" << code << "', found '" << imageAltText << "').";
 #endif
       continue;
     }
@@ -1036,7 +979,7 @@ void ChatMessageView::updateCustomEmoticon( const QString &code, const QString &
     if( img.getAttribute("contact") != handle )
     {
 #ifdef KMESSDEBUG_CHATMESSAGEVIEW
-      kDebug() << "Emoticon code found, but different handle: " << img.getAttribute("contact");
+      kmDebug() << "Emoticon code found, but different handle: " << img.getAttribute("contact");
 #endif
       continue;
     }
@@ -1067,7 +1010,7 @@ void ChatMessageView::updateCustomEmoticon( const QString &code, const QString &
       }
 
 #ifdef KMESSDEBUG_CHATMESSAGEVIEW
-      kDebug() << "Emoticon replacement has attribute: " << attribRegExp.cap(1) << "=" << attribRegExp.cap(2);
+      kmDebug() << "Emoticon replacement has attribute: " << attribRegExp.cap(1) << "=" << attribRegExp.cap(2);
 #endif
       img.setAttribute( attribRegExp.cap(1), attribRegExp.cap(2) );
 
@@ -1084,7 +1027,7 @@ void ChatMessageView::updateCustomEmoticon( const QString &code, const QString &
     &&  ! customEmoticonsPattern.contains( code ) )
     {
 #ifdef KMESSDEBUG_CHATMESSAGEVIEW
-      kDebug() << "Inserting emoticon addition link";
+      kmDebug() << "Inserting emoticon addition link";
 #endif
       // Copy the original image to a new one we'll modify
       DOM::HTMLElement newImage = img.cloneNode( true );
@@ -1124,7 +1067,7 @@ void ChatMessageView::updateCustomEmoticon( const QString &code, const QString &
 // Creates the default actions for a popup menu. Copy, Select All and Find.
 // Attaches them to slots on this class.
 //
-// Users of this class can add their own entries to the popup menu by getting 
+// Users of this class can add their own entries to the popup menu by getting
 // the KMenu instance representing the popup using ChatMessageView::popupMenu().
 //
 void ChatMessageView::createPopupMenuActions()
