@@ -97,13 +97,19 @@ ChatView::ChatView( QWidget *parent )
 ChatView::~ChatView()
 {
   // Delete the related widgets
-  delete contactsWidget_;
   delete inkDrawing_;
   delete messageEditContents_;
 }
 
 
 
+// Parse and add the given XML string to the view
+void ChatView::addContents( const QString& xmlString )
+{
+  chatMessageView_->addXml( xmlString );
+}
+
+
 // Copy the currently selected text
 void ChatView::editCopy()
 {
@@ -135,7 +141,7 @@ bool ChatView::eventFilter( QObject *obj, QEvent *event )
       if( ! dragEvent )
       {
 #ifdef KMESSDEBUG_CHATVIEW
-          kDebug() << "Ignoring invalid drag event!";
+          kmDebug() << "Ignoring invalid drag event!";
 #endif
         return false;
       }
@@ -146,14 +152,14 @@ bool ChatView::eventFilter( QObject *obj, QEvent *event )
       ||  mimeData->hasFormat( "application/kmess.list.item" ) )
       {
 #ifdef KMESSDEBUG_CHATVIEW
-        kDebug() << "Accepting drag event of mimetypes:" << dragEvent->mimeData()->formats();
+        kmDebug() << "Accepting drag event of mimetypes:" << dragEvent->mimeData()->formats();
 #endif
         dragEvent->acceptProposedAction();
         return true;
       }
 
 #ifdef KMESSDEBUG_CHATVIEW
-      kDebug() << "Ignoring invalid drop having mimetypes:" << dragEvent->mimeData()->formats();
+      kmDebug() << "Ignoring invalid drop having mimetypes:" << dragEvent->mimeData()->formats();
 #endif
       break;
     }
@@ -167,7 +173,7 @@ bool ChatView::eventFilter( QObject *obj, QEvent *event )
       if( ! dropEvent || dropEvent->source() != 0 )
       {
 #ifdef KMESSDEBUG_CHATVIEW
-        kDebug() << "Ignoring invalid drop!";
+        kmDebug() << "Ignoring invalid drop!";
 #endif
         break;
       }
@@ -176,7 +182,7 @@ bool ChatView::eventFilter( QObject *obj, QEvent *event )
       if( mimeData->hasUrls() )
       {
 #ifdef KMESSDEBUG_CHATVIEW
-        kDebug() << "Drag'n'dropped files:" << mimeData->urls();
+        kmDebug() << "Drag'n'dropped files:" << mimeData->urls();
 #endif
 
         // Send the files to the contact
@@ -193,13 +199,13 @@ bool ChatView::eventFilter( QObject *obj, QEvent *event )
         if( image.isNull() )
         {
 #ifdef KMESSDEBUG_CHATVIEW
-          kDebug() << "Drag'n'dropped an invalid image!";
+          kmDebug() << "Drag'n'dropped an invalid image!";
 #endif
           return true;
         }
 
 #ifdef KMESSDEBUG_CHATVIEW
-        kDebug() << "Drag'n'dropped a" << image.size() << "image";
+        kmDebug() << "Drag'n'dropped a" << image.size() << "image";
 #endif
 
         // Create a temporary file where the image will be stored.
@@ -214,7 +220,7 @@ bool ChatView::eventFilter( QObject *obj, QEvent *event )
         if( ! file.open() )
         {
 #ifdef KMESSDEBUG_CHATVIEW
-          kDebug() << "Cannot create temporary image file!";
+          kmDebug() << "Cannot create temporary image file!";
 #endif
           return true;
         }
@@ -254,7 +260,7 @@ bool ChatView::eventFilter( QObject *obj, QEvent *event )
         if( ! handles.isEmpty() )
         {
 #ifdef KMESSDEBUG_CHATVIEW
-          kDebug() << "Drag'n'dropped addresses:" << handles;
+          kmDebug() << "Drag'n'dropped addresses:" << handles;
 #endif
           inviteContacts( handles );
           dropEvent->acceptProposedAction();
@@ -268,7 +274,7 @@ bool ChatView::eventFilter( QObject *obj, QEvent *event )
     // Ensure that the chat shows the same contents when resizing it
     case QEvent::Resize:
     {
-      chatMessageView_->scrollChatToBottom();
+      chatMessageView_->scrollChatToBottomGently();
       break;
     }
 
@@ -317,19 +323,19 @@ int ChatView::getZoomFactor()
 bool ChatView::initialize()
 {
 #ifdef KMESSDEBUG_CHATVIEW
-  kDebug() << "initializing.";
+  kmDebug() << "initializing.";
 #endif
 
   if ( initialized_ )
   {
-    kDebug() << "already initialized.";
+    kmDebug() << "already initialized.";
     return false;
   }
 
   currentAccount_ = CurrentAccount::instance();
   if ( currentAccount_ == 0 )
   {
-    kDebug() << "Couldn't get the instance of the current account.";
+    kmDebug() << "Couldn't get the instance of the current account.";
     return false;
   }
 
@@ -375,7 +381,7 @@ bool ChatView::isEmpty() const
 bool ChatView::saveChatToFile( const QString &path, Account::ChatExportFormat format, bool overwriteContents, bool allowUserInteraction )
 {
 #ifdef KMESSDEBUG_CHATVIEW
-  kDebug() << "saving chat to '" << path << "'.";
+  kmDebug() << "saving chat to '" << path << "'.";
 #endif
 
   // Find out if the file already exists
@@ -391,7 +397,7 @@ bool ChatView::saveChatToFile( const QString &path, Account::ChatExportFormat fo
     }
 
     QFileInfo info( file );
-    kWarning() << "File save failed! Could not open file" << path << ".";
+    kmWarning() << "File save failed! Could not open file" << path << ".";
     KMessageBox::sorry( chatMessageView_->view(), i18n( "Could not save chat log in directory '%1'.\n"
                                     "Make sure you have permission to write in "
                                     "the folder where logs are being saved.",
@@ -415,10 +421,9 @@ bool ChatView::saveChatToFile( const QString &path, Account::ChatExportFormat fo
     fileData = file.read( 512 );
     if( fileData.indexOf( chatMessageView_->getStyleTag() ) == -1 )
     {
-      kWarning() << "Style Tag not found in data:" << fileData << ", writing to a new file";
+      kmWarning() << "Style Tag not found in data:" << fileData << ", writing to a new file";
 
       // we return false, so the caller will write this data to a new file
-      // TODO: make *this* method decide where to write the data?
       return false;
     }
   }
@@ -426,15 +431,15 @@ bool ChatView::saveChatToFile( const QString &path, Account::ChatExportFormat fo
   QString chatHistory( chatMessageView_->getHistory( format, willAppend, appendPoint ) );
 
 #ifdef KMESSDEBUG_CHATVIEW
-  kDebug() << "Writing to file:" << file.fileName();
-  kDebug() << "Current file exists?" << isExistingFile << " allow overwriting?" << overwriteContents;
-  kDebug() << "Will append to current file?" << willAppend;
+  kmDebug() << "Writing to file:" << file.fileName();
+  kmDebug() << "Current file exists?" << isExistingFile << " allow overwriting?" << overwriteContents;
+  kmDebug() << "Will append to current file?" << willAppend;
 #endif
 
   if( willAppend )
   {
 #ifdef KMESSDEBUG_CHATVIEW
-    kDebug() << "Appending to existing chat file...";
+    kmDebug() << "Appending to existing chat file...";
 #endif
 
     const qint16 maxReadSize = 256;
@@ -444,11 +449,11 @@ bool ChatView::saveChatToFile( const QString &path, Account::ChatExportFormat fo
     fileData = file.read( maxReadSize );
     int pos = fileData.lastIndexOf( appendPoint );
 
-    // The append point was not found: we'll fallback to creating a new file
+    // The append point was not found!
     if( pos < 0 )
     {
 #ifdef KMESSDEBUG_CHATVIEW
-      kDebug() << "Append process failed, insertion string not found.";
+      kmDebug() << "Append process failed, insertion string not found.";
 #endif
       return false;
     }
@@ -462,7 +467,7 @@ bool ChatView::saveChatToFile( const QString &path, Account::ChatExportFormat fo
   else
   {
 #ifdef KMESSDEBUG_CHATVIEW
-    kDebug() << "Creating new chat file...";
+    kmDebug() << "Creating new chat file...";
 #endif
     file.resize( 0 ); // Truncate it (99% useless precaution)
   }
@@ -475,13 +480,14 @@ bool ChatView::saveChatToFile( const QString &path, Account::ChatExportFormat fo
   {
     textStream.setCodec( QTextCodec::codecForLocale() );
   }
-  // For HTML and XML logs (that are created with charset attribute to UTF-8) we use UTF-8 encoding
+  // For HTML logs (which are created with the UTF-8 charset) we use UTF-8 encoding
   else
   {
     textStream.setCodec( QTextCodec::codecForName("UTF-8") );
   }
 
   textStream << chatHistory;
+  textStream.flush();
   file.close();
 
   return true;
@@ -507,6 +513,14 @@ void ChatView::setEnabled( bool isEnabled )
 
 
 
+// Replace the message browser's contents with the given XML string.
+void ChatView::setContents( const QString& xmlString )
+{
+  chatMessageView_->setXml( xmlString );
+}
+
+
+
 // Set the zoom factor of the text
 void ChatView::setZoomFactor( int percentage )
 {
@@ -546,8 +560,7 @@ void ChatView::showSaveChatDialog()
     path = KFileDialog::getSaveFileName( path,
                                          i18nc( "Chat log saving dialog, file type filter",
                                                 "*.html *.htm|Web Page (*.html)\n"
-                                                "*.txt|Plain Text Document (*.txt)\n"
-                                                "*.xml|XML Document (*.xml)" ) );
+                                                "*.txt|Plain Text Document (*.txt)\n" ) );
 
     // Verify if the user has canceled the command
     if( path.isEmpty() )
@@ -577,10 +590,6 @@ void ChatView::showSaveChatDialog()
   {
     format = Account::EXPORT_HTML;
   }
-  else if( targetFile.suffix() == "xml" )
-  {
-    format = Account::EXPORT_XML;
-  }
   else
   {
     format = Account::EXPORT_TEXT;
@@ -601,14 +610,14 @@ void ChatView::slotAddContact()
   if( ! chatViewClickedUrl_.isValid() )
   {
 #ifdef KMESSDEBUG_CHATVIEW
-    kDebug() << "Not adding anything from invalid URL: " << email;
+    kmDebug() << "Not adding anything from invalid URL: " << email;
 #endif
 
     return;
   }
 
 #ifdef KMESSDEBUG_CHATVIEW
-  kDebug() << "Adding contact from URL: " << email;
+  kmDebug() << "Adding contact from URL: " << email;
 #endif
 
   // Strip the pseudo-protocol 'mail to' from the email address
@@ -633,7 +642,7 @@ void ChatView::slotAddNewEmoticon()
   if( ! chatViewClickedUrl_.isValid() || chatViewClickedUrl_.protocol() != "kmess" || chatViewClickedUrl_.host() != "emoticon" )
   {
 #ifdef KMESSDEBUG_CHATVIEW
-    kDebug() << "Ignoring request for invalid URL: " << chatViewClickedUrl_;
+    kmDebug() << "Ignoring request for invalid URL: " << chatViewClickedUrl_;
 #endif
 
     return;
@@ -661,7 +670,7 @@ void ChatView::slotAddNewEmoticon()
   if( contact == 0 )
   {
 #ifdef KMESSDEBUG_CHATVIEW
-    kDebug() << "Contact handle not found: " << handle;
+    kmDebug() << "Contact handle not found: " << handle;
 #endif
 
     return;
@@ -672,7 +681,7 @@ void ChatView::slotAddNewEmoticon()
   shortcut = KUrl::fromPercentEncoding( shortcut.toUtf8() );
 
 #ifdef KMESSDEBUG_CHATVIEW
-  kDebug() << "Showing Add Emoticon dialog - shortcut=" << shortcut << " picture=" << picture;
+  kmDebug() << "Showing Add Emoticon dialog - shortcut=" << shortcut << " picture=" << picture;
 #endif
 
   // Finally, show the dialog, preselecting the picture file and shortcut
@@ -703,14 +712,14 @@ void ChatView::slotCopyAddress()
   if( ! chatViewClickedUrl_.isValid() )
   {
 #ifdef KMESSDEBUG_CHATVIEW
-    kDebug() << "Not copying invalid URL: " << url;
+    kmDebug() << "Not copying invalid URL: " << url;
 #endif
 
     return;
   }
 
 #ifdef KMESSDEBUG_CHATVIEW
-  kDebug() << "Copying URL: " << url;
+  kmDebug() << "Copying URL: " << url;
 #endif
 
   // Strip the pseudo-protocol 'mail to' from email addresses
@@ -750,7 +759,7 @@ void ChatView::slotIgnoreEmoticon()
   if( ! chatViewClickedUrl_.isValid() || chatViewClickedUrl_.protocol() != "kmess" || chatViewClickedUrl_.host() != "emoticon" )
   {
 #ifdef KMESSDEBUG_CHATVIEW
-    kDebug() << "Ignoring request for invalid URL: " << chatViewClickedUrl_;
+    kmDebug() << "Ignoring request for invalid URL: " << chatViewClickedUrl_;
 #endif
 
     return;
@@ -777,7 +786,7 @@ void ChatView::slotIgnoreEmoticon()
   if( contact == 0 )
   {
 #ifdef KMESSDEBUG_CHATVIEW
-    kDebug() << "Contact handle not found: " << handle;
+    kmDebug() << "Contact handle not found: " << handle;
 #endif
 
     return;
@@ -850,9 +859,16 @@ void ChatView::scrollTo( bool forward, bool fast )
 
 
 // Scroll the view down to the last line
-void ChatView::scrollToBottom()
+void ChatView::scrollToBottom( bool force )
 {
-  chatMessageView_->scrollChatToBottom();
+  if( force )
+  {
+    chatMessageView_->scrollChatToBottom();
+  }
+  else
+  {
+    chatMessageView_->scrollChatToBottomGently();
+  }
 }
 
 
@@ -877,7 +893,7 @@ void ChatView::slotSendAppCommand()
   if( ! chatViewClickedUrl_.isValid() || chatViewClickedUrl_.protocol() != "kmess" || chatViewClickedUrl_.host() != "application" )
   {
 #ifdef KMESSDEBUG_CHATVIEW
-    kDebug() << "Not sending invalid application link: " << chatViewClickedUrl_.url();
+    kmDebug() << "Not sending invalid application link: " << chatViewClickedUrl_.url();
 #endif
 
     return;
@@ -901,7 +917,7 @@ void ChatView::slotSendAppCommand()
 #endif
 
 #ifdef KMESSDEBUG_CHATVIEW
-  kDebug() << "Sending application link - method=" << method << " contact=" << contact << " cookie=" << cookie;
+  kmDebug() << "Sending application link - method=" << method << " contact=" << contact << " cookie=" << cookie;
 #endif
 
   emit appCommand( cookie, contact, method );
@@ -926,7 +942,7 @@ void ChatView::slotShowContextMenu( const QString &clickedUrl, const QPoint &poi
     KUrl url( clickedUrl );
 
 #ifdef KMESSDEBUG_CHATVIEW
-    kDebug() << "Clicked URL: " << url.prettyUrl();
+    kmDebug() << "Clicked URL: " << url.prettyUrl();
 #endif
 
     if( url.protocol() == "kmess" && url.host() == "emoticon" )
@@ -954,7 +970,7 @@ void ChatView::slotShowContextMenu( const QString &clickedUrl, const QPoint &poi
     }
     else
     {
-      urlAction = new KAction( KIcon( "launch" ), i18n("Visit &Link"), this );
+      urlAction = new KAction( KIcon( "document-open-remote" ), i18n("Visit &Link"), this );
       connect( urlAction, SIGNAL(triggered(bool)), this, SLOT(slotVisitAddress()) );
       contextMenu->addAction( urlAction );
 
@@ -967,7 +983,7 @@ void ChatView::slotShowContextMenu( const QString &clickedUrl, const QPoint &poi
   }
 
 #ifdef KMESSDEBUG_CHATVIEW
-  kDebug() << "Creating popup menu entries";
+  kmDebug() << "Creating popup menu entries";
 #endif
 
   // Create items
@@ -1016,14 +1032,14 @@ void ChatView::slotVisitAddress()
   if( ! chatViewClickedUrl_.isValid() )
   {
 #ifdef KMESSDEBUG_CHATVIEW
-    kDebug() << "Not opening invalid URL: " << chatViewClickedUrl_;
+    kmDebug() << "Not opening invalid URL: " << chatViewClickedUrl_;
 #endif
 
     return;
   }
 
 #ifdef KMESSDEBUG_CHATVIEW
-  kDebug() << "Opening URL: " << chatViewClickedUrl_;
+  kmDebug() << "Opening URL: " << chatViewClickedUrl_;
 #endif
 
   // Launch the browser for the given URL
@@ -1052,7 +1068,7 @@ void ChatView::updateCustomEmoticon( const QString &handle, const QString &code
   // Check for empty replacements.
   if( code.isEmpty() )
   {
-    kWarning() << "can't update custom emoticon, emoticon code not given (contact=" << handle << ").";
+    kmWarning() << "can't update custom emoticon, emoticon code not given (contact=" << handle << ").";
     return;
   }
 
