@@ -20,6 +20,7 @@
 #include "../contact/contact.h"
 #include "../contact/msnobject.h"
 #include "../contact/invitedcontact.h"
+#include "../dialogs/chathistorydialog.h"
 #include "../dialogs/invitedialog.h"
 #include "../model/contactlist.h"
 #include "../network/msnswitchboardconnection.h"
@@ -32,6 +33,7 @@
 #include "../kmessdebug.h"
 #include "chat.h"
 #include "config-kmess.h"
+#include "chathistorymanager.h"
 #include "contactswidget.h"
 #include "emoticonswidget.h"
 #include "winkswidget.h"
@@ -245,7 +247,7 @@ ChatWindow::~ChatWindow()
   saveProperties();
 
 #ifdef KMESSDEBUG_CHATWINDOW
-  kDebug() << "DESTROYED.";
+  kmDebug() << "DESTROYED.";
 #endif
 }
 
@@ -318,7 +320,7 @@ void ChatWindow::changeZoomFactor( bool increase )
   if( newZoom < 20 || newZoom > 300 )
   {
 #ifdef KMESSDEBUG_CHATWINDOW
-    kDebug() << "Zoom level out of bounds, not updating.";
+    kmDebug() << "Zoom level out of bounds, not updating.";
 #endif
     return;
   }
@@ -406,19 +408,19 @@ bool ChatWindow::closeAllTabs()
 bool ChatWindow::closeTab()
 {
 #ifdef KMESSDEBUG_CHATWINDOW
-  kDebug() << "Close request detected.";
+  kmDebug() << "Close request detected.";
 #endif
 
   Chat *currentChat = getCurrentChat();
   if( currentChat != 0 )
   {
 #ifdef KMESSDEBUG_CHATWINDOW
-    kDebug() << "Closing current chat tab " << currentChat;
+    kmDebug() << "Closing current chat tab " << currentChat;
 #endif
 
     if( ! slotTabRemoved( currentChat ) )
     {
-      kWarning() << "Unable to close the current chat!";
+      kmWarning() << "Unable to close the current chat!";
     }
   }
 
@@ -458,6 +460,7 @@ void ChatWindow::createMenus()
   inviteButton_       = new KAction      ( KIcon("list-add-user"),                         i18n("&Invite..."),         this );
   sendAction_         = new KAction      ( KIcon("folder-remote"),                         i18n("Send a &File..."),    this );
   nudgeAction_        = new KAction      ( KIcon("preferences-desktop-notification-bell"), i18n("Send a &Nudge!"),     this );
+  historyMenuAction_  = new KActionMenu  ( KIcon("chronometer"),                           i18n("Chat &History..."),   this );
   saveAction          = new KAction      ( KIcon("document-save"),                         i18n("Save Chat..."),       this );
   closeAllAction_     = new KAction      ( KIcon("dialog-close"),                          i18n("Close &All Tabs"),    this );
   closeAction         = KStandardAction::close  ( this, SLOT( closeWidgetOrTab() ) , actionCollection_ );
@@ -546,6 +549,8 @@ void ChatWindow::createMenus()
            this,                SLOT  (   startFileTransfer()     ) );
   connect( nudgeAction_,        SIGNAL(           triggered(bool) ),
            this,                SLOT  (           sendNudge()     ) );
+  connect( historyMenuAction_,  SIGNAL(           triggered(bool) ),
+           this,                SLOT  ( slotShowChatHistory()     ) );
   connect( saveAction,          SIGNAL(           triggered(bool) ),
            this,                SLOT  (            saveChat()     ) );
   connect( closeAllAction_,     SIGNAL(           triggered()     ),
@@ -572,6 +577,7 @@ void ChatWindow::createMenus()
   actionCollection_->addAction( "send",         sendAction_        );
   actionCollection_->addAction( "nudge",        nudgeAction_       );
   actionCollection_->addAction( "save",         saveAction         );
+  actionCollection_->addAction( "historyMenu",  historyMenuAction_ );
   actionCollection_->addAction( "closeAll",     closeAllAction_    );
   actionCollection_->addAction( "invite",       inviteButton_      );
 
@@ -691,7 +697,7 @@ void ChatWindow::editorColorChanged(const QColor &color)
   if ( color.name() != currentAccount_->getFontColor() )
   {
 #ifdef KMESSDEBUG_CHATWINDOW
-    kDebug() << "Color was reset to" << color.name() << ". Restoring it to the account setting.";
+    kmDebug() << "Color was reset to" << color.name() << ". Restoring it to the account setting.";
 #endif
     messageEdit_->setTextColor( QColor( currentAccount_->getFontColor() ) );
     messageEdit_->setFont( QFont ( currentAccount_->getFont() ) );
@@ -929,7 +935,7 @@ bool ChatWindow::eventFilter( QObject *obj, QEvent *event )
       if( ! dragEvent )
       {
 #ifdef KMESSDEBUG_CHATWINDOW
-        kDebug() << "Ignoring invalid drag event!";
+        kmDebug() << "Ignoring invalid drag event!";
 #endif
         return false;
       }
@@ -939,14 +945,14 @@ bool ChatWindow::eventFilter( QObject *obj, QEvent *event )
       ||  mimeData->hasImage() )
       {
 #ifdef KMESSDEBUG_CHATWINDOW
-        kDebug() << "Accepting drag event of mimetypes:" << dragEvent->mimeData()->formats();
+        kmDebug() << "Accepting drag event of mimetypes:" << dragEvent->mimeData()->formats();
 #endif
         dragEvent->acceptProposedAction();
         return true;
       }
 
 #ifdef KMESSDEBUG_CHATWINDOW
-      kDebug() << "Ignoring invalid drop having mimetypes:" << dragEvent->mimeData()->formats();
+      kmDebug() << "Ignoring invalid drop having mimetypes:" << dragEvent->mimeData()->formats();
 #endif
 
       break;
@@ -959,7 +965,7 @@ bool ChatWindow::eventFilter( QObject *obj, QEvent *event )
       if( ! dropEvent )
       {
 #ifdef KMESSDEBUG_CHATWINDOW
-        kDebug() << "Ignoring invalid drop!";
+        kmDebug() << "Ignoring invalid drop!";
 #endif
         return true;
       }
@@ -973,12 +979,12 @@ bool ChatWindow::eventFilter( QObject *obj, QEvent *event )
         const QString url( mimeData->urls().first().toString() );
 
 #ifdef KMESSDEBUG_CHATWINDOW
-        kDebug() << "Checking if the dropped inline image is a fortified-PNG...";
+        kmDebug() << "Checking if the dropped inline image is a fortified-PNG...";
 #endif
         if( url.startsWith( marker ) )
         {
 #ifdef KMESSDEBUG_CHATWINDOW
-          kDebug() << "Setting drawing to the Ink Canvas.";
+          kmDebug() << "Setting drawing to the Ink Canvas.";
 #endif
           QByteArray isfData( url.mid( marker.length() ).toAscii() );
           Isf::Drawing* drawing = &( Isf::Stream::readerPng( isfData, true ) );
@@ -1003,7 +1009,7 @@ bool ChatWindow::eventFilter( QObject *obj, QEvent *event )
       if( dropEvent->source() != 0 )
       {
 #ifdef KMESSDEBUG_CHATWINDOW
-        kDebug() << "Ignoring internal drop!";
+        kmDebug() << "Ignoring internal drop!";
 #endif
         dropEvent->ignore();
         return true;
@@ -1013,7 +1019,7 @@ bool ChatWindow::eventFilter( QObject *obj, QEvent *event )
       if( mimeData->hasUrls() )
       {
 #ifdef KMESSDEBUG_CHATWINDOW
-        kDebug() << "Drag'n'dropped files:" << mimeData->urls();
+        kmDebug() << "Drag'n'dropped files:" << mimeData->urls();
 #endif
 
         // Send the files to the contact
@@ -1030,13 +1036,13 @@ bool ChatWindow::eventFilter( QObject *obj, QEvent *event )
         if( image.isNull() )
         {
 #ifdef KMESSDEBUG_CHATVIEW
-          kDebug() << "Drag'n'dropped an invalid image!";
+          kmDebug() << "Drag'n'dropped an invalid image!";
 #endif
           return true;
         }
 
 #ifdef KMESSDEBUG_CHATWINDOW
-        kDebug() << "Drag'n'dropped a" << image.size() << "image";
+        kmDebug() << "Drag'n'dropped a" << image.size() << "image";
 #endif
 
         // Create a temporary file where the image will be stored.
@@ -1051,7 +1057,7 @@ bool ChatWindow::eventFilter( QObject *obj, QEvent *event )
         if( ! file.open() )
         {
 #ifdef KMESSDEBUG_CHATWINDOW
-          kDebug() << "Cannot create temporary image file!";
+          kmDebug() << "Cannot create temporary image file!";
 #endif
           return true;
         }
@@ -1279,13 +1285,13 @@ bool ChatWindow::initialize()
 {
   if( initialized_ )
   {
-    kDebug() << "already initialized.";
+    kmDebug() << "already initialized.";
     return false;
   }
 
   if( ! initializeCurrentAccount() )
   {
-    kDebug() << "Couldn't setup the current account.";
+    kmDebug() << "Couldn't setup the current account.";
     return false;
   }
 
@@ -1341,7 +1347,7 @@ bool ChatWindow::initializeCurrentAccount()
   currentAccount_ = CurrentAccount::instance();
   if ( currentAccount_ == 0 )
   {
-    kWarning() << "Could not get an instance of the current account.";
+    kmWarning() << "Could not get an instance of the current account.";
     return false;
   }
 
@@ -1378,7 +1384,7 @@ void ChatWindow::insertEmoticon( const QString &shortcut )
 bool ChatWindow::queryClose()
 {
 #ifdef KMESSDEBUG_CHATWINDOW
-  kDebug() << "Closing all open chats";
+  kmDebug() << "Closing all open chats";
 #endif
 
   return closeAllTabs();
@@ -1390,7 +1396,7 @@ bool ChatWindow::queryClose()
 bool ChatWindow::queryExit()
 {
 #ifdef KMESSDEBUG_CHATWINDOW
-  kDebug() << "Closing all open chats";
+  kmDebug() << "Closing all open chats";
 #endif
 
   // Allow performing last operations to all open chats and delete them
@@ -1409,7 +1415,7 @@ bool ChatWindow::queryExit()
   // Always accept this one, otherwise the chat window won't close.
   // The quit is presented in KMessApplication::slotLastWindowClosed() too.
 #ifdef KMESSDEBUG_KMESSINTERFACE
-  kDebug() << "Accepting exit request.";
+  kmDebug() << "Accepting exit request.";
 #endif
 
   return true;
@@ -1539,7 +1545,7 @@ void ChatWindow::sendInk()
   // was enabled...
   if( ! supportGifInk && ! supportIsfInk )
   {
-    kWarning() << "Neither Ink formats are supported by the participants!";
+    kmWarning() << "Neither Ink formats are supported by the participants!";
 
     currentChat->showMessage( ChatMessage( ChatMessage::TYPE_SYSTEM,
                                            ChatMessage::CONTENT_SYSTEM_ERROR,
@@ -1558,7 +1564,7 @@ void ChatWindow::sendInk()
   if( supportIsfInk )
   {
 #ifdef KMESSDEBUG_CHATWINDOW
-    kDebug() << "Retrieving ISF ink data";
+    kmDebug() << "Retrieving ISF ink data";
 #endif
 
     format = FORMAT_ISF;
@@ -1567,7 +1573,7 @@ void ChatWindow::sendInk()
   else if( supportGifInk && Isf::Stream::supportsGif() )
   {
 #ifdef KMESSDEBUG_CHATWINDOW
-    kDebug() << "Retrieving GIF ink data";
+    kmDebug() << "Retrieving GIF ink data";
 #endif
 
     format = FORMAT_GIF;
@@ -1577,7 +1583,7 @@ void ChatWindow::sendInk()
 
   if( ink.isEmpty() )
   {
-    kWarning() << "An error occured while creating the" << ( supportIsfInk ? "ISF" : "GIF" ) << "Ink data!";
+    kmWarning() << "An error occured while creating the" << ( supportIsfInk ? "ISF" : "GIF" ) << "Ink data!";
 
     currentChat->showMessage( ChatMessage( ChatMessage::TYPE_SYSTEM,
                                            ChatMessage::CONTENT_SYSTEM_ERROR,
@@ -1913,7 +1919,7 @@ void ChatWindow::showMenuBar()
 void ChatWindow::showStatusMessage( ChatStatusBar::MessageType type, QString message )
 {
 #ifdef KMESSDEBUG_CHATWINDOW
-  kDebug() << "Showing status message" << message << "(" << type << ")";
+  kmDebug() << "Showing status message" << message << "(" << type << ")";
 #endif
   statusLabel_->setMessage( type, message );
 }
@@ -1927,7 +1933,7 @@ void ChatWindow::showStatusMessage( QString message, int duration )
   message = message.replace( "\n", " " );
 
 #ifdef KMESSDEBUG_CHATWINDOW
-  kDebug() << "Showing status bar text" << message << "with duration" << duration;
+  kmDebug() << "Showing status bar text" << message << "with duration" << duration;
 #endif
 
   // HACK: Empty strings are not rendered, and any previously set text is not removed.
@@ -1951,7 +1957,7 @@ void ChatWindow::showStatusMessage( QString message, int duration )
   }
 
 #ifdef KMESSDEBUG_CHATWINDOW
-  kDebug() << "Setting status bar update timer to" << duration << "sec.";
+  kmDebug() << "Setting status bar update timer to" << duration << "sec.";
 #endif
   statusTimer_.start( duration * 1000 );
 }
@@ -2069,7 +2075,7 @@ void ChatWindow::slotGotNudge()
   if( lastShake_.secsTo( QTime::currentTime() ) < 15 )
   {
 #ifdef KMESSDEBUG_CHATWINDOW
-    kDebug() << "Not shaking the window until"
+    kmDebug() << "Not shaking the window until"
              << lastShake_.secsTo( QTime::currentTime() ) << "more seconds.";
 #endif
     return;
@@ -2116,13 +2122,13 @@ void ChatWindow::slotGotTypingMessage( Chat *chat )
   {
     chat = getCurrentChat();
 #ifdef KMESSDEBUG_CHATWINDOW_TYPING_MESSAGES
-    kDebug() << "Using current chat" << chat;
+    kmDebug() << "Using current chat" << chat;
 #endif
   }
 #ifdef KMESSDEBUG_CHATWINDOW_TYPING_MESSAGES
   else
   {
-    kDebug() << "Using chat:" << chat;
+    kmDebug() << "Using chat:" << chat;
   }
 #endif
 
@@ -2131,7 +2137,7 @@ void ChatWindow::slotGotTypingMessage( Chat *chat )
   const QStringList typingContacts( chat->getTypingContacts() );
 
 #ifdef KMESSDEBUG_CHATWINDOW_TYPING_MESSAGES
-  kDebug() << "These contacts are typing:" << typingContacts;
+  kmDebug() << "These contacts are typing:" << typingContacts;
 #endif
 
   // Update the color of this chat's tab
@@ -2156,7 +2162,7 @@ void ChatWindow::slotGotTypingMessage( Chat *chat )
   if( chat != getCurrentChat() )
   {
 #ifdef KMESSDEBUG_CHATWINDOW_TYPING_MESSAGES
-    kDebug() << "Typing message was not for the active chat, skipping status bar update.";
+    kmDebug() << "Typing message was not for the active chat, skipping status bar update.";
 #endif
     return;
   }
@@ -2165,7 +2171,7 @@ void ChatWindow::slotGotTypingMessage( Chat *chat )
   if( typingContacts.isEmpty() )
   {
 #ifdef KMESSDEBUG_CHATWINDOW_TYPING_MESSAGES
-    kDebug() << "No contacts are typing anymore, cleaning up the status bar.";
+    kmDebug() << "No contacts are typing anymore, cleaning up the status bar.";
 #endif
     showStatusMessage();
     return;
@@ -2312,6 +2318,53 @@ void ChatWindow::slotSendButtonClicked()
 
 
 
+
+// Show the chat history for a contact
+void ChatWindow::slotShowChatHistory()
+{
+  const KAction* action = qobject_cast< const KAction* >( sender() );
+
+  if( ! action )
+  {
+#ifdef KMESSDEBUG_CHATWINDOW
+    kmWarning() << "Called directly, action is not valid!";
+#endif
+    return;
+  }
+
+  // The click came from the menu item itself, not from a sub item.
+  // Select the first contact of the list
+  if( action == historyMenuAction_ )
+  {
+    if( historyMenuAction_->children().isEmpty() )
+    {
+#ifdef KMESSDEBUG_CHATWINDOW
+      kmWarning() << "No contacts available in the menu!";
+#endif
+      return;
+    }
+
+    action = qobject_cast< const KAction* >( historyMenuAction_->children().first() );
+    KMESS_ASSERT( action );
+  }
+
+  const QString handle( action->data().toString() );
+
+  if( handle.isEmpty() )
+  {
+#ifdef KMESSDEBUG_CHATWINDOW
+    kmWarning() << "Action did not contain a valid handle! (contained a" << action->data().typeName() << " instead)";
+#endif
+    return;
+  }
+
+  ChatHistoryDialog *dialog = new ChatHistoryDialog( this );
+  dialog->setInitialContact( currentAccount_->getHandle(), handle );
+  dialog->show();
+}
+
+
+
 // Switch to the message editor, or another one
 void ChatWindow::slotSwitchEditor( QObject* widget )
 {
@@ -2321,7 +2374,7 @@ void ChatWindow::slotSwitchEditor( QObject* widget )
   bool disableNewLineButton = true;
 
 #ifdef KMESSDEBUG_CHATWINDOW
-  kDebug() << "Switching editors: caller:" << caller;
+  kmDebug() << "Switching editors: caller:" << caller;
 #endif
 
   // Some widgets are pretty high, hide them unless they're needed
@@ -2338,7 +2391,7 @@ void ChatWindow::slotSwitchEditor( QObject* widget )
   if( caller == winksButton_ && winksButton_->isChecked() )
   {
 #ifdef KMESSDEBUG_CHATWINDOW
-    kDebug() << "Switching to winks list.";
+    kmDebug() << "Switching to winks list.";
 #endif
     winksWidget_->refresh();
     winksWidget_->show();
@@ -2357,7 +2410,7 @@ void ChatWindow::slotSwitchEditor( QObject* widget )
   else if( caller == inkButton_ && inkButton_->isChecked() )
   {
 #ifdef KMESSDEBUG_CHATWINDOW
-    kDebug() << "Switching to ink editor.";
+    kmDebug() << "Switching to ink editor.";
 #endif
     inkCanvas_->show();
 
@@ -2378,7 +2431,7 @@ void ChatWindow::slotSwitchEditor( QObject* widget )
        &&  standardEmoticonButton_->isChecked() )
   {
 #ifdef KMESSDEBUG_CHATWINDOW
-    kDebug() << "Switching to standard emoticons widget.";
+    kmDebug() << "Switching to standard emoticons widget.";
 #endif
     standardEmoticonsWidget_->show();
 
@@ -2395,7 +2448,7 @@ void ChatWindow::slotSwitchEditor( QObject* widget )
        &&  customEmoticonButton_->isChecked() )
   {
 #ifdef KMESSDEBUG_CHATWINDOW
-    kDebug() << "Switching to custom emoticons widget.";
+    kmDebug() << "Switching to custom emoticons widget.";
 #endif
     customEmoticonsWidget_->show();
 
@@ -2410,7 +2463,7 @@ void ChatWindow::slotSwitchEditor( QObject* widget )
   else  // Otherwise, show the message editor
   {
 #ifdef KMESSDEBUG_CHATWINDOW
-    kDebug() << "Switching to the message editor.";
+    kmDebug() << "Switching to the message editor.";
 #endif
     editorChooser_->setCurrentWidget( textPage_ );
     winksButton_->setChecked( false );
@@ -2428,7 +2481,7 @@ void ChatWindow::slotSwitchEditor( QObject* widget )
   newLineButton_->setDisabled( disableNewLineButton );
 
   // Also scroll down the chat, in all cases
-  getCurrentChat()->scrollToBottom();
+  getCurrentChat()->scrollToBottom( false /* no forced scrolling */ );
 }
 
 
@@ -2490,7 +2543,7 @@ void ChatWindow::slotTabChanged( int currentIndex )
   if( ! initialized_ )
   {
 #ifdef KMESSDEBUG_CHATWINDOW
-    kDebug() << "Not switching tab while not initialized.";
+    kmDebug() << "Not switching tab while not initialized.";
 #endif
     return;
   }
@@ -2500,11 +2553,11 @@ void ChatWindow::slotTabChanged( int currentIndex )
 #ifdef KMESSDEBUG_CHATWINDOW
     if( currentIndex == -1 )
     {
-      kDebug() << "The window is closing.";
+      kmDebug() << "The window is closing.";
     }
     else
     {
-      kDebug() << "Chat tab index" << currentIndex << "doesn't exist in the tabs list!";
+      kmDebug() << "Chat tab index" << currentIndex << "doesn't exist in the tabs list!";
     }
 #endif
 
@@ -2519,14 +2572,14 @@ void ChatWindow::slotTabChanged( int currentIndex )
   if( chat == 0 )
   {
 #ifdef KMESSDEBUG_CHATWINDOW
-    kDebug() << "Chat tab" << currentIndex << "was destroyed";
+    kmDebug() << "Chat tab" << currentIndex << "was destroyed";
 #endif
     return;
   }
 #ifdef KMESSDEBUG_CHATWINDOW
   else
   {
-    kDebug() << "Activating chat tab" << currentIndex;
+    kmDebug() << "Activating chat tab" << currentIndex;
   }
 #endif
 
@@ -2559,6 +2612,38 @@ void ChatWindow::slotTabChanged( int currentIndex )
   updateModeButtons();
   slotGotTypingMessage( chat );
 
+  QAction* action;
+  qDeleteAll( historyMenuAction_->children() );
+
+  const QStringList participantsList( chat->getParticipants() );
+  const QStringList contactsWithHistory( ChatHistoryManager::contactsList() );
+  foreach( const QString &handle, participantsList )
+  {
+    const ContactBase *contact = currentAccount_->getContactByHandle( handle );
+    if( contact == 0 )
+    {
+      contact = currentAccount_->addInvitedContact( handle );
+    }
+
+    action = new KAction( KIcon( MsnStatus::getIconName( contact->getStatus() ) ),
+                          contact->getFriendlyName( STRING_CLEANED ),
+                          historyMenuAction_ );
+    action->setData( handle );
+
+    // Only connect the items whose contact has recorded history
+    if( contactsWithHistory.contains( handle ) )
+    {
+      connect( action, SIGNAL(           triggered(bool) ),
+               this,   SLOT  ( slotShowChatHistory()     ) );
+    }
+    else
+    {
+      action->setEnabled( false );
+    }
+
+    historyMenuAction_->addAction( action );
+  }
+
   // Re-enable the spell checker for this tab.
   // FIXME KDE4.x bug this needs to be unset then set
   messageEdit_->setCheckSpellingEnabled( ! spellCheckAction_->isChecked() );
@@ -2576,7 +2661,7 @@ bool ChatWindow::slotTabRemoved( Chat *chat )
   int closedTabIndex = chatTabs_->indexOf( chat );
 
 #ifdef KMESSDEBUG_CHATWINDOW
-  kDebug() << "Removing chat with index" << closedTabIndex;
+  kmDebug() << "Removing chat with index" << closedTabIndex;
 #endif
 
   // Remove the tab of the closed chat
@@ -2586,7 +2671,7 @@ bool ChatWindow::slotTabRemoved( Chat *chat )
   chat->queryClose();
 
 #ifdef KMESSDEBUG_CHATWINDOW
-  kDebug() << "Removed tab index" << closedTabIndex;
+  kmDebug() << "Removed tab index" << closedTabIndex;
 #endif
 
   // Free the memory
@@ -2608,8 +2693,8 @@ bool ChatWindow::slotTabRemoved( QWidget *chatWidget )
 #endif
 
 #ifdef KMESSDEBUG_CHATWINDOW
-  kDebug() << "Forwarding removal command for a chat widget.";
-  kDebug() << "Currently open chats:" << chatTabs_->count();
+  kmDebug() << "Forwarding removal command for a chat widget.";
+  kmDebug() << "Currently open chats:" << chatTabs_->count();
 #endif
 
   // Cast the Widget to Chat pointer
@@ -2617,7 +2702,7 @@ bool ChatWindow::slotTabRemoved( QWidget *chatWidget )
 
   if( chat == 0 )
   {
-    kWarning() << "Unable to find chat for widget:" << chatWidget;
+    kmWarning() << "Unable to find chat for widget:" << chatWidget;
     return false;
   }
 
@@ -2642,7 +2727,7 @@ void ChatWindow::slotUpdateChatInfo( Chat *chat )
   if( index == -1 )
   {
 #ifdef KMESSDEBUG_CHATWINDOW
-    kDebug() << "Cannot find source chat!";
+    kmDebug() << "Cannot find source chat!";
 #endif
     return;
   }
@@ -2695,7 +2780,7 @@ void ChatWindow::slotUpdateChatInfo( Chat *chat )
   if ( chat == getCurrentChat() )
   {
 #ifdef KMESSDEBUG_CHATWINDOW
-    kDebug() << "Source chat is the current one, updating UI.";
+    kmDebug() << "Source chat is the current one, updating UI.";
 #endif
 
     // Update the window title
@@ -2738,7 +2823,7 @@ void ChatWindow::toggleSessionInfo( bool showSessionMessages )
 void ChatWindow::toggleSpellCheck( bool useSpellCheck )
 {
 #ifdef KMESSDEBUG_CHATWINDOW
-  kDebug() << "Spell checking is now" << useSpellCheck;
+  kmDebug() << "Spell checking is now" << useSpellCheck;
 #endif
 
   // Sync the action with a manually set flag (ie in readProperties())
@@ -2802,7 +2887,7 @@ void ChatWindow::updateModeButtons()
   }
 
 #ifdef KMESSDEBUG_CHATWINDOW
-  kDebug() << "Winks/Ink button disabling check: all contacts support winks?" << enableWinksButton
+  kmDebug() << "Winks/Ink button disabling check: all contacts support winks?" << enableWinksButton
            << "and ink?" << enableInkButton;
 #endif
 
