@@ -20,6 +20,7 @@
 #include "../contact/contact.h"
 #include "../contact/contactextension.h"
 #include "../contact/msnstatus.h"
+#include "../dialogs/chathistorydialog.h"
 #include "../dialogs/contactpropertiesdialog.h"
 #include "../model/contactlist.h"
 #include "../utils/kmessshared.h"
@@ -27,6 +28,7 @@
 #include "../currentaccount.h"
 #include "../emoticonmanager.h"
 #include "../kmessdebug.h"
+#include "chathistorymanager.h"
 
 // HACK: Must go after 2.0-final
 #include "../network/msnnotificationconnection.h"
@@ -104,7 +106,7 @@ void ContactFrame::activate( ContactBase *contact )
   if( contact == 0 )
   {
 #ifdef KMESSDEBUG_CONTACTFRAME
-    kDebug() << "Deactivating frame for contact:" << handle_;
+    kmDebug() << "Deactivating frame for contact:" << handle_;
 #endif
 
     contact_         = 0;
@@ -194,11 +196,11 @@ void ContactFrame::contactDestroyed( QObject *object )
 #ifdef KMESSDEBUG_CONTACTFRAME
   if( contact_ && contact_ != object )
   {
-    kWarning() << "Received unexpected contact reference to" << object->metaObject()->className();
+    kmWarning() << "Received unexpected contact reference to" << object->metaObject()->className();
   }
   else
   {
-    kDebug() << "Resetting contact reference.";
+    kmDebug() << "Resetting contact reference.";
   }
 #else
   Q_UNUSED( object );
@@ -300,7 +302,7 @@ bool ContactFrame::eventFilter( QObject *obj, QEvent *event )
 
       if( mimeUrl.isEmpty() )
       {
-        kWarning() << "Dropped empty MIME URL";
+        kmWarning() << "Dropped empty MIME URL";
         return true;
       }
 
@@ -308,7 +310,7 @@ bool ContactFrame::eventFilter( QObject *obj, QEvent *event )
 
       if( ! pictureData.load( filePath ) )
       {
-        kWarning() << "The file dropped is not an image or doesn't exist";
+        kmWarning() << "The file dropped is not an image or doesn't exist";
         return true;
       }
 
@@ -351,11 +353,11 @@ bool ContactFrame::initContactPopup()
   }
 
   // Initialize context popup actions
-  popupStartPrivateChat_    = new KAction( KIcon("user-group-new"),           i18n("&Start Private Chat"), this);
-  popupEmailContact_        = new KAction( KIcon("mail-message-new"),         i18n("&Send Email"),       this );
-  popupMsnProfile_          = new KAction( KIcon("preferences-desktop-user"), i18n("&View Profile"),     this );
-  //popupEditNotes_           = new KAction( KIcon("user-properties"),          i18n("Ed&it Notes"),       this );
-  popupContactProperties_   = new KAction( KIcon("user-properties"),          i18n("&Properties"),       this );
+  popupStartPrivateChat_    = new KAction( KIcon("user-group-new"),           i18n("&Start Private Chat"), this );
+  popupEmailContact_        = new KAction( KIcon("mail-message-new"),         i18n("&Send Email"),         this );
+  popupShowHistory_         = new KAction( KIcon("chronometer"),              i18n("Chat &History"),       this );
+  popupMsnProfile_          = new KAction( KIcon("preferences-desktop-user"), i18n("&View Profile"),       this );
+  popupContactProperties_   = new KAction( KIcon("user-properties"),          i18n("&Properties"),         this );
 
   popupAddContact_          = new KAction( KIcon("list-add"),         i18n("&Add Contact"),      this );
   popupAllowContact_        = new KAction( KIcon("dialog-ok-apply"),  i18n("A&llow Contact"),    this );
@@ -379,9 +381,8 @@ bool ContactFrame::initContactPopup()
   connect( popupStartPrivateChat_,    SIGNAL(triggered( bool )), this,  SLOT( slotStartPrivateChat()  ) );
 
   connect( popupEmailContact_,        SIGNAL(triggered(bool)),   this,  SLOT( sendEmail()             ) );
+  connect( popupShowHistory_,         SIGNAL(triggered(bool)),   this,  SLOT( showChatHistory()       ) );
   connect( popupMsnProfile_,          SIGNAL(triggered(bool)),   this,  SLOT( showProfile()           ) );
-  //connect( popupEditNotes_,           SIGNAL(triggered(bool)),   this,  SLOT( showContactProperties() ) );
-  //connect( popupContactProperties_,   SIGNAL(triggered(bool)),   this,  SLOT( showContactProperties() ) );
 
   connect( popupAddContact_,          SIGNAL(triggered(bool)),   this,  SLOT( toggleContactAdded()    ) );
   connect( popupAllowContact_,        SIGNAL(triggered(bool)),   this,  SLOT( allowContact()          ) );
@@ -422,9 +423,9 @@ bool ContactFrame::initContactPopup()
   contactActionPopup_->addTitle( contact_->getHandle() );
   contactActionPopup_->addAction( popupStartPrivateChat_ );
   contactActionPopup_->addAction( popupEmailContact_ );
+  contactActionPopup_->addAction( popupShowHistory_ );
   contactActionPopup_->addAction( popupMsnProfile_ );
   contactActionPopup_->addAction( popupCopyMenu_ );
-  //contactActionPopup_->addAction( popupEditNotes_ );
   contactActionPopup_->addSeparator();
 
   contactActionPopup_->addAction( popupAddContact_ );
@@ -477,7 +478,7 @@ void ContactFrame::setDisplayMode( DisplayMode mode )
   currentMode_ = mode;
 
 #ifdef KMESSDEBUG_CONTACTFRAME
-  kDebug() << "Frame mode:" << mode;
+  kmDebug() << "Frame mode:" << mode;
 #endif
 
   // Change the displayed widgets
@@ -522,6 +523,16 @@ void ContactFrame::setEnabled( bool isEnabled )
 
 
 
+// Show the contact's chat history
+void ContactFrame::showChatHistory()
+{
+  ChatHistoryDialog *dialog = new ChatHistoryDialog( this );
+  dialog->setInitialContact( CurrentAccount::instance()->getHandle(), handle_ );
+  dialog->show();
+}
+
+
+
 // Update and show the contact popup menu
 void ContactFrame::showContactPopup( const QPoint &point )
 {
@@ -582,7 +593,8 @@ void ContactFrame::showContactPopup( const QPoint &point )
     }
   }
 
-  //popupEditNotes_          ->setVisible( detailedContact_ != 0 );
+  popupShowHistory_        ->setEnabled( ChatHistoryManager::contactsList().contains( handle_ ) );
+
   popupContactProperties_  ->setVisible( detailedContact_ != 0 );
   popupMsnProfile_         ->setVisible( detailedContact_ != 0 );
 
@@ -610,16 +622,9 @@ void ContactFrame::showContactProperties()
     // Default is not to open notes tab
     ContactPropertiesDialog::DefaultTab defaultTab = ContactPropertiesDialog::Information;
 
-    // If we've been called via the edit notes action, open that tab
-    if( sender() == popupEditNotes_ )
-    {
-      defaultTab = ContactPropertiesDialog::Notes;
-    }
-    else if( sender() == popupPropImages_ )
-    {
-      defaultTab = ContactPropertiesDialog::Images;
-    }
-    else if( sender() == popupPropEmoticons_ )
+    // If we've been called via a specialized properties action,
+    // open the corresponding tab
+    if( sender() == popupPropEmoticons_ )
     {
       defaultTab = ContactPropertiesDialog::Emoticons;
     }
@@ -752,13 +757,13 @@ void ContactFrame::updatePicture()
   &&  contactPictureDate == contactPictureDate_ )
   {
 #ifdef KMESSDEBUG_CONTACTFRAME
-    kDebug() << "Picture was already loaded.";
+    kmDebug() << "Picture was already loaded.";
 #endif
     return;
   }
 
 #ifdef KMESSDEBUG_CONTACTFRAME
-  kDebug() << "New contact picture:" << contactPicturePath;
+  kmDebug() << "New contact picture:" << contactPicturePath;
 #endif
 
   QImage contactImage( contactPicturePath );
