@@ -71,7 +71,7 @@ ContactsWidget::~ContactsWidget()
   contactFrames_.clear();
 
 #ifdef KMESSDEBUG_CONTACTSWIDGET
-  kDebug() << "DESTROYED.";
+  kmDebug() << "DESTROYED.";
 #endif
 }
 
@@ -105,7 +105,7 @@ void ContactsWidget::contactJoined( ContactBase* contact )
   }
 
 #ifdef KMESSDEBUG_CONTACTSWIDGET
-  kDebug() << handle;
+  kmDebug() << handle;
 #endif
 
   ContactFrame::DisplayMode frameMode;
@@ -141,7 +141,7 @@ void ContactsWidget::contactLeft( ContactBase *contact, bool /*isChatIdle*/ )
   }
 
 #ifdef KMESSDEBUG_CONTACTSWIDGET
-  kDebug() << handle;
+  kmDebug() << handle;
 #endif
 
 
@@ -204,7 +204,7 @@ bool ContactsWidget::eventFilter( QObject *obj, QEvent *event )
   if( obj != userPixmapLabel_ )
   {
 #ifdef KMESSDEBUG_CONTACTSWIDGET
-    kWarning() << "Received event '" << eventType << "' from object '" << obj->objectName() << "'.";
+    kmWarning() << "Received event '" << eventType << "' from object '" << obj->objectName() << "'.";
 #endif
     return false;
   }
@@ -280,7 +280,7 @@ bool ContactsWidget::eventFilter( QObject *obj, QEvent *event )
 
       if( mimeUrl.isEmpty() )
       {
-        kWarning() << "Dropped empty MIME URL";
+        kmWarning() << "Dropped empty MIME URL";
         return true;
       }
 
@@ -304,7 +304,7 @@ bool ContactsWidget::eventFilter( QObject *obj, QEvent *event )
 
       if( ! pictureData.load( localFilePath ) )
       {
-        kWarning() << "The file dropped is not an image or doesn't exist";
+        kmWarning() << "The file dropped is not an image or doesn't exist";
         return true;
       }
 
@@ -346,7 +346,7 @@ bool ContactsWidget::eventFilter( QObject *obj, QEvent *event )
       {
         if( ! pictureFolder.rename( tempPictureFile, pictureName ) )
         {
-          kWarning() << "The display picture file could not be renamed from" << tempPictureFile << "to" << pictureName << ".";
+          kmWarning() << "The display picture file could not be renamed from" << tempPictureFile << "to" << pictureName << ".";
           return true;
         }
       }
@@ -510,7 +510,7 @@ void ContactsWidget::setDockWidget( QDockWidget *dockWidget, Qt::DockWidgetArea
 void ContactsWidget::slotLocationChanged( Qt::DockWidgetArea area )
 {
 #ifdef KMESSDEBUG_CONTACTSWIDGET
-  kDebug() << "Changing location to" << area;
+  kmDebug() << "Changing location to" << area;
 #endif
 
   switch( area )
@@ -589,7 +589,7 @@ void ContactsWidget::slotUpdateDisplayPicture()
   if( ! isVisible )
   {
 #ifdef KMESSDEBUG_CONTACTSWIDGET
-    kDebug() << "Not updating hidden user picture widget";
+    kmDebug() << "Not updating hidden user picture widget";
 #endif
     return;
   }
@@ -599,13 +599,13 @@ void ContactsWidget::slotUpdateDisplayPicture()
   if( userPixmapLabel_->property( "PictureFileName" ) == pictureFileName )
   {
 #ifdef KMESSDEBUG_CONTACTSWIDGET
-    kDebug() << "User picture unchanged, not updating widget";
+    kmDebug() << "User picture unchanged, not updating widget";
 #endif
     return;
   }
 
 #ifdef KMESSDEBUG_CONTACTSWIDGET
-  kDebug() << "Updating user picture widget";
+  kmDebug() << "Updating user picture widget";
 #endif
 
   // Change the picture
