@@ -97,7 +97,7 @@ ContactPropertiesDialog::~ContactPropertiesDialog()
 
   delete mediaSound_;
 #ifdef KMESSDEBUG_CONTACTPROPERTIES
-  kDebug() << "DESTROYED.";
+  kmDebug() << "DESTROYED.";
 #endif
 }
 
@@ -268,7 +268,7 @@ bool ContactPropertiesDialog::eventFilter(QObject *obj, QEvent *event )
 bool ContactPropertiesDialog::launch( Contact *contact, DefaultTab defaultTab )
 {
 #ifdef KMESSDEBUG_CONTACTPROPERTIES
-  kDebug() << "Launch with contact " << contact->getHandle();
+  kmDebug() << "Launch with contact " << contact->getHandle();
 #endif
 
   // Copy the pointer to the contact class
@@ -614,7 +614,7 @@ void ContactPropertiesDialog::slotRemoveEmoticon()
   if( item == 0 )
   {
 #ifdef KMESSDEBUG_CONTACTPROPERTIES
-    kDebug() << "No emoticon selected!";
+    kmDebug() << "No emoticon selected!";
 #endif
     return;
   }
@@ -622,7 +622,7 @@ void ContactPropertiesDialog::slotRemoveEmoticon()
   bool removed = contact_->manageEmoticonBlackList( false, item->data( Qt::UserRole ).toString() );
 
 #ifdef KMESSDEBUG_CONTACTPROPERTIES
-  kDebug() << "Blacklist operation succeeded?" << removed;
+  kmDebug() << "Blacklist operation succeeded?" << removed;
 #endif
 
   if( removed )
@@ -709,7 +709,7 @@ void ContactPropertiesDialog::slotUsePicture()
 bool ContactPropertiesDialog::checkNotificationSoundFile( const KUrl &url ) {
 
 #ifdef KMESSDEBUG_CONTACTPROPERTIES
-  kDebug() << "Checking filetype";
+  kmDebug() << "Checking filetype";
 #endif
 
   if( Phonon::BackendCapabilities::availableMimeTypes().contains(
