@@ -45,6 +45,58 @@ NetworkWindow * NetworkWindow::instance_(0);
 
 
 
+#ifdef KMESS_NETWORK_WINDOW
+
+// The network window can optionally be compiled.
+// The macro's from kmessdebug.h make it easy to handle this
+// without optionally depending on networkwindow.h everywhere.
+
+/**
+ * @brief Inform the network window the connection was closed, used by <code>KMESS_NET_CLOSE</code>.
+ * @param  connection  Reference to the caller object, to distinguish between connections.
+ * @ingroup Debug
+ */
+void _kmessNetClose(QObject *connection)
+{
+  NetworkWindow::instance()->connectionClosed(connection);
+}
+
+/**
+ * @brief Inform the network window about a new connection, used by <code>KMESS_NET_INIT</code>.
+ * @param  connection  Reference to the caller object, to distinguish between connections.
+ * @param  title       The title for the connection in the network window.
+ * @ingroup Debug
+ */
+void _kmessNetInit(QObject *connection, const QString &title)
+{
+  NetworkWindow::instance()->setConnectionTitle(connection, title);
+}
+
+/**
+ * @brief Add the received data to the network window, used by <code>KMESS_NET_RECEIVED</code>.
+ * @param  connection  Reference to the caller object, to distinguish between connections.
+ * @param  message     The data received from the connection, should be a complete message.
+ * @ingroup Debug
+ */
+void _kmessNetReceived(QObject *connection, const QByteArray &message)
+{
+  NetworkWindow::instance()->addIncomingMessage(connection, message);
+}
+
+/**
+ * @brief Add the sent data to the network window, used by <code>KMESS_NET_SENT</code>.
+ * @param  connection  Reference to the caller object, to distinguish between connections.
+ * @param  message     The data sent to the connection, should be a complete message.
+ * @ingroup Debug
+ */
+void _kmessNetSent(QObject *connection, const QByteArray &message)
+{
+  NetworkWindow::instance()->addOutgoingMessage(connection, message);
+}
+
+#endif
+
+
 // Constructor
 NetworkWindow::NetworkWindow( QWidget *parent )
   : KDialog( parent, Qt::Dialog ) // Explicitly set the window type to disable the destructive close behavior
@@ -709,7 +761,7 @@ NetworkWindow::~NetworkWindow()
       // If no type is found, assume it's a standard MSN connection.
       if( entry->type == TYPE_UNKNOWN )
       {
-        kWarning() << "Could not determine connection type for message: " << message.data();
+        kmWarning() << "Could not determine connection type for message: " << message.data();
         entry->type = TYPE_NS;
       }
     }
@@ -1107,7 +1159,7 @@ NetworkWindow::~NetworkWindow()
     if( path.isEmpty() )
       return;
 
-    kDebug() << "NetworkWindow - saving network log for window '" << name << "' to '" << path << "'.";
+    kmDebug() << "NetworkWindow - saving network log for window '" << name << "' to '" << path << "'.";
 
     bool failed = false;
 
@@ -1116,7 +1168,7 @@ NetworkWindow::~NetworkWindow()
     if( ! file.open( QIODevice::WriteOnly ) )
     {
       failed = true;
-      kWarning() << "File save failed - couldn't open file.";
+      kmWarning() << "File save failed - couldn't open file.";
     }
 
     // Output the HTML with the right text encoding
