@@ -157,14 +157,14 @@ bool EmoticonTheme::createTheme( const QString& themeDir )
   QFile xmlFile( themeFileName );
 
 #ifdef KMESSDEBUG_EMOTICON_THEMES
-  kDebug() << "Loading emoticons from theme XML: '" << themeFileName << "'";
+  kmDebug() << "Loading emoticons from theme XML: '" << themeFileName << "'";
 #endif
 
   // Try to read the XML
   if( ! xmlFile.open( QIODevice::ReadOnly ) )
   {
 #ifdef KMESSDEBUG_EMOTICON_THEMES
-    kDebug() << "Could not open '" << themeFileName << "'";
+    kmDebug() << "Could not open '" << themeFileName << "'";
 #endif
     return false;
   }
@@ -175,7 +175,7 @@ bool EmoticonTheme::createTheme( const QString& themeDir )
   if( ! xml.setContent( xmlFile.readAll(), false, &xmlError ) )
   {
 #ifdef KMESSDEBUG_EMOTICON_THEMES
-    kDebug() << "Failure parsing '" << themeFileName << "': " << xmlError;
+    kmDebug() << "Failure parsing '" << themeFileName << "': " << xmlError;
 #endif
     xmlFile.close();
     return false;
@@ -215,7 +215,7 @@ bool EmoticonTheme::createTheme( const QString& themeDir )
   }
 
 #ifdef KMESSDEBUG_EMOTICON_THEMES
-  kDebug() << "Added " << emoticons_.count() << " emoticons.";
+  kmDebug() << "Added " << emoticons_.count() << " emoticons.";
 #endif
 
   return true;
@@ -390,14 +390,14 @@ QString EmoticonTheme::getThemeIcon( QString themeDir )
   QFile xmlFile( themeFileName );
 
 #ifdef KMESSDEBUG_EMOTICON_THEMES
-  kDebug() << "Getting first emoticon from theme XML: '" << themeFileName << "'";
+  kmDebug() << "Getting first emoticon from theme XML: '" << themeFileName << "'";
 #endif
 
   // Try to read the XML
   if( ! xmlFile.open( QIODevice::ReadOnly ) )
   {
 #ifdef KMESSDEBUG_EMOTICON_THEMES
-    kDebug() << "Could not open '" << themeFileName << "'";
+    kmDebug() << "Could not open '" << themeFileName << "'";
 #endif
     return QString::null;
   }
@@ -408,7 +408,7 @@ QString EmoticonTheme::getThemeIcon( QString themeDir )
   if( ! xml.setContent( xmlFile.readAll(), false, &xmlError ) )
   {
 #ifdef KMESSDEBUG_EMOTICON_THEMES
-    kDebug() << "Failure parsing '" << themeFileName << "': " << xmlError;
+    kmDebug() << "Failure parsing '" << themeFileName << "': " << xmlError;
 #endif
     xmlFile.close();
     return QString::null;
@@ -459,7 +459,7 @@ bool EmoticonTheme::loadTheme( QString themeName, bool isCustomTheme )
   isCustomTheme_ = isCustomTheme;
 
 #ifdef KMESSDEBUG_EMOTICON_THEMES
-  kDebug() << "Loading " << themeName << " as " << (isCustomTheme?"custom":"default") << " theme.";
+  kmDebug() << "Loading " << themeName << " as " << (isCustomTheme?"custom":"default") << " theme.";
 #endif
 
   // Change the theme name (where it is stored)
@@ -468,7 +468,7 @@ bool EmoticonTheme::loadTheme( QString themeName, bool isCustomTheme )
   if( oldThemePath == themePath_ )
   {
 #ifdef KMESSDEBUG_EMOTICON_THEMES
-    kDebug() << "Theme" << themeName << "was already loaded!";
+    kmDebug() << "Theme" << themeName << "was already loaded!";
 #endif
     return true;
   }
@@ -512,7 +512,7 @@ bool EmoticonTheme::removeEmoticon( QString shortcut )
   }
 
 #ifdef KMESSDEBUG_EMOTICON_THEMES
-  kDebug() << "Removing emoticon" << shortcut << ".";
+  kmDebug() << "Removing emoticon" << shortcut << ".";
 #endif
 
   foreach( Emoticon *emoticon, emoticons_ )
@@ -555,7 +555,7 @@ bool EmoticonTheme::renameEmoticon( QString oldShortcut, QString newShortcut )
   }
 
 #ifdef KMESSDEBUG_EMOTICON_THEMES
-  kDebug() << "Renaming emoticon" << oldShortcut << "to" << newShortcut << ".";
+  kmDebug() << "Renaming emoticon" << oldShortcut << "to" << newShortcut << ".";
 #endif
 
   foreach( Emoticon *emoticon, emoticons_ )
@@ -607,7 +607,7 @@ bool EmoticonTheme::saveTheme()
   if( ! dir.exists() )
   {
     // The theme hasn't been created!
-    kWarning() << "Couldn't create the new theme folder '" << themePath_ << "'!";
+    kmWarning() << "Couldn't create the new theme folder '" << themePath_ << "'!";
 
     return false;
   }
@@ -616,14 +616,14 @@ bool EmoticonTheme::saveTheme()
   QFile xmlFile( themeFileName );
 
 #ifdef KMESSDEBUG_EMOTICON_THEMES
-  kDebug() << "Saving emoticons to theme XML: '" << themeFileName << "'";
+  kmDebug() << "Saving emoticons to theme XML: '" << themeFileName << "'";
 #endif
 
 
   // Open the destination XML file
   if( ! xmlFile.open( QIODevice::WriteOnly ) )
   {
-    kWarning() << "Save failed - couldn't open file '" << themeFileName << "'.";
+    kmWarning() << "Save failed - couldn't open file '" << themeFileName << "'.";
     KMessageBox::sorry( 0, i18n("Could not save the emoticon theme. Make sure you have permission to write to the theme folder '%1'.",  themePath_ ) );
     return false;
   }
@@ -715,7 +715,7 @@ void EmoticonTheme::updateCache()
   QFileInfo file;
 
 #ifdef KMESSDEBUG_EMOTICON_THEMES
-  kDebug() << "Updating the caches.";
+  kmDebug() << "Updating the caches.";
 #endif
 
   // Remove all replacements, some emoticons may be no longer valid
@@ -732,7 +732,7 @@ void EmoticonTheme::updateCache()
     if( ! emoticon->isValid() )
     {
 #ifdef KMESSDEBUG_EMOTICON_THEMES
-      kDebug() << "Invalid emoticon '" << emoticon->getPicturePath()
+      kmDebug() << "Invalid emoticon '" << emoticon->getPicturePath()
                 << "' with code: " << emoticon->getShortcut() << endl;
 #endif
       continue;
@@ -777,7 +777,7 @@ void EmoticonTheme::updateCache()
   }
 
 #ifdef KMESSDEBUG_EMOTICON_THEMES
-  kDebug() << "Cache contains " << largeReplacements_.count() << " emoticon shortcuts.";
+  kmDebug() << "Cache contains " << largeReplacements_.count() << " emoticon shortcuts.";
 #endif
 
   // Cache the patterns.
@@ -815,7 +815,7 @@ void EmoticonTheme::updateTitles()
   }
 
 #ifdef KMESSDEBUG_EMOTICON_THEMES
-  kDebug() << "Updating standard emoticons names...";
+  kmDebug() << "Updating standard emoticons names...";
 #endif
 
   QHash<QString,QString> emoticonTitles;
@@ -926,7 +926,7 @@ bool EmoticonTheme::updateTheme( const QString& themeDir )
   QFile xmlFile( themeFileName );
 
 #ifdef KMESSDEBUG_EMOTICON_THEMES
-  kDebug() << "Updating emoticons from theme XML: '" << themeFileName << "'";
+  kmDebug() << "Updating emoticons from theme XML: '" << themeFileName << "'";
 #endif
 
 
@@ -934,7 +934,7 @@ bool EmoticonTheme::updateTheme( const QString& themeDir )
   if( ! xmlFile.open( QIODevice::ReadOnly ) )
   {
 #ifdef KMESSDEBUG_EMOTICON_THEMES
-    kDebug() << "Could not open '" << themeFileName << "'";
+    kmDebug() << "Could not open '" << themeFileName << "'";
 #endif
     return false;
   }
@@ -945,7 +945,7 @@ bool EmoticonTheme::updateTheme( const QString& themeDir )
   if( ! xml.setContent( xmlFile.readAll(), false, &xmlError ) )
   {
 #ifdef KMESSDEBUG_EMOTICON_THEMES
-    kDebug() << "Failure parsing '" << themeFileName << "': " << xmlError;
+    kmDebug() << "Failure parsing '" << themeFileName << "': " << xmlError;
 #endif
 
     xmlFile.close();
@@ -976,7 +976,7 @@ bool EmoticonTheme::updateTheme( const QString& themeDir )
   }
 
 #ifdef KMESSDEBUG_EMOTICON_THEMES
-  kDebug() << "Updated " << themeFiles.count() << " emoticons, setting them up.";
+  kmDebug() << "Updated " << themeFiles.count() << " emoticons, setting them up.";
 #endif
 
   // Loop through all current emoticons.
