@@ -154,7 +154,7 @@ InitialView::InitialView( QWidget *parent )
 InitialView::~InitialView()
 {
 #ifdef KMESSDEBUG_INITIALVIEW
-  kDebug() << "DESTROYED.";
+  kmDebug() << "DESTROYED.";
 #endif
 }
 
@@ -229,7 +229,7 @@ void InitialView::changedAccount( QString oldName, QString newName )
 
   if( ! foundItem )
   {
-    kWarning() << "Account not found in pulldown list!";
+    kmWarning() << "Account not found in pulldown list!";
   }
 }
 
@@ -247,14 +247,14 @@ void InitialView::changedAccount( QString oldName, QString newName )
 void InitialView::reconnect( QString handle, bool connectImmediately )
 {
 #ifdef KMESSDEBUG_INITIALVIEW
-  kDebug() << "Reconnecting account" << handle;
+  kmDebug() << "Reconnecting account" << handle;
 #endif
 
   Account *account = accounts_[ handle ];
   if( account == 0 )
   {
 #ifdef KMESSDEBUG_INITIALVIEW
-    kDebug() << "Account not found, aborting.";
+    kmDebug() << "Account not found, aborting.";
 #endif
 
     statusMessage( i18nc( "Status message on login screen",
@@ -267,7 +267,7 @@ void InitialView::reconnect( QString handle, bool connectImmediately )
   if( account->getPassword().isEmpty() || ! account->getSavePassword() )
   {
 #ifdef KMESSDEBUG_INITIALVIEW
-    kDebug() << "Account has no password, aborting.";
+    kmDebug() << "Account has no password, aborting.";
 #endif
 
     statusMessage( i18nc( "Status message on login screen",
@@ -285,7 +285,7 @@ void InitialView::reconnect( QString handle, bool connectImmediately )
     // We're connected to the network, try connecting now
     case Solid::Networking::Connected:
 #ifdef KMESSDEBUG_INITIALVIEW
-      kDebug() << "Network status: Connected. Scheduling reconnection.";
+      kmDebug() << "Network status: Connected. Scheduling reconnection.";
 #endif
       if( connectImmediately )
       {
@@ -302,7 +302,7 @@ void InitialView::reconnect( QString handle, bool connectImmediately )
     case Solid::Networking::Unconnected:
     case Solid::Networking::Connecting:
 #ifdef KMESSDEBUG_INITIALVIEW
-      kDebug() << "Network status: Unconnected/connecting. Waiting for a connection.";
+      kmDebug() << "Network status: Unconnected/connecting. Waiting for a connection.";
 #endif
       setEnabled( false );
       statusMessage( i18nc( "Status message on login screen",
@@ -314,7 +314,7 @@ void InitialView::reconnect( QString handle, bool connectImmediately )
     // The connection is being brought down, wait for it
     case Solid::Networking::Disconnecting:
 #ifdef KMESSDEBUG_INITIALVIEW
-      kDebug() << "Network status: disconnecting. Waiting a moment for reconnection.";
+      kmDebug() << "Network status: disconnecting. Waiting a moment for reconnection.";
 #endif
       reconnectionRemainingSeconds_ = 30;
       return;
@@ -324,7 +324,7 @@ void InitialView::reconnect( QString handle, bool connectImmediately )
     case Solid::Networking::Unknown:
 
 #ifdef KMESSDEBUG_INITIALVIEW
-      kDebug() << "Network status: Unknown. Scheduling reconnection.";
+      kmDebug() << "Network status: Unknown. Scheduling reconnection.";
 #endif
       // When the user starts kmess and the connection status is unknown, connect immediately.
       if( connectImmediately )
@@ -370,7 +370,7 @@ void InitialView::slotConnectionStatusChanged( Solid::Networking::Status newStat
     case Solid::Networking::Connected:     status = "Connected";         break;
     default:                               status = "Other (not known)"; break;
   }
-  kDebug() << "The network connection status has changed to:" << status << ".";
+  kmDebug() << "The network connection status has changed to:" << status << ".";
 #endif
 
   // If Solid is unable to retrieve the status, assume we're connected
@@ -380,7 +380,7 @@ void InitialView::slotConnectionStatusChanged( Solid::Networking::Status newStat
     if( ! triedConnecting_ )
     {
 #ifdef KMESSDEBUG_INITIALVIEW
-      kDebug() << "no connection attempt active, do nothing.";
+      kmDebug() << "no connection attempt active, do nothing.";
 #endif
       statusMessage();
       setEnabled( true );
@@ -388,13 +388,13 @@ void InitialView::slotConnectionStatusChanged( Solid::Networking::Status newStat
     else
     {
 #ifdef KMESSDEBUG_INITIALVIEW
-      kDebug() << "A connection attempt was in progress, continuing...";
+      kmDebug() << "A connection attempt was in progress, continuing...";
 #endif
 
       if( ! reconnectionHandle_.isEmpty() )
       {
 #ifdef KMESSDEBUG_INITIALVIEW
-        kDebug() << "Reconnection asked, scheduling.";
+        kmDebug() << "Reconnection asked, scheduling.";
 #endif
         reconnect( reconnectionHandle_ );
       }
@@ -476,7 +476,7 @@ void InitialView::deleteAccount(Account *account)
 
   if( ! foundItem )
   {
-    kWarning() << "Account not found in pulldown list!";
+    kmWarning() << "Account not found in pulldown list!";
   }
 }
 
@@ -675,7 +675,7 @@ void InitialView::setEnabled( bool isEnabled )
 void InitialView::slotConnectClicked()
 {
 #ifdef KMESSDEBUG_INITIALVIEW
-  kDebug() << "Connect button clicked," << ( isConnectingUI_ ? "disconnecting" : "connecting" );
+  kmDebug() << "Connect button clicked," << ( isConnectingUI_ ? "disconnecting" : "connecting" );
 #endif
 
   // The button was acting as Disconnect button when it was clicked
@@ -751,7 +751,7 @@ bool InitialView::startConnecting( const QString handle, bool emitConnectionSign
   }
 
 #ifdef KMESSDEBUG_INITIALVIEW
-  kDebug() << "Connecting with handle:" << handle;
+  kmDebug() << "Connecting with handle:" << handle;
 #endif
 
   // Disable the widgets to start connecting
