@@ -22,6 +22,7 @@
 #include "emoticonmanager.h" //
 
 #include "chat/chat.h"
+#include "chat/chathistorymanager.h"
 #include "chat/chatmaster.h"
 #include "contact/contact.h"
 #include "contact/group.h"
@@ -30,6 +31,7 @@
 #include "dialogs/awaymessagedialog.h"
 #include "dialogs/chathistorydialog.h"
 #include "dialogs/contactaddeduserdialog.h"
+#include "dialogs/contactaddeduserwidget.h"
 #include "dialogs/listexportdialog.h"
 #include "dialogs/transferwindow.h"
 #include "model/contactlist.h"
@@ -38,6 +40,7 @@
 #include "notification/chatnotification.h"
 #include "notification/contactstatusnotification.h"
 #include "notification/newemailnotification.h"
+#include "notification/addressbooknotifications.h"
 #include "notification/systemtraywidget.h"
 #include "settings/accountsettingsdialog.h"
 #include "utils/idletimer.h"
@@ -46,6 +49,7 @@
 #include "utils/kmessshared.h"
 #include "utils/nowlisteningclient.h"
 #include "utils/richtextparser.h"
+#include "utils/faderwidget.h"
 #include "account.h"
 #include "accountsmanager.h"
 #include "accountaction.h"
@@ -72,6 +76,8 @@
 #include <KStatusBar>
 #include <KToggleAction>
 
+
+
 #ifdef KMESSTEST
   #include "dialogs/networkwindow.h"
 #endif
@@ -83,6 +89,8 @@ KMess::KMess( QWidget *parent )
    chatNotification_(0),
    contactStatusNotification_(0),
    newEmailNotification_(0),
+   addressBookNotifications_(0),
+   contactAddedUserDialog_(0),
    idleTimer_(0),
    initialized_(false),
    initialView_(0),
@@ -98,7 +106,7 @@ KMess::KMess( QWidget *parent )
 KMess::~KMess()
 {
 #ifdef KMESSDEBUG_KMESS
-  kDebug() << "shutting down KMess...";
+  kmDebug() << "shutting down KMess...";
 #endif
 
   /*
@@ -140,6 +148,7 @@ KMess::~KMess()
   delete newEmailNotification_;
   delete nowListeningClient_;
   delete msnNotificationConnection_;
+  delete addressBookNotifications_;
 
   AccountsManager::destroy();
   CurrentAccount::destroy();
@@ -150,7 +159,7 @@ KMess::~KMess()
 #endif
 
 #ifdef KMESSDEBUG_KMESS
-  kDebug() << "DESTROYED.";
+  kmDebug() << "DESTROYED.";
 #endif
 }
 
@@ -203,7 +212,7 @@ void KMess::addNewContact()
     return;
   }
 #ifdef KMESSDEBUG_KMESS
-  kDebug() << "Adding " << newHandle << "to groups: " << groupsId;
+  kmDebug() << "Adding " << newHandle << "to groups: " << groupsId;
 #endif
 
   // Check if the contact is already in contact list
@@ -238,7 +247,7 @@ void KMess::addNewGroup()
   KMESS_ASSERT( msnNotificationConnection_ != 0 );
 #endif
 #ifdef KMESSDEBUG_KMESS
-  kDebug();
+  kmDebug();
 #endif
   QString newGroupName;
   bool    okPressed = false;
@@ -276,7 +285,7 @@ void KMess::applicationClosing()
   if( chatMaster_ != 0 )
   {
 #ifdef KMESSDEBUG_KMESS
-    kDebug() << "destroying chat master";
+    kmDebug() << "destroying chat master";
 #endif
 
     // Close the chat windows earlier, so logs are saved.
@@ -293,7 +302,7 @@ void KMess::slotAccountChanged( Account *account, QString oldHandle, QString old
   QString newHandle( account->getHandle() );
 
 #ifdef KMESSDEBUG_KMESS
-  kDebug() << "Saving UI settings for" << newHandle;
+  kmDebug() << "Saving UI settings for" << newHandle;
 #endif
 
   if ( msnNotificationConnection_ != 0 )
@@ -321,7 +330,7 @@ void KMess::slotAccountChanged( Account *account, QString oldHandle, QString old
   if( initialView_ )
   {
 #ifdef KMESSDEBUG_KMESS
-  kDebug() << "Updating initial view";
+  kmDebug() << "Updating initial view";
 #endif
     // Notify the initial view when the account handle has changed.
     initialView_->changedAccount( oldHandle, newHandle );
@@ -399,7 +408,7 @@ void KMess::changeStatus( QAction *action )
 void KMess::changeStatus( Status newStatus, QString autoReplyMessage )
 {
 #ifdef KMESSDEBUG_KMESS
-  kDebug() << "Selected status:" << MsnStatus::getCode( newStatus );
+  kmDebug() << "Selected status:" << MsnStatus::getCode( newStatus );
 #endif
 
   // Is the status is set manually, idle is forced.
@@ -433,7 +442,7 @@ void KMess::changedNowListeningSettings()
   nowListeningClient_->setEnabled( currentAccount_->getShowNowListening() && isOnline );
 
 #ifdef KMESSDEBUG_KMESS
-  kDebug() << "Now listening setting is now"
+  kmDebug() << "Now listening setting is now"
            << ( currentAccount_->getShowNowListening() ? "enabled" : "disabled") << endl;
 #endif
 }
@@ -486,12 +495,12 @@ void KMess::changedStatus( Account *account )
   }
   else
   {
-    kWarning() << "Changed status dropdown without an account set!";
+    kmWarning() << "Changed status dropdown without an account set!";
     return;
   }
 
 #ifdef KMESSDEBUG_KMESS
-  kDebug() << "Changed status to" << MsnStatus::getCode( newStatus )
+  kmDebug() << "Changed status to" << MsnStatus::getCode( newStatus )
            << "Autoreply is" <<  currentAccount_->getAutoreply() << endl;
 #endif
 
@@ -528,16 +537,23 @@ void KMess::changeViewMode(int mode)
 void KMess::showContactAddedUserDialog( const QString handle )
 {
 #ifdef KMESSDEBUG_KMESS
-  kDebug() << "Contact" << handle << "added user, showing dialog.";
+  kmDebug() << "Contact" << handle << "added user, showing dialog.";
 #endif
 
   // Show a dialog and let the user choose whether to add, allow, or block the contact.
-  ContactAddedUserDialog *dialog = new ContactAddedUserDialog( handle , handle );
+  if ( !contactAddedUserDialog_ )
+  {
+    contactAddedUserDialog_ = new ContactAddedUserDialog( handle , handle );
+  }
+  else
+  {
+    contactAddedUserDialog_->addTab( handle, handle );
+  }
 
-  connect( dialog, SIGNAL(                       userChoice(const QString&,const QStringList&,const int) ),
-           this,   SLOT  ( slotContactAddedUserDialogChoice(const QString&,const QStringList&,const int) ) );
+  connect( contactAddedUserDialog_,  SIGNAL(                    userChoice( const QString&, const QStringList&, const int)),
+           this,                     SLOT( slotContactAddedUserDialogChoice( const QString&, const QStringList&, const int )));
 
-  dialog->show();
+  contactAddedUserDialog_->show();
 }
 
 
@@ -617,7 +633,7 @@ void KMess::showRemoveGroupDialog(QString groupId)
   // If the group was not found, bail out
   if(group == 0)
   {
-    kDebug() << "Couldn't find a matching group.";
+    kmDebug() << "Couldn't find a matching group.";
     return;
   }
 
@@ -658,7 +674,7 @@ void KMess::showRenameGroupDialog( QString groupId )
   // If the group was found
   if ( group == 0 )
   {
-    kDebug() << "Couldn't find a matching group.";
+    kmDebug() << "Couldn't find a matching group.";
     return;
   }
 
@@ -698,7 +714,7 @@ void KMess::showChatHistory( const QString &handle )
 {
   ChatHistoryDialog *dialog = new ChatHistoryDialog( this );
 
-  dialog->setContact( handle );
+  dialog->setInitialContact( currentAccount_->getHandle(), handle );
   dialog->show();
 }
 
@@ -722,7 +738,7 @@ void KMess::checkAutologin(QString handle)
   if ( handle.isEmpty() )
   {
 #ifdef KMESSDEBUG_KMESS
-    kDebug() << "No handle was given, find an account that uses autologin.";
+    kmDebug() << "No handle was given, find an account that uses autologin.";
 #endif
 
     const QList<Account*> accountsList = AccountsManager::instance()->getAccounts();
@@ -741,7 +757,7 @@ void KMess::checkAutologin(QString handle)
   else
   {
 #ifdef KMESSDEBUG_KMESS
-  kDebug() << "finding account: " << handle << ".";
+  kmDebug() << "finding account: " << handle << ".";
 #endif
     loginAccount = AccountsManager::instance()->getAccountByHandle(handle);
   }
@@ -820,13 +836,16 @@ void KMess::connected()
   // Show the connected message
   statusMessage( i18n("Connected"), false );
 
+  // Start the chat history manager
+  ChatHistoryManager::setAccount( currentAccount_->getHandle() );
+
   // The connection was successful, this means the supplied
   // email and password were correct: save the settings now
   if( ! currentAccount_->getSavePassword() )
   {
     // we reset the password here if it shouldn't be saved (so accountsmanager removes it)
 #ifdef KMESSDEBUG_KMESS
-    kDebug() << "Resetting password in currentAccount because it shouldn't be saved.";
+    kmDebug() << "Resetting password in currentAccount because it shouldn't be saved.";
 #endif
     currentAccount_->setPassword( "" );
   }
@@ -856,7 +875,7 @@ void KMess::connectWithAccount(Account *account)
   if(KMESS_NULL(account)) return;
 
 #ifdef KMESSDEBUG_KMESS
-  kDebug() << "Connecting account:" << account->getHandle();
+  kmDebug() << "Connecting account:" << account->getHandle();
 #endif
 
   startConnection( account );
@@ -868,7 +887,7 @@ void KMess::connectWithAccount(Account *account)
 void KMess::connectWithAccount(QString handle, QString password, bool rememberAccount, bool rememberPassword, bool autologin, Status initialStatus )
 {
 #ifdef KMESSDEBUG_KMESS
-  kDebug() << "Connecting with handle " << handle;
+  kmDebug() << "Connecting with handle " << handle;
 #endif
 
   // Try to find an existing account
@@ -942,7 +961,7 @@ void KMess::connectWithAccount(QString handle, QString password, bool rememberAc
 void KMess::reconnect()
 {
 #ifdef KMESSDEBUG
-  kDebug() << "Reconnecting";
+  kmDebug() << "Reconnecting";
 #endif
   connectWithAccount( currentAccount_ );
 }
@@ -953,7 +972,7 @@ void KMess::reconnect()
 bool KMess::createDirectories()
 {
 #ifdef KMESSDEBUG_KMESS
-  kDebug() << "Creating default directories.";
+  kmDebug() << "Creating default directories.";
 #endif
   KStandardDirs *dirs   = KGlobal::dirs();
   QString        localKdeDir;
@@ -961,7 +980,7 @@ bool KMess::createDirectories()
 
   localKdeDir = dirs->localkdedir();
 #ifdef KMESSDEBUG_KMESS
-  kDebug() << "Local KDE dir is " << localKdeDir << ".";
+  kmDebug() << "Local KDE dir is " << localKdeDir << ".";
 #endif
   appsDir.setPath( localKdeDir + "/share/apps" );
 
@@ -969,12 +988,12 @@ bool KMess::createDirectories()
   {
     kmessDir.setPath( appsDir.absolutePath() + "/kmess" );
 #ifdef KMESSDEBUG_KMESS
-    kDebug() << "kmess dir should be at " << kmessDir.absolutePath() << ".";
+    kmDebug() << "kmess dir should be at " << kmessDir.absolutePath() << ".";
 #endif
     if ( !kmessDir.exists() )
     {
 #ifdef KMESSDEBUG_KMESS
-      kDebug() << "Creating kmess dir.";
+      kmDebug() << "Creating kmess dir.";
 #endif
       appsDir.mkdir( kmessDir.absolutePath() );
     }
@@ -982,7 +1001,7 @@ bool KMess::createDirectories()
 #ifdef KMESSDEBUG_KMESS
   else
   {
-    kDebug() << "" << appsDir.absolutePath() << " doesn't exist!";
+    kmDebug() << "" << appsDir.absolutePath() << " doesn't exist!";
   }
 #endif
 #ifdef KMESSTEST
@@ -1029,26 +1048,31 @@ void KMess::slotAccountDeleted( Account *account )
 void KMess::slotContactAddedUserDialogChoice( const QString &handle, const QStringList &groupIds, const int code )
 {
 #ifdef KMESSDEBUG_KMESS
-  kDebug() << "Contact" << handle << "added user, who has choosen option:" << code
+  kmDebug() << "Contact" << handle << "added user, who has choosen option:" << code
            << "Group list:" << groupIds;
 #endif
 
-  switch( (ContactAddedUserDialog::ReturnCode) code )
+  switch( (ContactAddedUserWidget::ReturnCode) code )
   {
-    case ContactAddedUserDialog::ADD:
+    case ContactAddedUserWidget::ADD:
       // Add the contact to the allowed and friends lists
       msnNotificationConnection_->addNewContact( handle, groupIds );
       break;
 
-    case ContactAddedUserDialog::ALLOW:
+    case ContactAddedUserWidget::ALLOW:
       // Add the contact to the allowed list
       msnNotificationConnection_->allowContact( handle );
       break;
 
-    case ContactAddedUserDialog::BLOCK:
+    case ContactAddedUserWidget::BLOCK:
       // Add the contact to the blocked list.
       msnNotificationConnection_->blockContact( handle );
       break;
+
+    case ContactAddedUserWidget::IGNORE:
+    default:
+      // Action ignored
+      break;
   }
 }
 
@@ -1063,7 +1087,7 @@ void KMess::slotContactAddedUserDialogChoice( const QString &handle, const QStri
 void KMess::slotConnectionStatusChanged( Solid::Networking::Status newStatus )
 {
 #ifdef KMESSDEBUG_KMESSINTERFACE
-  kDebug() << "Solid status changed to " << newStatus;
+  kmDebug() << "Solid status changed to " << newStatus;
 #endif
 
   // If Solid is unable to retrieve the status, assume we're connected
@@ -1095,7 +1119,7 @@ void KMess::disconnectClicked()
   KMESS_ASSERT( msnNotificationConnection_ != 0 );
 #endif
 #ifdef KMESSDEBUG_KMESSINTERFACE
-  kDebug() << "Disconnecting.";
+  kmDebug() << "Disconnecting.";
 #endif
   msnNotificationConnection_->closeConnection();
 }
@@ -1109,7 +1133,7 @@ void KMess::disconnected()
   KMESS_ASSERT( chatMaster_ != 0 );
 #endif
 #ifdef KMESSDEBUG_KMESS
-  kDebug() << "Disconnected.";
+  kmDebug() << "Disconnected.";
 #endif
 
   // this method is also called when initializing the GUI, avoid mangling the settings at that point.
@@ -1127,14 +1151,14 @@ void KMess::disconnected()
       if( account->isDeleted() )
       {
 #ifdef KMESSDEBUG_KMESS
-        kDebug() << "Account" << account->getHandle() << "was deleted, removing menu items.";
+        kmDebug() << "Account" << account->getHandle() << "was deleted, removing menu items.";
 #endif
         slotAccountDeleted( account );
       }
       else
       {
 #ifdef KMESSDEBUG_KMESS
-        kDebug() << "Saving the CurrentAccount.";
+        kmDebug() << "Saving the CurrentAccount.";
 #endif
 
         // Transfer account settings
@@ -1163,14 +1187,14 @@ void KMess::disconnected()
   currentAccount_->setStatus( STATUS_OFFLINE );
   currentAccount_->setAutoreply( false );
 #ifdef KMESSDEBUG_KMESS
-  kDebug() << "Swap views.";
+  kmDebug() << "Swap views.";
 #endif
 
   // Show the screen where to insert login details to log back in
   switchViewToInitialScreen();
 
 #ifdef KMESSDEBUG_KMESS
-  kDebug() << "Blank the caption.";
+  kmDebug() << "Blank the caption.";
 #endif
 
   // Set the caption
@@ -1184,12 +1208,12 @@ bool KMess::initialize()
 {
   if ( initialized_ )
   {
-    kDebug() << "Already initialized.";
+    kmDebug() << "Already initialized.";
     return false;
   }
 
 #ifdef KMESSDEBUG_KMESS
-  kDebug() << "initializing main class.";
+  kmDebug() << "initializing main class.";
 #endif
 
   // Initialize the Rich Text parser engine
@@ -1199,52 +1223,52 @@ bool KMess::initialize()
   currentAccount_ = CurrentAccount::instance();
   if ( currentAccount_ == 0 )
   {
-    kDebug() << "Couldn't get a pointer to the instance of the current account.";
+    kmDebug() << "Couldn't get a pointer to the instance of the current account.";
     return false;
   }
   if ( !KMessInterface::initialize() )
   {
-    kDebug() << "Couldn't initialize ancestor.";
+    kmDebug() << "Couldn't initialize ancestor.";
     return false;
   }
   if ( !initMsnNotificationConnection() )
   {
-    kDebug() << "Couldn't initialize the MsnNotificationConnection class.";
+    kmDebug() << "Couldn't initialize the MsnNotificationConnection class.";
     return false;
   }
   if ( !initIdleTimer() )
   {
-    kDebug() << "Couldn't initialize the IdleTimer class.";
+    kmDebug() << "Couldn't initialize the IdleTimer class.";
     return false;
   }
   if ( !initChatMaster() )
   {
-    kDebug() << "Couldn't initialize the Chat master.";
+    kmDebug() << "Couldn't initialize the Chat master.";
     return false;
   }
   if ( !initNotifications() )
   {
-    kDebug() << "Couldn't initialize the notifications.";
+    kmDebug() << "Couldn't initialize the notifications.";
     return false;
   }
   if ( !initNowListening() )
   {
-    kDebug() << "Couldn't initialize the now listening support.";
+    kmDebug() << "Couldn't initialize the now listening support.";
     return false;
   }
   if ( !initEmoticonManager() )
   {
-    kDebug() << "Couldn't initialize the emoticon manager.";
+    kmDebug() << "Couldn't initialize the emoticon manager.";
     return false;
   }
   if ( !initProxy() )
   {
-    kDebug() << "Couldn't initialize the proxy support.";
+    kmDebug() << "Couldn't initialize the proxy support.";
     return false;
   }
   if ( !createDirectories() )
   {
-    kDebug() << "Couldn't create local KDE directories.";
+    kmDebug() << "Couldn't create local KDE directories.";
     return false;
   }
 
@@ -1256,7 +1280,6 @@ bool KMess::initialize()
   // Connect current account signals for Now Listening
   connect( currentAccount_, SIGNAL(               changedStatus() ),
            this,            SLOT  ( changedNowListeningSettings() ));
-
   // Connect current account
   connect( currentAccount_, SIGNAL(         changedFriendlyName() ),
            this,            SLOT  (            setCaptionToUser() ));
@@ -1295,7 +1318,7 @@ bool KMess::initialize()
   // Added debug here because this has a potential to cause problems..
   // It would be better if each class got things right from it's construtor or initialize method.
 #ifdef KMESSDEBUG_KMESS
-  kDebug() << "faking disconnect signal.";
+  kmDebug() << "faking disconnect signal.";
 #endif
   disconnected();
 
@@ -1304,7 +1327,7 @@ bool KMess::initialize()
 
   // All done, mark as initialized
 #ifdef KMESSDEBUG_KMESS
-  kDebug() << "main class is initialized.";
+  kmDebug() << "main class is initialized.";
 #endif
 
   initialized_ = true;
@@ -1321,18 +1344,18 @@ bool KMess::initChatMaster()
 #endif
   if ( msnNotificationConnection_ == 0 )
   {
-    kDebug() << "The notification connection must be initialized before the chat master.";
+    kmDebug() << "The notification connection must be initialized before the chat master.";
     return false;
   }
   chatMaster_ = new ChatMaster( this );
   if ( chatMaster_ == 0 )
   {
-    kDebug() << "Couldn't create the chat master.";
+    kmDebug() << "Couldn't create the chat master.";
     return false;
   }
   if ( !chatMaster_->initialize() )
   {
-    kDebug() << "Couldn't initialize the chat master.";
+    kmDebug() << "Couldn't initialize the chat master.";
     return false;
   }
 
@@ -1344,7 +1367,7 @@ bool KMess::initChatMaster()
   connect( chatMaster_,                SIGNAL(     unblockContact(QString) ),
            msnNotificationConnection_, SLOT  (     unblockContact(QString) ) );
   connect( chatMaster_,                SIGNAL(         addContact(QString) ),
-           msnNotificationConnection_, SLOT  (      addNewContact(QString) ) );
+           msnNotificationConnection_, SLOT  (      addNewContact(QString, const QStringList) ) );
   connect( chatMaster_,                SIGNAL(      removeContact(QString,bool) ),
            msnNotificationConnection_, SLOT  (      removeContact(QString,bool) ) );
   connect( chatMaster_,                SIGNAL(       allowContact(QString) ),
@@ -1373,7 +1396,7 @@ bool KMess::initEmoticonManager()
 {
   if ( msnNotificationConnection_ == 0 )
   {
-    kDebug() << "MsnNotificationConnection must be initialized before EmoticonManager";
+    kmDebug() << "MsnNotificationConnection must be initialized before EmoticonManager";
     return false;
   }
 
@@ -1398,7 +1421,7 @@ bool KMess::initIdleTimer()
   idleTimer_ = new IdleTimer();
   if ( idleTimer_ == 0 )
   {
-    kDebug() << "Couldn't create the idle timer.";
+    kmDebug() << "Couldn't create the idle timer.";
     return false;
   }
   // Connect the timer to signal when the user is away.
@@ -1424,7 +1447,7 @@ bool KMess::initMsnNotificationConnection()
   initialized = msnNotificationConnection_->initialize();
   if ( !initialized )
   {
-    kDebug() << "Couldn't initialize MsnNotificationConnection.";
+    kmDebug() << "Couldn't initialize MsnNotificationConnection.";
     return false;
   }
 
@@ -1454,18 +1477,19 @@ bool KMess::initNotifications()
   KMESS_ASSERT( chatNotification_           == 0 );
   KMESS_ASSERT( contactStatusNotification_  == 0 );
   KMESS_ASSERT( newEmailNotification_       == 0 );
+  KMESS_ASSERT( addressBookNotifications_     == 0 );
 #endif
 
   const ContactList *contactList;
 
   if ( systemTrayWidget_ == 0 )
   {
-    kDebug() << "The system tray widget must be initialized before the notifications!";
+    kmDebug() << "The system tray widget must be initialized before the notifications!";
     return false;
   }
   if ( msnNotificationConnection_ == 0 )
   {
-    kDebug() << "The notification connection must be initialized before the notifications!";
+    kmDebug() << "The notification connection must be initialized before the notifications!";
     return false;
   }
 
@@ -1486,7 +1510,7 @@ bool KMess::initNotifications()
     }
 
     // Always show warning at the console.
-    kWarning() << "Sounds and notifications will not be available, the file 'kmess/kmess.notifyrc' could not be found.";
+    kmWarning() << "Sounds and notifications will not be available, the file 'kmess/kmess.notifyrc' could not be found.";
 
     // Show the message in the GUI as well.
     // Allow to user to choose "don't show this message again", in case he/she doesn't know how to fix it.
@@ -1512,8 +1536,9 @@ bool KMess::initNotifications()
   chatNotification_          = new ChatNotification         ( notificationManager_ );
   contactStatusNotification_ = new ContactStatusNotification( notificationManager_ );
   newEmailNotification_      = new NewEmailNotification     ( notificationManager_ );
+  addressBookNotifications_  = new AddressBookNotifications  ( notificationManager_ );
 
-    // Connect the chat messages notification signals
+  // Connect the chat messages notification signals
   connect( chatMaster_,                 SIGNAL( newChatMessage(const ChatMessage&, Chat*)                   ),
            chatNotification_,           SLOT  (         notify(const ChatMessage&, Chat*)                   ) );
   connect( chatNotification_,           SIGNAL(      raiseChat(Chat*,bool)                                  ),
@@ -1527,10 +1552,13 @@ bool KMess::initNotifications()
   connect( contactList,                 SIGNAL( contactChangedStatus(Contact*,bool)                          ),
            contactStatusNotification_,  SLOT  (               notify(Contact*,bool)                          ) );
 
-    // Connect the "Email notification" signals
+  // Connect the "Email notification" signals.
   connect( msnNotificationConnection_,  SIGNAL( newEmail(QString, QString, bool, QString, QString, QString) ),
            newEmailNotification_,       SLOT  (   notify(QString, QString, bool, QString, QString, QString) ) );
 
+  connect( msnNotificationConnection_, SIGNAL( addressBookChanged( const QString&, AddressBookService::AddressBookUpdate ) ),
+           addressBookNotifications_,  SLOT(               notify( const QString&, AddressBookService::AddressBookUpdate ) ) );
+
   // Connect the "Chat request" signals
   connect( contactStatusNotification_,  SIGNAL(   startChat(QString) ),
                           chatMaster_,  SLOT  ( requestChat(QString) ) );
@@ -1540,6 +1568,7 @@ bool KMess::initNotifications()
   KMESS_ASSERT( chatNotification_          != 0 );
   KMESS_ASSERT( contactStatusNotification_ != 0 );
   KMESS_ASSERT( newEmailNotification_      != 0 );
+  KMESS_ASSERT( addressBookNotifications_  != 0 );
 #endif
 
   return true;
@@ -1552,7 +1581,7 @@ bool KMess::initNowListening()
 {
   if ( msnNotificationConnection_ == 0 )
   {
-    kDebug() << "The notification connection must be initialized before the now listening support!";
+    kmDebug() << "The notification connection must be initialized before the now listening support!";
     return false;
   }
 
@@ -1576,7 +1605,7 @@ bool KMess::initProxy()
   if( ! KProtocolManager::useProxy() )
   {
 #ifdef KMESSDEBUG_KMESS
-    kDebug() << "No proxy support is needed (kde's proxy is turned off).";
+    kmDebug() << "No proxy support is needed (kde's proxy is turned off).";
 #endif
     return true;
   }
@@ -1587,13 +1616,13 @@ bool KMess::initProxy()
   if( proxyAddress.isEmpty() || proxyAddress == "DIRECT" )
   {
 #ifdef KMESSDEBUG_KMESS
-    kDebug() << "No proxy support is needed (no proxy is needed for HTTPS traffic).";
+    kmDebug() << "No proxy support is needed (no proxy is needed for HTTPS traffic).";
 #endif
     return true;
   }
 
 #ifdef KMESSDEBUG_KMESS
-  kDebug() << "Proxy URL:" << proxyAddress;
+  kmDebug() << "Proxy URL:" << proxyAddress;
 #endif
 
   KUrl proxyUrl( proxyAddress );
@@ -1638,7 +1667,7 @@ bool KMess::isConnected()
 void KMess::readGlobalProperties( KConfig *sessionConfig )
 {
 #ifdef KMESSDEBUG_KMESS
-  kDebug() << "Loading current state...";
+  kmDebug() << "Loading current state...";
 #endif
 
   KConfigGroup settings( sessionConfig->group( "state" ) );
@@ -1660,7 +1689,7 @@ void KMess::readGlobalProperties( KConfig *sessionConfig )
 void KMess::saveGlobalProperties( KConfig *sessionConfig )
 {
 #ifdef KMESSDEBUG_KMESS
-  kDebug() << "Saving current state...";
+  kmDebug() << "Saving current state...";
 #endif
 
   KConfigGroup settings( sessionConfig->group( "state" ) );
@@ -1681,7 +1710,7 @@ void KMess::saveGlobalProperties( KConfig *sessionConfig )
 void KMess::readProperties( const KConfigGroup &config )
 {
 #ifdef KMESSDEBUG_KMESS
-  kDebug() << "Reading properties";
+  kmDebug() << "Reading properties";
 #endif
 
   KConfigGroup group;
@@ -1720,7 +1749,7 @@ void KMess::saveProperties( KConfigGroup &config )
   KMessInterface::saveProperties( group );
 
 #ifdef KMESSDEBUG_KMESS
-  kDebug() << "saving properties";
+  kmDebug() << "saving properties";
 #endif
 
   // Have all the accounts save their properties
@@ -1738,7 +1767,7 @@ void KMess::saveProperties( KConfigGroup &config )
     {
       // Move the settings from the current account to the account
 #ifdef KMESSDEBUG_KMESS
-      kDebug() << "copying settings from CurrentAccount to the Account object.";
+      kmDebug() << "copying settings from CurrentAccount to the Account object.";
 #endif
       account->copyAccount( currentAccount_ );
     }
@@ -1838,7 +1867,7 @@ void KMess::startConnection( Account *account )
 
   // Copy the account to the current account
 #ifdef KMESSDEBUG_KMESS
-  kDebug() << "copying data of account" << account->getHandle() << "to the CurrentAccount object.";
+  kmDebug() << "copying data of account" << account->getHandle() << "to the CurrentAccount object.";
 #endif
   currentAccount_->copyAccount( account );
 
@@ -1866,11 +1895,6 @@ void KMess::switchViewToContactList()
     view_->deleteLater();
     view_ = 0;
   }
-  if( initialView_ )
-  {
-    initialView_->deleteLater();
-    initialView_ = 0;
-  }
 
 #ifdef KMESSTEST
   KMESS_ASSERT( msnNotificationConnection_ != 0 );
@@ -1920,6 +1944,22 @@ void KMess::switchViewToContactList()
 
   // Set it as the application's main widget
   setCentralWidget( view_ );
+
+  bool nofade = KMessConfig::instance()->getGlobalConfig( "MainWindow" ).readEntry( "NoFadeEffect", false );
+
+  if ( ! nofade )
+  {
+    FaderWidget *fader = new FaderWidget( initialView_, view_ );
+    fader->setDuration( 1000 );
+    fader->resize( initialView_->size() );
+    fader->start();
+  }
+
+  if( initialView_ )
+  {
+    initialView_->deleteLater();
+    initialView_ = 0;
+  }
 }
 
 
@@ -2031,18 +2071,18 @@ void KMess::updateContextMenu( const QItemSelection &selection )
 void KMess::userIsIdle()
 {
 #ifdef KMESSDEBUG_IDLETIMER
-    kDebug();
+    kmDebug();
 #endif
   if ( ( currentAccount_ != 0 ) && ( msnNotificationConnection_ != 0 ) )
   {
 #ifdef KMESSDEBUG_IDLETIMER
-    kDebug() << "Current status is " << currentAccount_->getStatus() << ".";
+    kmDebug() << "Current status is " << currentAccount_->getStatus() << ".";
 #endif
     // Only change the state if the user is currently set as online
     if ( currentAccount_->getStatus() == STATUS_ONLINE )
     {
 #ifdef KMESSDEBUG_IDLETIMER
-      kDebug() << "Change status to Idle.";
+      kmDebug() << "Change status to Idle.";
 #endif
       // Request a status change to Idle
       msnNotificationConnection_->changeStatus( STATUS_IDLE );
@@ -2057,25 +2097,25 @@ void KMess::userIsIdle()
 void KMess::userIsNotIdle()
 {
 #ifdef KMESSDEBUG_IDLETIMER
-    kDebug();
+    kmDebug();
 #endif
   if ( ( currentAccount_ != 0 ) && ( msnNotificationConnection_ != 0 ) )
   {
 #ifdef KMESSDEBUG_IDLETIMER
-    kDebug() << "User is no longer idle, current status is " << currentAccount_->getStatus();
+    kmDebug() << "User is no longer idle, current status is " << currentAccount_->getStatus();
 #endif
     // Only change the state if the user is currently set as idle AND the idle status was not forced by the user
     if ( currentAccount_->getStatus() == STATUS_IDLE && ! isIdleForced_ )
     {
 #ifdef KMESSDEBUG_IDLETIMER
-      kDebug() << "Change status to Online";
+      kmDebug() << "Change status to Online";
 #endif
       // Request a status change to Online
       msnNotificationConnection_->changeStatus( STATUS_ONLINE );
     }
   }
 #ifdef KMESSDEBUG_IDLETIMER
-    kDebug() << "Done userIsNotIdle().";
+    kmDebug() << "Done userIsNotIdle().";
 #endif
 }
 
