@@ -70,7 +70,7 @@ KMessInterface::~KMessInterface()
   delete statusLabel_;
 
 #ifdef KMESSDEBUG_KMESSINTERFACE
-  kDebug() << "DESTROYED.";
+  kmDebug() << "DESTROYED.";
 #endif
 }
 
@@ -79,7 +79,7 @@ KMessInterface::~KMessInterface()
 // "Add a new contact" was selected from the menu.
 void KMessInterface::addNewContact()
 {
-  kDebug() << "not implemented";
+  kmDebug() << "not implemented";
 }
 
 // Show the chat history dialog and, if requested, that of a specific contact
@@ -87,20 +87,20 @@ void KMessInterface::showChatHistory( const QString &handle )
 {
   Q_UNUSED( handle );
 
-  kDebug() << "not implemented";
+  kmDebug() << "not implemented";
 }
 
 // "Add a new group" was selected from the menu.
 void KMessInterface::addNewGroup()
 {
-  kDebug() << "not implemented";
+  kmDebug() << "not implemented";
 }
 
 
 // The application is closing, after queryExit() was approved
 void KMessInterface::applicationClosing()
 {
-  kDebug() << "not implemented";
+  kmDebug() << "not implemented";
 }
 
 
@@ -108,7 +108,7 @@ void KMessInterface::applicationClosing()
 // A view pictures mode has been selected from the menu.
 void KMessInterface::changedListPictureSize( int /*mode*/ )
 {
-  kDebug() << "not implemented";
+  kmDebug() << "not implemented";
 }
 
 
@@ -118,7 +118,7 @@ void KMessInterface::changeStatus( QAction *action )
 {
   Q_UNUSED( action );
 
-  kDebug() << "not implemented";
+  kmDebug() << "not implemented";
 }
 
 
@@ -126,27 +126,27 @@ void KMessInterface::changeStatus( QAction *action )
 // A view mode has been selected from the menu.
 void KMessInterface::changeViewMode(int /*mode*/)
 {
-  kDebug() << "not implemented";
+  kmDebug() << "not implemented";
 }
 
 
 
 void KMessInterface::showListExportDialog()
 {
-  kDebug() << "not implemented";
+  kmDebug() << "not implemented";
 }
 
 
 
 void KMessInterface::showNetworkWindow()
 {
-  kDebug() << "not implemented";
+  kmDebug() << "not implemented";
 }
 
 
 void KMessInterface::showTransferWindow()
 {
-  kDebug() << "not implemented";
+  kmDebug() << "not implemented";
 }
 
 
@@ -303,7 +303,7 @@ void KMessInterface::createMenus()
 // "Add new account" has been selected from the menu.
 void KMessInterface::createNewAccount()
 {
-  kDebug() << "not implemented";
+  kmDebug() << "not implemented";
 }
 
 
@@ -311,7 +311,7 @@ void KMessInterface::createNewAccount()
 // Disconnect was selected from the menu.
 void KMessInterface::disconnectClicked()
 {
-  kDebug() << "not implemented";
+  kmDebug() << "not implemented";
 }
 
 
@@ -338,11 +338,11 @@ void KMessInterface::enableMenus(bool connected)
 bool KMessInterface::initialize()
 {
 #ifdef KMESSDEBUG_KMESSINTERFACE
-  kDebug() << "initializing";
+  kmDebug() << "initializing";
 #endif
   if ( initialized_ )
   {
-    kDebug() << "already initialized.";
+    kmDebug() << "already initialized.";
     return false;
   }
 
@@ -401,12 +401,12 @@ bool KMessInterface::initialize()
 
   if ( ! initSystemTrayWidget() )
   {
-    kDebug() << "Couldn't initialize the system tray widget.";
+    kmDebug() << "Couldn't initialize the system tray widget.";
     return false;
   }
 
 #ifdef KMESSDEBUG_KMESSINTERFACE
-  kDebug() << "initialized";
+  kmDebug() << "initialized";
 #endif
   return true;
 }
@@ -420,7 +420,7 @@ bool KMessInterface::initSystemTrayWidget()
   systemTrayWidget_ = new SystemTrayWidget( this ) ;
   if ( systemTrayWidget_ == 0 )
   {
-    kDebug() << "Couldn't create system tray widget.";
+    kmDebug() << "Couldn't create system tray widget.";
     return false;
   }
 
@@ -450,7 +450,7 @@ bool KMessInterface::initSystemTrayWidget()
 void KMessInterface::menuClose()
 {
 #ifdef KMESSDEBUG_KMESSINTERFACE
-  kDebug() << "'Close' was selected from the menu.";
+  kmDebug() << "'Close' was selected from the menu.";
 #endif
 
   // Hide the window
@@ -469,7 +469,7 @@ void KMessInterface::menuClose()
 void KMessInterface::menuQuit()
 {
 #ifdef KMESSDEBUG_KMESSINTERFACE
-  kDebug() << "'Quit' was selected from the menu.";
+  kmDebug() << "'Quit' was selected from the menu.";
 #endif
 
   // Tell the application manager we want to quit
@@ -493,7 +493,7 @@ bool KMessInterface::queryExit()
       kmessApp->sessionSaving() )
   {
 #ifdef KMESSDEBUG_KMESSINTERFACE
-    kDebug() << "Accepting exit request.";
+    kmDebug() << "Accepting exit request.";
 #endif
 
     return true;
@@ -504,7 +504,7 @@ bool KMessInterface::queryExit()
     // Reject the request again.
 
 #ifdef KMESSDEBUG_KMESSINTERFACE
-    kDebug() << "Rejecting exit request! Keep running with all windows hidden.";
+    kmDebug() << "Rejecting exit request! Keep running with all windows hidden.";
 #endif
 
     return false;
@@ -525,7 +525,7 @@ bool KMessInterface::queryClose()
       kmessApp->sessionSaving() )
   {
 #ifdef KMESSDEBUG_KMESSINTERFACE
-    kDebug() << "Accepting quit request.";
+    kmDebug() << "Accepting quit request.";
 #endif
 
     // Make sure that substituent also return true
@@ -543,7 +543,7 @@ bool KMessInterface::queryClose()
     systemTrayWidget_->displayCloseMessage();
 
 #ifdef KMESSDEBUG_KMESSINTERFACE
-    kDebug() << "Rejecting quit request, hiding window";
+    kmDebug() << "Rejecting quit request, hiding window";
 #endif
 
     // Only hide, disallow event
@@ -558,7 +558,7 @@ bool KMessInterface::queryClose()
 void KMessInterface::readProperties( const KConfigGroup &config )
 {
 #ifdef KMESSDEBUG_KMESSINTERFACE
-  kDebug() << "Reading properties";
+  kmDebug() << "Reading properties";
 #endif
 
   KConfigGroup group;
@@ -615,7 +615,7 @@ void KMessInterface::readProperties( const KConfigGroup &config )
 void KMessInterface::saveProperties(KConfigGroup &config)
 {
 #ifdef KMESSDEBUG_KMESSINTERFACE
-  kDebug() << "Saving properties";
+  kmDebug() << "Saving properties";
 #endif
 
   KConfigGroup group;
@@ -642,7 +642,7 @@ void KMessInterface::saveProperties(KConfigGroup &config)
   group.writeEntry("Lock Toolbar", toolBar( "mainToolBar" )->toolBarsLocked());*/
 
 #ifdef KMESSDEBUG_KMESSINTERFACE
-  kDebug() << "Done saving properties";
+  kmDebug() << "Done saving properties";
 #endif
 }
 
@@ -720,7 +720,7 @@ void KMessInterface::showStatusBar()
 // Show the user's MSN profile.
 void KMessInterface::showUserProfile()
 {
-  kDebug() << "not implemented";
+  kmDebug() << "not implemented";
 }
 
 // Change the status bar message.
@@ -732,7 +732,7 @@ void KMessInterface::statusMessage( QString message, bool isError )
     message_ = message;
 
 #ifdef KMESSDEBUG_KMESSINTERFACE
-    kDebug() << "Changed message to" << message;
+    kmDebug() << "Changed message to" << message;
 #endif
   }
 
@@ -761,7 +761,7 @@ void KMessInterface::statusMessage( QString message, bool isError )
 // The "show allowed contacts" menu item has been toggled.
 void KMessInterface::toggleShowAllowed(bool /*show*/)
 {
-  kDebug() << "not implemented";
+  kmDebug() << "not implemented";
 }
 
 
@@ -769,7 +769,7 @@ void KMessInterface::toggleShowAllowed(bool /*show*/)
 // The "show empty groups" menu item has been toggled.
 void KMessInterface::toggleShowEmpty(bool /*show*/)
 {
-  kDebug() << "not implemented";
+  kmDebug() << "not implemented";
 }
 
 
@@ -777,7 +777,7 @@ void KMessInterface::toggleShowEmpty(bool /*show*/)
 // The "show history box" menu item has been toggled.
 void KMessInterface::toggleShowHistoryBox(bool /*show*/)
 {
-  kDebug() << "not implemented";
+  kmDebug() << "not implemented";
 }
 
 
@@ -785,7 +785,7 @@ void KMessInterface::toggleShowHistoryBox(bool /*show*/)
 // The "show search in contact list" menu item has been toggled.
 void KMessInterface::toggleShowSearchFrame(bool /*show*/)
 {
-  kDebug() << "not implemented";
+  kmDebug() << "not implemented";
 }
 
 
@@ -793,7 +793,7 @@ void KMessInterface::toggleShowSearchFrame(bool /*show*/)
 // The "show offline contacts" menu item has been toggled.
 void KMessInterface::toggleShowOffline(bool /*show*/)
 {
-  kDebug() << "not implemented";
+  kmDebug() << "not implemented";
 }
 
 
@@ -801,7 +801,7 @@ void KMessInterface::toggleShowOffline(bool /*show*/)
 // The "show removed contacts" menu item has been toggled.
 void KMessInterface::toggleShowRemoved(bool /*show*/)
 {
-  kDebug() << "not implemented";
+  kmDebug() << "not implemented";
 }
 
 
