@@ -125,7 +125,7 @@ KMessView::~KMessView()
   viewModel_ = 0;
 
 #ifdef KMESSDEBUG_KMESSVIEW_GENERAL
-  kDebug() << "DESTROYED.";
+  kmDebug() << "DESTROYED.";
 #endif
 }
 
@@ -182,7 +182,7 @@ const ModelDataList KMessView::getItemData( const QModelIndex &index )
   if( ! itemIndex.isValid() || itemIndex.model() != viewModel_ )
   {
 #ifdef KMESSDEBUG_KMESSVIEW_ITEM_VISIBILITY
-    kDebug() << "Skipping an invalid item at index:" << index;
+    kmDebug() << "Skipping an invalid item at index:" << index;
 #endif
     return ModelDataList();
   }
@@ -194,7 +194,7 @@ const ModelDataList KMessView::getItemData( const QModelIndex &index )
   if( ! data.canConvert( QVariant::Map ) )
   {
 #ifdef KMESSDEBUG_KMESSVIEW_ITEM_VISIBILITY
-    kDebug() << "Skipping an item with invalid data at index:" << index;
+    kmDebug() << "Skipping an item with invalid data at index:" << index;
 #endif
     return ModelDataList();
   }
@@ -206,7 +206,7 @@ const ModelDataList KMessView::getItemData( const QModelIndex &index )
   if( itemData.isEmpty() )
   {
 #ifdef KMESSDEBUG_KMESSVIEW_ITEM_VISIBILITY
-      kDebug() << "Skipping an empty item at index:" << index;
+      kmDebug() << "Skipping an empty item at index:" << index;
 #endif
     return ModelDataList();
   }
@@ -236,28 +236,28 @@ bool KMessView::initialize( QAbstractItemModel *viewModel )
 
   if ( initialized_ )
   {
-    kDebug() << "already initialized.";
+    kmDebug() << "already initialized.";
     return false;
   }
 
   success = initContactListView( viewModel );
   if(! success)
   {
-    kDebug() << "Couldn't initialize contact list view.";
+    kmDebug() << "Couldn't initialize contact list view.";
     return false;
   }
 
   success = initContactPopup();
   if(! success)
   {
-    kDebug() << "Couldn't initialize contact popup.";
+    kmDebug() << "Couldn't initialize contact popup.";
     return false;
   }
 
   success = initGroupPopup();
   if(! success)
   {
-    kDebug() << "Couldn't initialize group popup.";
+    kmDebug() << "Couldn't initialize group popup.";
     return false;
   }
 
@@ -462,7 +462,7 @@ bool KMessView::eventFilter(QObject *obj, QEvent *event)
   &&  obj != contactListView_->viewport() )
   {
 #ifdef KMESSDEBUG_KMESSVIEW_GENERAL
-    kWarning() << "Received event '" << event->type() << "' from object '" << obj->objectName() << "'.";
+    kmWarning() << "Received event '" << event->type() << "' from object '" << obj->objectName() << "'.";
 #endif
     return false;
   }
@@ -521,7 +521,7 @@ bool KMessView::eventFilter(QObject *obj, QEvent *event)
 
         if( mimeUrl.isEmpty() )
         {
-          kWarning() << "Dropped empty MIME URL";
+          kmWarning() << "Dropped empty MIME URL";
           return true;
         }
 
@@ -546,7 +546,7 @@ bool KMessView::eventFilter(QObject *obj, QEvent *event)
 
         if( ! pictureData.load( localFilePath ) )
         {
-          kWarning() << "The file dropped is not an image or doesn't exist";
+          kmWarning() << "The file dropped is not an image or doesn't exist";
           return true;
         }
 
@@ -588,7 +588,7 @@ bool KMessView::eventFilter(QObject *obj, QEvent *event)
         {
           if( ! pictureFolder.rename( tempPictureFile, pictureName ) )
           {
-            kWarning() << "The display picture file could not be renamed from" << tempPictureFile << "to" << pictureName << ".";
+            kmWarning() << "The display picture file could not be renamed from" << tempPictureFile << "to" << pictureName << ".";
             return true;
           }
         }
@@ -637,7 +637,7 @@ bool KMessView::eventFilter(QObject *obj, QEvent *event)
 bool KMessView::initContactListView( QAbstractItemModel *viewModel )
 {
 #ifdef KMESSDEBUG_KMESSVIEW_GENERAL
-  kDebug() << "Initializing the contact list view.";
+  kmDebug() << "Initializing the contact list view.";
 #endif
 
   // Create a proxy model to filter and sort the raw contact list view
@@ -901,8 +901,8 @@ void KMessView::slotGroupChanged( const QModelIndex &index )
   }
 
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-  kDebug() << "Changed index:" << index;
-  kDebug() << "Current index at that row:" << viewModel_->index( index.row(), 0, QModelIndex() );
+  kmDebug() << "Changed index:" << index;
+  kmDebug() << "Current index at that row:" << viewModel_->index( index.row(), 0, QModelIndex() );
 #endif
 
   // Skip invalid items
@@ -911,7 +911,7 @@ void KMessView::slotGroupChanged( const QModelIndex &index )
   ||  ! index.data().canConvert( QVariant::Map ) )
   {
 #ifdef KMESSDEBUG_KMESSVIEW_ITEM_VISIBILITY
-    kDebug() << "Skipping an invalid index:" << index;
+    kmDebug() << "Skipping an invalid index:" << index;
 #endif
     return;
   }
@@ -1128,7 +1128,7 @@ void KMessView::showContextMenu( const QPoint &point )
   }
   else
   {
-    kWarning() << "Invalid type of list item" << itemData[ "type" ];
+    kmWarning() << "Invalid type of list item" << itemData[ "type" ];
   }
 }
 
@@ -1401,7 +1401,7 @@ void KMessView::slotItemDoubleClicked( const QModelIndex &index )
   if( KGlobalSettings::singleClick() )
   {
 #ifdef KMESSDEBUG_KMESSVIEW_GENERAL
-    kDebug() << "Accidental double click detected, skipping click event.";
+    kmDebug() << "Accidental double click detected, skipping click event.";
 #endif
     return;
   }
@@ -1417,7 +1417,7 @@ void KMessView::slotItemSingleClicked( const QModelIndex &index )
   if( ! KGlobalSettings::singleClick() )
   {
 #ifdef KMESSDEBUG_KMESSVIEW_GENERAL
-    kDebug() << "Accidental single click detected, skipping click event.";
+    kmDebug() << "Accidental single click detected, skipping click event.";
 #endif
 
     accidental = true;
@@ -1437,7 +1437,7 @@ void KMessView::slotItemClicked( const QModelIndex &index, const bool accidental
   // The index was empty
   if( itemData.isEmpty() )
   {
-    kWarning() << "Invalid list index given!";
+    kmWarning() << "Invalid list index given!";
     return;
   }
 
@@ -1452,7 +1452,15 @@ void KMessView::slotItemClicked( const QModelIndex &index, const bool accidental
         return;
       }
 
-      contactListView_->setExpanded( index, ! itemData[ "isExpanded" ].toBool() );
+      // Keep the group expansion state volatile while filtering (don't save it)
+      if( ! viewModel_->filterRegExp().isEmpty() )
+      {
+        contactListView_->setExpanded( index, ! contactListView_->isExpanded( index ) );
+      }
+      else
+      {
+        contactListView_->setExpanded( index, ! itemData[ "isExpanded" ].toBool() );
+      }
       break;
 
 
@@ -1468,7 +1476,7 @@ void KMessView::slotItemClicked( const QModelIndex &index, const bool accidental
 
     default:
 #ifdef KMESSDEBUG_KMESSVIEW_GENERAL
-      kWarning() << "Nothing to do!";
+      kmWarning() << "Nothing to do!";
 #endif
       break;
   }
@@ -1497,7 +1505,7 @@ void KMessView::slotMoveGroupDown()
   }
 
 #ifdef KMESSDEBUG_KMESSVIEW_GENERAL
-  kDebug() << "Selected group:" << group->getId() << "to move down in place of group:" << nextGroup->getId();
+  kmDebug() << "Selected group:" << group->getId() << "to move down in place of group:" << nextGroup->getId();
 #endif
 
   // Get the group sorting position for both groups
@@ -1536,7 +1544,7 @@ void KMessView::slotMoveGroupUp()
   }
 
 #ifdef KMESSDEBUG_KMESSVIEW_GENERAL
-  kDebug() << "Selected group:" << group->getId() << "to move up in place of group:" << prevGroup->getId();
+  kmDebug() << "Selected group:" << group->getId() << "to move up in place of group:" << prevGroup->getId();
 #endif
 
   // Get the group sorting position for both groups
@@ -1789,7 +1797,7 @@ void KMessView::updateFriendlyName( bool refreshOnly )
   if( refreshOnly || ! isActiveWindow() || ! topLevelWidget()->isActiveWindow() )
   {
 #ifdef KMESSDEBUG_KMESSVIEW_GENERAL
-    kDebug() << "Refreshing name only: initial update or non-intentional focus lose.";
+    kmDebug() << "Refreshing name only: initial update or non-intentional focus lose.";
 #endif
 
     // Refresh the message
@@ -1802,7 +1810,7 @@ void KMessView::updateFriendlyName( bool refreshOnly )
   QString newName( friendlyNameInput_->text().trimmed() );
 
 #ifdef KMESSDEBUG_KMESSVIEW_GENERAL
-  kDebug() << "Updating friendly name to:" << newName;
+  kmDebug() << "Updating friendly name to:" << newName;
 #endif
 
   // Set a default name (the email address) if the field is left empty
@@ -1849,7 +1857,7 @@ void KMessView::updatePersonalMessage( bool refreshOnly )
   if( refreshOnly || ! isActiveWindow() || ! topLevelWidget()->isActiveWindow() )
   {
 #ifdef KMESSDEBUG_KMESSVIEW_GENERAL
-    kDebug() << "Refreshing message only: initial update or non-intentional focus lose.";
+    kmDebug() << "Refreshing message only: initial update or non-intentional focus lose.";
 #endif
 
     // Refresh the message
@@ -1872,14 +1880,14 @@ void KMessView::updatePersonalMessage( bool refreshOnly )
   const QString message( personalMessageInput_->text().trimmed() );
 
 #ifdef KMESSDEBUG_KMESSVIEW_GENERAL
-  kDebug() << "Updating personal message to:" << message;
+  kmDebug() << "Updating personal message to:" << message;
 #endif
 
   // Protect against weird situations where the label is seen as text.
   // The lost focus event is also sent when the while window looses focus
   if( message == defaultMessage )
   {
-    kWarning() << "Personal message label was about to be used as personal message!";
+    kmWarning() << "Personal message label was about to be used as personal message!";
     return;
   }
 
@@ -1910,7 +1918,7 @@ void KMessView::updatePersonalMessage( bool refreshOnly )
 void KMessView::slotScheduleGroupUpdate()
 {
 #ifdef KMESSDEBUG_KMESSVIEW_ITEM_VISIBILITY
-  kDebug() << "Scheduling another groups update";
+  kmDebug() << "Scheduling another groups update";
 #endif
   updateTimer_.start( 250 );
 }
@@ -1921,7 +1929,7 @@ void KMessView::slotScheduleGroupUpdate()
 void KMessView::slotSearchContact( const QString& searchFor )
 {
 #ifdef KMESSDEBUG_KMESSVIEW_ITEM_VISIBILITY
-  kDebug() << "Search expression changed to:" << searchFor;
+  kmDebug() << "Search expression changed to:" << searchFor;
 #endif
 
   QString searchExpression;
@@ -1949,6 +1957,10 @@ void KMessView::slotSearchContact( const QString& searchFor )
     searchEdit_->setStyleSheet( "" );
   }
 
+  // True if the user was filtering for something and wanted to filter for something else;
+  // used to maintain the group expansion states while refining the search terms
+  bool isFilteringAgain = ( ! searchExpression.isEmpty() && ! viewModel_->filterRegExp().isEmpty() );
+
   viewModel_->setFilterRegExp( searchExpression );
 
   // Show or hide groups which do or do not contain results
@@ -1961,7 +1973,7 @@ void KMessView::slotSearchContact( const QString& searchFor )
     if( ! index.isValid() )
     {
 #ifdef KMESSDEBUG_KMESSVIEW_ITEM_VISIBILITY
-      kDebug() << "Skipping invalid index" << index;
+      kmDebug() << "Skipping invalid index" << index;
 #endif
       continue;
     }
@@ -1973,8 +1985,8 @@ void KMessView::slotSearchContact( const QString& searchFor )
     if( itemData.isEmpty() || itemData[ "type" ].toInt() != ContactListModelItem::ItemGroup )
     {
 #ifdef KMESSDEBUG_KMESSVIEW_ITEM_VISIBILITY
-      kDebug() << "Skipping non-group index" << index;
-      kDebug() << "-- Index data:" << itemData;
+      kmDebug() << "Skipping non-group index" << index;
+      kmDebug() << "-- Index data:" << itemData;
 #endif
       continue;
     }
@@ -1985,7 +1997,11 @@ void KMessView::slotSearchContact( const QString& searchFor )
       bool isHidden = ( ! viewModel_->hasChildren( index ) );
 
       contactListView_->setRowHidden( row, QModelIndex(), isHidden );
-      contactListView_->setExpanded( index, true );
+
+      if( ! isFilteringAgain )
+      {
+        contactListView_->setExpanded( index, true );
+      }
     }
     // When the search terms are removed, enable back all groups
     else
@@ -2014,7 +2030,7 @@ void KMessView::slotShowChatHistory()
 
   // Show the selected contact. If no log exists
   // (no chats with that person yet), then don't show the History dialog
-  if( dialog->setContact( itemData[ "handle" ].toString() ) )
+  if( dialog->setInitialContact( currentAccount_->getHandle(), itemData[ "handle" ].toString() ) )
   {
     dialog->show();
   }
@@ -2126,13 +2142,13 @@ void KMessView::slotUpdateDisplayPicture()
   if( displayPicFrame_->property( "PictureFileName" ) == pictureFileName )
   {
 #ifdef KMESSDEBUG_KMESSVIEW
-    kDebug() << "No need to change the display picture";
+    kmDebug() << "No need to change the display picture";
 #endif
     return;
   }
 
 #ifdef KMESSDEBUG_KMESSVIEW
-  kDebug() << "Changing display picture to path:" << pictureFileName;
+  kmDebug() << "Changing display picture to path:" << pictureFileName;
 #endif
 
   // Change the picture
@@ -2175,7 +2191,7 @@ void KMessView::slotUpdateGroups()
   }
 
 #ifdef KMESSDEBUG_KMESSVIEW_ITEM_VISIBILITY
-  kDebug() << "Updating groups expanded status for" << viewModel_->rowCount() << "rows";
+  kmDebug() << "Updating groups expanded status for" << viewModel_->rowCount() << "rows";
 #endif
 
   for( int row = viewModel_->rowCount() - 1; row >= 0; row-- )
@@ -2183,9 +2199,9 @@ void KMessView::slotUpdateGroups()
     const QModelIndex index( viewModel_->index( row, 0, QModelIndex() ) );
 
 #ifdef KMESSDEBUG_KMESSVIEW_ITEM_VISIBILITY
-  kDebug() << "Current row:" << row << "of" << viewModel_->rowCount();
-  kDebug() << "Index:" << index;
-  kDebug() << "Model has it?" << viewModel_->hasIndex( row, 0, QModelIndex() );
+  kmDebug() << "Current row:" << row << "of" << viewModel_->rowCount();
+  kmDebug() << "Index:" << index;
+  kmDebug() << "Model has it?" << viewModel_->hasIndex( row, 0, QModelIndex() );
 #endif
 
     // Skip invalid items
@@ -2194,7 +2210,7 @@ void KMessView::slotUpdateGroups()
     ||  ! index.data().canConvert( QVariant::Map ) )
     {
 #ifdef KMESSDEBUG_KMESSVIEW_ITEM_VISIBILITY
-      kDebug() << "Skipping an invalid item at row" << row << ":" << index;
+      kmDebug() << "Skipping an invalid item at row" << row << ":" << index;
 #endif
       continue;
     }
@@ -2206,8 +2222,8 @@ void KMessView::slotUpdateGroups()
     if( itemData.isEmpty() || itemData[ "type" ].toInt() != ContactListModelItem::ItemGroup )
     {
 #ifdef KMESSDEBUG_KMESSVIEW_ITEM_VISIBILITY
-      kDebug() << "Skipping a non-group at row" << row << ":" << index;
-      kDebug() << "Skipped item's details:" << itemData;
+      kmDebug() << "Skipping a non-group at row" << row << ":" << index;
+      kmDebug() << "Skipped item's details:" << itemData;
 #endif
       continue;
     }
@@ -2216,13 +2232,13 @@ void KMessView::slotUpdateGroups()
     contactListView_->setExpanded( index, itemData[ "isExpanded" ].toBool() );
 
 #ifdef KMESSDEBUG_KMESSVIEW_ITEM_VISIBILITY
-    kDebug() << "Group" << itemData[ "name" ].toString() << "is"
+    kmDebug() << "Group" << itemData[ "name" ].toString() << "is"
              << ( itemData[ "isExpanded" ].toBool() ? "expanded" : "contracted" );
 #endif
   }
 
 #ifdef KMESSDEBUG_KMESSVIEW_ITEM_VISIBILITY
-  kDebug() << "Update done.";
+  kmDebug() << "Update done.";
 #endif
 }
 
@@ -2267,7 +2283,7 @@ void KMessView::slotUpdateUserStatus()
   const Status status( currentAccount_->getStatus() );
 
 #ifdef KMESSDEBUG_KMESSVIEW_GENERAL
-  kDebug() << "Updating user status to:" << MsnStatus::getName( status );
+  kmDebug() << "Updating user status to:" << MsnStatus::getName( status );
 #endif
 
   // Update the widgets
