@@ -134,9 +134,9 @@ void KMessViewDelegate::paint( QPainter *painter, const QStyleOptionViewItem &op
     // Restore the painter to the previous state
     painter->restore();
 
-    kWarning() << "Unknown type of item:" << itemData[ "type" ].toInt();
-    kWarning() << "Index:" << index;
-    kWarning() << "Data:" << itemData;
+    kmWarning() << "Unknown type of item:" << itemData[ "type" ].toInt();
+    kmWarning() << "Index:" << index;
+    kmWarning() << "Data:" << itemData;
     return;
   }
 
