@@ -123,6 +123,8 @@ int main(int argc, char *argv[])
   aboutData.addCredit( ki18n("Andrea Blankenstijn"),       ki18n("More French translation"),         "darkan9el" "@" "gmail" "." "com" ); // or "andrea" "@" "zenephiris" "." "ch"
   aboutData.addCredit( ki18n("Barthe Guillaume"),          ki18n("More French translation"),         "gu_barthe" "@" "yahoo" "." "fr" );
   aboutData.addCredit( ki18n("Scias"),                     ki18n("More French translation"),         "shining" "." "scias" "@" "gmail" "." "com" );
+  aboutData.addCredit( ki18n("Grégory Bellier"),           ki18n("More French translation"),         "gregory" "." "bellier" "@" "gmail" "." "com" );
+  aboutData.addCredit( ki18n("Anthony Rey"),               ki18n("More French translation"),         "gnuk" "@" "mailoo" "." "org");
 
   aboutData.addCredit( ki18n("Páder Rezső"),               ki18n("Hungarian translation"),            "rezso" "@" "rezso" "." "net");
   aboutData.addCredit( ki18n("Pauli Henrik"),              ki18n("More Hungarian translation"),      "henrik.pauli" "@" "drangolin" "." "net");
@@ -181,6 +183,7 @@ int main(int argc, char *argv[])
   aboutData.addCredit( ki18n("Anastasios Bourazanis"),     ki18n("Emoticon preview in settings page,clickable contact properties dialog text"), "a.brzns" "@" "gmail" "." "com");
   aboutData.addCredit( ki18n("Marco Mentasti"),            ki18n("Internationalization fixes, drag'n'drop of images into display pictures"), "marcomentasti" "@" "gmail" "." "com" );
   aboutData.addCredit( ki18n("Francesco Nwokeka"),         ki18n("Now Listening toggle button above the contact list."), "" );
+  aboutData.addCredit( ki18n("Timo Tambet"),               ki18n("Contact Changed and Group Changed notifications, contact added user dialog tabbing"), "ttambet" "@" "gmail" "." "com" );
 
   // Other apps
   aboutData.addCredit( ki18n("KMerlin (kmerlin.olsd.de)"), ki18n("Inspiration and assorted code"));
