@@ -53,14 +53,14 @@ ContactList::ContactList()
 ContactList::~ContactList()
 {
 #ifdef KMESSDEBUG_CONTACTLIST_GENERAL
-  kDebug() << "DESTROYING...";
+  kmDebug() << "DESTROYING...";
 #endif
 
   // Destroy the list's contents, without regenerating the special groups and the model
   reset( false );
 
 #ifdef KMESSDEBUG_CONTACTLIST_GENERAL
-  kDebug() << "DESTROYED.";
+  kmDebug() << "DESTROYED.";
 #endif
 }
 
@@ -75,7 +75,7 @@ Contact * ContactList::addContact( const QString& handle, const QString& friendl
   if( KMESS_NULL(rootNode_) ) return 0;
 
 #ifdef KMESSDEBUG_CONTACTLIST_GENERAL
-  kDebug() << "Adding to list contact" << handle << " in groups" << groupIds;
+  kmDebug() << "Adding to list contact" << handle << " in groups" << groupIds;
 #endif
 
 #ifdef KMESSTEST
@@ -91,7 +91,7 @@ Contact * ContactList::addContact( const QString& handle, const QString& friendl
   // TODO we could return the Contact* founded ?!
   if( getContactByHandle( handle ) != 0 )
   {
-    kWarning() << "attempted to add contact " << handle << " twice.";
+    kmWarning() << "attempted to add contact " << handle << " twice.";
     return 0;
   }
 
@@ -132,7 +132,7 @@ Contact * ContactList::addContact( const QString& handle, const QString& friendl
     ContactListModelItem *groupNode = rootNode_->childGroup( id );
     if( ! groupNode )
     {
-      kWarning() << "Contact's group" << id << "doesn't exist!";
+      kmWarning() << "Contact's group" << id << "doesn't exist!";
       continue;
     }
 
@@ -141,7 +141,7 @@ Contact * ContactList::addContact( const QString& handle, const QString& friendl
 
     if ( !groupIdx.isValid() )
     {
-      kWarning() << "Formed invalid index for group " << id << " for contact " << handle << ", not adding to group";
+      kmWarning() << "Formed invalid index for group " << id << " for contact " << handle << ", not adding to group";
       continue;
     }
 
@@ -180,13 +180,13 @@ Group* ContactList::addGroup( const QString& groupId, const QString& groupName )
   if( KMESS_NULL(rootNode_) ) return 0;
 
 #ifdef KMESSDEBUG_CONTACTLIST_GENERAL
-  kDebug() << groupName << "(" << groupId << ")";
+  kmDebug() << groupName << "(" << groupId << ")";
 #endif
 
   // Check if the group already exists
   if ( groupExists( groupId ) )
   {
-    kDebug() << "Group " << groupId << " already exists.";
+    kmDebug() << "Group " << groupId << " already exists.";
     return 0;
   }
 
@@ -235,7 +235,7 @@ void ContactList::changeContactStatus( const QString& handle, Status status, con
   Contact *contact = getContactByHandle( handle );
   if ( contact == 0 )
   {
-    kWarning() << "changeContactStatus - Couldn't find contact " << handle << " in the contact list.";
+    kmWarning() << "changeContactStatus - Couldn't find contact " << handle << " in the contact list.";
     return;
   }
 
@@ -274,14 +274,14 @@ void ContactList::changeContactStatus( const QString& handle, Status status, con
     if( oldStatus != status )
     {
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-      kDebug() << "Changing contact" << handle << "'s status";
+      kmDebug() << "Changing contact" << handle << "'s status";
 #endif
       // Signal that the contact has changed status, but not switched between an online status and the offline one
       emit contactChangedStatus( contact, showBaloon );
     }
 
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-    kDebug() << "Status unchanged, skipping.";
+    kmDebug() << "Status unchanged, skipping.";
 #endif
 
     forwardDataChanged( rootNode_->childContacts( handle ) );
@@ -307,21 +307,21 @@ void ContactList::changeContactStatus( const QString& handle, Status status, con
 
   if( ! sourceGroup || ! destinationGroup )
   {
-    kWarning() << "The Online or Offline groups are not available!";
+    kmWarning() << "The Online or Offline groups are not available!";
     return;
   }
 
   // Move the contact from the first group and put it in the other one
 
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-  kDebug() << "Moving contact" << handle << "from" << sourceGroup << "to" << destinationGroup;
+  kmDebug() << "Moving contact" << handle << "from" << sourceGroup << "to" << destinationGroup;
 #endif
 
   ContactListModelItem *contactItem = sourceGroup->childContact( handle );
   if( ! contactItem )
   {
-    kWarning() << "Unable to find contact" << handle << "(now online?" << contact->isOnline();
-    kWarning() << "The contact is in groups:" << rootNode_->childContacts( handle );
+    kmWarning() << "Unable to find contact" << handle << "(now online?" << contact->isOnline();
+    kmWarning() << "The contact is in groups:" << rootNode_->childContacts( handle );
     return;
   }
 
@@ -348,7 +348,7 @@ int ContactList::columnCount( const QModelIndex &/*parent*/ ) const
   if( rootNode_ == 0 )
   {
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-    kWarning() << "Called columnCount() without a root node!";
+    kmWarning() << "Called columnCount() without a root node!";
 #endif
     return 0;
   }
@@ -396,7 +396,7 @@ bool ContactList::dropMimeData( const QMimeData *data, Qt::DropAction action, in
   if( action == Qt::IgnoreAction )
   {
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-    kDebug() << "Ignore action";
+    kmDebug() << "Ignore action";
 #endif
     return true;
   }
@@ -405,7 +405,7 @@ bool ContactList::dropMimeData( const QMimeData *data, Qt::DropAction action, in
   if( ! data->hasFormat( "application/kmess.list.item" ) )
   {
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-    kDebug() << "Invalid format:" << data->formats();
+    kmDebug() << "Invalid format:" << data->formats();
 #endif
     return false;
   }
@@ -413,13 +413,13 @@ bool ContactList::dropMimeData( const QMimeData *data, Qt::DropAction action, in
   if ( column > 0 )
   {
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-    kDebug() << "Invalid column:" << column;
+    kmDebug() << "Invalid column:" << column;
 #endif
     return false;
   }
 
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-  kDebug() << "Drop info - parent:" << parent << "Data:" << parent.data();
+  kmDebug() << "Drop info - parent:" << parent << "Data:" << parent.data();
 #endif
 
   QByteArray encodedData( data->data( "application/kmess.list.item" ) );
@@ -436,7 +436,7 @@ bool ContactList::dropMimeData( const QMimeData *data, Qt::DropAction action, in
     if( sourceItem == 0 )
     {
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-      kDebug() << "Invalid item extracted from mime data!";
+      kmDebug() << "Invalid item extracted from mime data!";
 #endif
       continue;
     }
@@ -446,13 +446,13 @@ bool ContactList::dropMimeData( const QMimeData *data, Qt::DropAction action, in
     if( targetItem == 0 )
     {
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-      kDebug() << "Invalid target item!";
+      kmDebug() << "Invalid target item!";
 #endif
       continue;
     }
 
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-    kDebug() << "Extracted item:" << sourceItem;
+    kmDebug() << "Extracted item:" << sourceItem;
 #endif
 
     // Take action, depending on the type of dropped item
@@ -474,7 +474,7 @@ bool ContactList::dropMimeData( const QMimeData *data, Qt::DropAction action, in
         if( sourceGroup->isSpecialGroup() )
         {
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-          kDebug() << "Cannot move a contact from within a special group.";
+          kmDebug() << "Cannot move a contact from within a special group.";
 #endif
           continue;
         }
@@ -484,7 +484,7 @@ bool ContactList::dropMimeData( const QMimeData *data, Qt::DropAction action, in
           // Contact dropped to root
           case ContactListModelItem::ItemRoot:
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-            kDebug() << "Cannot move a contact to root.";
+            kmDebug() << "Cannot move a contact to root.";
 #endif
             continue;
 
@@ -494,7 +494,7 @@ bool ContactList::dropMimeData( const QMimeData *data, Qt::DropAction action, in
             if( targetItem == sourceItem->parent() )
             {
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-              kDebug() << "Cannot move a contact to its own group.";
+              kmDebug() << "Cannot move a contact to its own group.";
 #endif
               continue;
             }
@@ -505,7 +505,7 @@ bool ContactList::dropMimeData( const QMimeData *data, Qt::DropAction action, in
             if( contact->getGroupIds().contains( targetGroup->getId() ) )
             {
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-              kDebug() << "Cannot move a contact where it already is.";
+              kmDebug() << "Cannot move a contact where it already is.";
 #endif
               continue;
             }
@@ -514,13 +514,13 @@ bool ContactList::dropMimeData( const QMimeData *data, Qt::DropAction action, in
             if( targetGroup->isSpecialGroup() )
             {
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-              kDebug() << "Cannot move a contact to a special group.";
+              kmDebug() << "Cannot move a contact to a special group.";
 #endif
               continue;
             }
 
 #ifdef KMESSDEBUG_CONTACTLIST
-            kDebug() << "Moving contact from group" << sourceGroup->getId() << "to" << targetGroup->getId();
+            kmDebug() << "Moving contact from group" << sourceGroup->getId() << "to" << targetGroup->getId();
 #endif
             emit dndMoveContactToGroup( contact->getHandle(), sourceGroup->getId(), targetGroup->getId() );
             break;
@@ -532,7 +532,7 @@ bool ContactList::dropMimeData( const QMimeData *data, Qt::DropAction action, in
             if( targetItem == sourceItem )
             {
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-              kDebug() << "Cannot move a contact to itself.";
+              kmDebug() << "Cannot move a contact to itself.";
 #endif
               continue;
             }
@@ -543,7 +543,7 @@ bool ContactList::dropMimeData( const QMimeData *data, Qt::DropAction action, in
             if( contact->getGroupIds().contains( targetGroup->getId() ) )
             {
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-              kDebug() << "Cannot move a contact where it already is.";
+              kmDebug() << "Cannot move a contact where it already is.";
 #endif
               continue;
             }
@@ -552,13 +552,13 @@ bool ContactList::dropMimeData( const QMimeData *data, Qt::DropAction action, in
             if( targetGroup->isSpecialGroup() )
             {
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-              kDebug() << "Cannot move a contact to a special group.";
+              kmDebug() << "Cannot move a contact to a special group.";
 #endif
               continue;
             }
 
 #ifdef KMESSDEBUG_CONTACTLIST
-            kDebug() << "Moving contact from group" << sourceGroup->getId() << "to" << targetGroup->getId();
+            kmDebug() << "Moving contact from group" << sourceGroup->getId() << "to" << targetGroup->getId();
 #endif
             emit dndMoveContactToGroup( contact->getHandle(), sourceGroup->getId(), targetGroup->getId() );
             break;
@@ -584,7 +584,7 @@ bool ContactList::dropMimeData( const QMimeData *data, Qt::DropAction action, in
         if( sourceGroup->isSpecialGroup() )
         {
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-          kDebug() << "Cannot move a special group.";
+          kmDebug() << "Cannot move a special group.";
 #endif
           continue;
         }
@@ -594,7 +594,7 @@ bool ContactList::dropMimeData( const QMimeData *data, Qt::DropAction action, in
           // Group dropped to the root
           case ContactListModelItem::ItemRoot:
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-            kDebug() << "Cannot move a group to root.";
+            kmDebug() << "Cannot move a group to root.";
 #endif
             continue;
 
@@ -604,7 +604,7 @@ bool ContactList::dropMimeData( const QMimeData *data, Qt::DropAction action, in
             if( targetItem == sourceItem )
             {
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-              kDebug() << "Cannot move a group to itself.";
+              kmDebug() << "Cannot move a group to itself.";
 #endif
               continue;
             }
@@ -615,13 +615,13 @@ bool ContactList::dropMimeData( const QMimeData *data, Qt::DropAction action, in
             if( targetGroup->isSpecialGroup() )
             {
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-              kDebug() << "Cannot move to a special group.";
+              kmDebug() << "Cannot move to a special group.";
 #endif
               continue;
             }
 
 #ifdef KMESSDEBUG_CONTACTLIST
-            kDebug() << "Swapping groups" << sourceGroup->getName() << "and" << targetGroup->getName();
+            kmDebug() << "Swapping groups" << sourceGroup->getName() << "and" << targetGroup->getName();
 #endif
             // Get the group sorting position for both groups
             int oldGroupPos = targetGroup->getSortPosition();
@@ -649,7 +649,7 @@ bool ContactList::dropMimeData( const QMimeData *data, Qt::DropAction action, in
             if( targetItem->parent() == sourceItem )
             {
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-              kDebug() << "Cannot move a group to itself.";
+              kmDebug() << "Cannot move a group to itself.";
 #endif
               continue;
             }
@@ -657,13 +657,13 @@ bool ContactList::dropMimeData( const QMimeData *data, Qt::DropAction action, in
             if( targetGroup->isSpecialGroup() )
             {
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-              kDebug() << "Cannot move to a special group.";
+              kmDebug() << "Cannot move to a special group.";
 #endif
               continue;
             }
 
 #ifdef KMESSDEBUG_CONTACTLIST
-            kDebug() << "Swapping groups" << sourceGroup->getName() << "and" << targetGroup->getName();
+            kmDebug() << "Swapping groups" << sourceGroup->getName() << "and" << targetGroup->getName();
 #endif
 
             // Get the group sorting position for both groups
@@ -718,7 +718,7 @@ void ContactList::dump( ContactListModelItem *start, int depth ) const
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
   if( ! rootNode_ )
   {
-    kDebug() << "Contact List model is empty!";
+    kmDebug() << "Contact List model is empty!";
     return;
   }
 
@@ -726,16 +726,16 @@ void ContactList::dump( ContactListModelItem *start, int depth ) const
   if( ! start )
   {
     start = rootNode_;
-    kDebug() << "Contact List model stats";
-    kDebug() << "--------------------------------------";
-    kDebug() << "Columns:"            << columnCount();
-    kDebug() << "Rows:"               << rowCount();
-    kDebug() << "Root group Columns:" << rootNode_->columnCount();
-    kDebug() << "Root group Rows:"    << rootNode_->childCount();
-    kDebug();
-    kDebug() << "Contact List model dump";
-    kDebug() << "--------------------------------------";
-    kDebug() << "Root @" << (void*)rootNode_;
+    kmDebug() << "Contact List model stats";
+    kmDebug() << "--------------------------------------";
+    kmDebug() << "Columns:"            << columnCount();
+    kmDebug() << "Rows:"               << rowCount();
+    kmDebug() << "Root group Columns:" << rootNode_->columnCount();
+    kmDebug() << "Root group Rows:"    << rootNode_->childCount();
+    kmDebug();
+    kmDebug() << "Contact List model dump";
+    kmDebug() << "--------------------------------------";
+    kmDebug() << "Root @" << (void*)rootNode_;
     started = true;
   }
 
@@ -751,14 +751,14 @@ void ContactList::dump( ContactListModelItem *start, int depth ) const
     switch( type )
     {
       case ContactListModelItem::ItemContact:
-        kDebug() << spacer << (i+1) << ") Contact:"
+        kmDebug() << spacer << (i+1) << ") Contact:"
                            << item->data( 0 ).toMap()["handle"].toString()
                            << "(" << item->data( sortRole ).toInt() << ") "
                            "@" << (void*)item;
         break;
 
       case ContactListModelItem::ItemGroup:
-        kDebug() << spacer << (i+1) << ") Group:"
+        kmDebug() << spacer << (i+1) << ") Group:"
                            << item->data( 0 ).toMap()["id"].toString()
                            << "(" << item->data( sortRole ).toInt() << ") "
                            "@" << (void*)item;
@@ -766,14 +766,14 @@ void ContactList::dump( ContactListModelItem *start, int depth ) const
         break;
 
       default:
-        kDebug() << spacer << "Unknown type of item: " + type << "@" << (void*)item;
+        kmDebug() << spacer << "Unknown type of item: " + type << "@" << (void*)item;
         break;
     }
   }
 
   if( started )
   {
-    kDebug() << "--------------------------------------";
+    kmDebug() << "--------------------------------------";
   }
 #else
   Q_UNUSED( start );
@@ -793,7 +793,7 @@ void ContactList::ensureGroupListValid()
   int fillOffset = 0;
 
 #ifdef KMESSDEBUG_CONTACTLIST_GENERAL
-  kDebug() << "Checking the group list against duplicates and gaps...";
+  kmDebug() << "Checking the group list against duplicates and gaps...";
   int gaps = 0, duplicates = 0;
 #endif
 
@@ -805,7 +805,7 @@ void ContactList::ensureGroupListValid()
     if( group->getSortPosition() < 5 && ! group->isSpecialGroup() )
     {
 #ifdef KMESSDEBUG_CONTACTLIST_GENERAL
-      kWarning() << "Found a non-special group with sortPosition < 5, resetting to " << group->getSortPosition() + 5;
+      kmWarning() << "Found a non-special group with sortPosition < 5, resetting to " << group->getSortPosition() + 5;
 #endif
       // the part below will automatically fix any duplicates caused by this:
       group->setSortPosition( group->getSortPosition() + 5, false );
@@ -864,7 +864,7 @@ void ContactList::ensureGroupListValid()
     else if( matches.count() == 0 )
     {
 #ifdef KMESSDEBUG_CONTACTLIST_GENERAL
-      kDebug() << "Gap found in group list for position " << pos << ", fixing.";
+      kmDebug() << "Gap found in group list for position " << pos << ", fixing.";
       gaps++;
 #endif
       // there's a gap, lower all other indices in the group list
@@ -873,7 +873,7 @@ void ContactList::ensureGroupListValid()
     else
     {
 #ifdef KMESSDEBUG_CONTACTLIST_GENERAL
-      kDebug() << "Duplicate found in group list for position " << pos << ", fixing.";
+      kmDebug() << "Duplicate found in group list for position " << pos << ", fixing.";
       duplicates++;
 #endif
 
@@ -893,7 +893,7 @@ void ContactList::ensureGroupListValid()
   }
 
 #ifdef KMESSDEBUG_CONTACTLIST_GENERAL
-  kDebug() << "Done checking the contact list. " << duplicates << " duplicates, " << gaps << " gaps fixed.";
+  kmDebug() << "Done checking the contact list. " << duplicates << " duplicates, " << gaps << " gaps fixed.";
 #endif
 
   groups_.clear();
@@ -970,7 +970,7 @@ bool ContactList::isGroupEmpty( const QString &groupId ) const
   ContactListModelItem *item = rootNode_->childGroup( groupId );
   if( item == 0 )
   {
-    kWarning() << "Cannot find group" << groupId;
+    kmWarning() << "Cannot find group" << groupId;
     return false;
   }
 
@@ -997,7 +997,7 @@ Qt::ItemFlags ContactList::flags( const QModelIndex &index ) const
   if( item == 0 )
   {
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-    kDebug() << "Invalid target item!";
+    kmDebug() << "Invalid target item!";
 #endif
     return 0;
   }
@@ -1081,7 +1081,7 @@ void ContactList::forwardDataChanged( ModelItemList itemList )
   if( itemList.isEmpty() )
   {
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-    kDebug() << "Called with an empty list!";
+    kmDebug() << "Called with an empty list!";
 #endif
     return;
   }
@@ -1102,17 +1102,17 @@ void ContactList::forwardDataChanged( ModelItemList itemList )
 /*
     // Useful debugging statements, but way too verbose
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-    kDebug() << "--------------------------------------------------";
-    kDebug() << "Item                  :" << item;
-    kDebug() << "Root item             :" << rootNode_;
-    kDebug() << "Parent item           :" << item->parent();
-    kDebug() << "Index                 :" << changedIndex;
-    kDebug() << "Parent index          :" << changedIndex.parent();
+    kmDebug() << "--------------------------------------------------";
+    kmDebug() << "Item                  :" << item;
+    kmDebug() << "Root item             :" << rootNode_;
+    kmDebug() << "Parent item           :" << item->parent();
+    kmDebug() << "Index                 :" << changedIndex;
+    kmDebug() << "Parent index          :" << changedIndex.parent();
     if( changedIndex.parent().isValid() )
-      kDebug() << "Parent index refers to:" << static_cast<ContactListModelItem*>( changedIndex.parent().internalPointer() );
+      kmDebug() << "Parent index refers to:" << static_cast<ContactListModelItem*>( changedIndex.parent().internalPointer() );
     else
-      kDebug() << "Parent index refers to: Root, or a broken item";
-    kDebug() << "Parent index's parent :" << changedIndex.parent().parent();
+      kmDebug() << "Parent index refers to: Root, or a broken item";
+    kmDebug() << "Parent index's parent :" << changedIndex.parent().parent();
 #endif
 */
 
@@ -1144,7 +1144,7 @@ QMimeData *ContactList::mimeData( const QModelIndexList &indexes ) const
     if( item == 0 )
     {
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-      kDebug() << "Invalid item!";
+      kmDebug() << "Invalid item!";
 #endif
       continue;
     }
@@ -1155,13 +1155,13 @@ QMimeData *ContactList::mimeData( const QModelIndexList &indexes ) const
     &&  itemType != ContactListModelItem::ItemGroup )
     {
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-      kDebug() << "Non draggable item!";
+      kmDebug() << "Non draggable item!";
 #endif
       continue;
     }
 
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-    kDebug() << "Preparing drag data for item" << item;
+    kmDebug() << "Preparing drag data for item" << item;
 #endif
 
     // Save the pointer as a 64-bit unsigned integer
@@ -1491,7 +1491,7 @@ void ContactList::slotGroupMoved( Group *group, int oldPosition, int newPosition
   if( oldPosition == newPosition )
   {
 #ifdef KMESSDEBUG_CONTACTLIST_GENERAL
-    kDebug() << "A group moved to the same location, skipping handling.";
+    kmDebug() << "A group moved to the same location, skipping handling.";
 #endif
     return;
   }
@@ -1529,12 +1529,12 @@ void ContactList::slotGroupMoved( Group *group, int oldPosition, int newPosition
   if( KMESS_NULL( oldGroup ) )
   {
     // This happens when newPosition > groups_.count(), i.e., invalid moving code
-    kWarning() << "Couldn't find a group with index " << newPosition << "!";
+    kmWarning() << "Couldn't find a group with index " << newPosition << "!";
     return;
   }
 
 #ifdef KMESSDEBUG_CONTACTLIST_GENERAL
-  kDebug() << "Moving group" << group->getName() << "(position" << oldPosition << ")"
+  kmDebug() << "Moving group" << group->getName() << "(position" << oldPosition << ")"
     << "to position" << newPosition << "(currently group" << oldGroup->getName() << ")";
 #endif
 
@@ -1578,7 +1578,7 @@ void ContactList::slotForwardContactOffline(Contact *contact, bool showBaloon)
 #ifdef KMESSDEBUG_CONTACTLIST_GENERAL
   if ( contact != 0 )
   {
-    kDebug() << "Forwarding that " << contact->getHandle() << " went offline.";
+    kmDebug() << "Forwarding that " << contact->getHandle() << " went offline.";
   }
 #endif
 
@@ -1597,7 +1597,7 @@ void ContactList::slotForwardContactOnline(Contact *contact, bool showBaloon)
 #ifdef KMESSDEBUG_CONTACTLIST_GENERAL
   if ( contact != 0 )
   {
-    kDebug() << "Forwarding that " << contact->getHandle() << " went online.";
+    kmDebug() << "Forwarding that " << contact->getHandle() << " went online.";
   }
 #endif
 
@@ -1613,7 +1613,7 @@ void ContactList::removeContact( QString contactId )
 
   if( contact == 0 )
   {
-    kWarning() << "Contact" << contactId << "doesn't exist in the contact list.";
+    kmWarning() << "Contact" << contactId << "doesn't exist in the contact list.";
     return;
   }
 
@@ -1640,14 +1640,14 @@ void ContactList::removeContactFromGroup ( const QString& handle, ContactListMod
 {
   if ( ! groupItem )
   {
-    kWarning() << "Invalid group";
+    kmWarning() << "Invalid group";
     return;
   }
 
   const QModelIndex groupIndex( index(groupItem->row(), 0, QModelIndex() ) );
   if ( !groupIndex.isValid() )
   {
-    kWarning() << "Group does not exist in the contact list";
+    kmWarning() << "Group does not exist in the contact list";
     return;
   }
 
@@ -1656,7 +1656,7 @@ void ContactList::removeContactFromGroup ( const QString& handle, ContactListMod
 
   if ( !contactItem )
   {
-    kWarning() << "Contact/group mismatch";
+    kmWarning() << "Contact/group mismatch";
     return;
   }
 
@@ -1678,20 +1678,20 @@ void ContactList::removeGroup( const QString& groupId )
 
   if ( group == 0 || nodeToRemove == 0 )
   {
-    kWarning() << "Group" << groupId << "doesn't exist in the contact list.";
+    kmWarning() << "Group" << groupId << "doesn't exist in the contact list.";
     return;
   }
 
   if( nodeToRemove->childCount() )
   {
-    kWarning() << "Group" << groupId << "was not empty!";
+    kmWarning() << "Group" << groupId << "was not empty!";
     return;
   }
 
   ContactListModelItem *gropNode = rootNode_->childGroup( groupId );
   if ( ! gropNode )
   {
-    kWarning() << "Group " << groupId << " does not exist in the model!";
+    kmWarning() << "Group " << groupId << " does not exist in the model!";
     return;
   }
 
@@ -1723,7 +1723,7 @@ void ContactList::renameContact( QString handle, QString newName )
   contact = getContactByHandle( handle );
   if ( contact == 0 )
   {
-    kDebug() << "Couldn't find contact " << handle << " in the contact list.";
+    kmDebug() << "Couldn't find contact " << handle << " in the contact list.";
     return;
   }
 
@@ -1741,7 +1741,7 @@ void ContactList::renameGroup( const QString& groupId, const QString& groupName
   Group *group = getGroupById( groupId );
   if( group == 0 )
   {
-    kWarning() << "Group" << groupId << "not found in the contact list.";
+    kmWarning() << "Group" << groupId << "not found in the contact list.";
     return;
   }
 
@@ -1767,7 +1767,7 @@ void ContactList::reset( bool restore )
   if( rootNode_ )
   {
 #ifdef KMESSDEBUG_CONTACTLISTMODEL
-    kDebug() << "Resetting model tree...";
+    kmDebug() << "Resetting model tree...";
 #endif
 
     // Delete everything from the model tree
@@ -1797,7 +1797,7 @@ void ContactList::reset( bool restore )
   if( contacts_.count() || groups_.count() )
   {
 #ifdef KMESSDEBUG_CONTACTLIST_DISCONNECTION
-    kDebug() << "Resetting" << contacts_.count() << "contacts...";
+    kmDebug() << "Resetting" << contacts_.count() << "contacts...";
 #endif
 
     // Delete all contacts
@@ -1805,7 +1805,7 @@ void ContactList::reset( bool restore )
     contacts_.clear();
 
 #ifdef KMESSDEBUG_CONTACTLIST_DISCONNECTION
-    kDebug() << "Resetting" << groups_.count() << "groups...";
+    kmDebug() << "Resetting" << groups_.count() << "groups...";
 #endif
 
     // Delete all groups
@@ -1841,7 +1841,7 @@ void ContactList::reset( bool restore )
 void ContactList::readProperties()
 {
 #ifdef KMESSDEBUG_CONTACTLIST_GENERAL
-  kDebug() << "Loading properties for the contact list";
+  kmDebug() << "Loading properties for the contact list";
 #endif
 
   const QString& handle = CurrentAccount::instance()->getHandle();
@@ -1909,13 +1909,13 @@ int ContactList::rowCount( const QModelIndex &parent ) const
 void ContactList::saveProperties()
 {
 #ifdef KMESSDEBUG_CONTACTLIST_GENERAL
-  kDebug() << "Saving properties for the contact list";
+  kmDebug() << "Saving properties for the contact list";
 #endif
 
   // Do not save account properties when it's a temporary account
   if( CurrentAccount::instance()->isGuestAccount() )
   {
-    kWarning() << "Requested to save properties, but this is a guest account!";
+    kmWarning() << "Requested to save properties, but this is a guest account!";
     return;
   }
 
@@ -1957,7 +1957,7 @@ void ContactList::saveProperties()
     foreach( const QString &unusedContact, pendingRemoval )
     {
   #ifdef KMESSDEBUG_CONTACTLIST_GENERAL
-      kDebug() << "Deleting unused contact info for " << unusedContact;
+      kmDebug() << "Deleting unused contact info for " << unusedContact;
   #endif
 
       // Remove the custom picture associated with this contact, if there is any
@@ -1976,7 +1976,7 @@ void ContactList::saveProperties()
 #ifdef KMESSDEBUG_CONTACTLIST_GENERAL
   else
   {
-  kDebug() << "No contacts to save";
+  kmDebug() << "No contacts to save";
   }
 #endif
 }
