@@ -106,14 +106,14 @@ void ContactListModelItem::appendChild( ContactListModelItem *item )
   ||  ( itemType_ == ItemGroup   && item->getType() != ItemContact )
   ||    itemType_ == ItemContact )
   {
-    kWarning() << "Cannot insert this item:" << item << "into this one:" << this;
+    kmWarning() << "Cannot insert this item:" << item << "into this one:" << this;
     return;
   }
 
   // Also, don't add items which are already present
   if( childItems_.contains( item ) )
   {
-    kWarning() << "Tried to add twice item:" << item;
+    kmWarning() << "Tried to add twice item:" << item;
     return;
   }
 
@@ -153,7 +153,7 @@ ContactListModelItem *ContactListModelItem::childContact( const QString &handle
   // Prevent incorrect usage
   if( itemType_ != ItemGroup )
   {
-    kWarning() << "Called childContact() on a non-group item:" << this;
+    kmWarning() << "Called childContact() on a non-group item:" << this;
     return 0;
   }
 
@@ -199,7 +199,7 @@ ModelItemList ContactListModelItem::childContacts( const QString &handle )
     {
       if( item->getType() != ItemContact )
       {
-        kWarning() << "Invalid item in group" << this << ":" << item;
+        kmWarning() << "Invalid item in group" << this << ":" << item;
         return ModelItemList();
       }
 
@@ -212,7 +212,7 @@ ModelItemList ContactListModelItem::childContacts( const QString &handle )
   }
   else
   {
-    kWarning() << "Called childContacts() from a Contact item:" << this;
+    kmWarning() << "Called childContacts() from a Contact item:" << this;
     return ModelItemList();
   }
 
@@ -234,7 +234,7 @@ ContactListModelItem *ContactListModelItem::childGroup( const QString &id )
   // Prevent incorrect usage
   if( itemType_ != ItemRoot )
   {
-    kWarning() << "Called childGroup() on a non-root item:" << this;
+    kmWarning() << "Called childGroup() on a non-root item:" << this;
     return 0;
   }
 
@@ -242,7 +242,7 @@ ContactListModelItem *ContactListModelItem::childGroup( const QString &id )
   {
     if( item->getType() != ItemGroup )
     {
-      kWarning() << "Invalid item in root" << this << ":" << item;
+      kmWarning() << "Invalid item in root" << this << ":" << item;
       return 0;
     }
 
@@ -405,8 +405,8 @@ const QVariant ContactListModelItem::data( int role ) const
       else
       {
         // Avoid crashing without hints
-        kWarning() << "Called data( SortRole ) on an invalid item: (see below)";
-        kWarning() << this;
+        kmWarning() << "Called data( SortRole ) on an invalid item: (see below)";
+        kmWarning() << this;
         return QVariant( 0 );
       }
 
@@ -452,8 +452,8 @@ const QVariant ContactListModelItem::data( int role ) const
       else
       {
         // Avoid crashing without hints
-        kWarning() << "Called data( SearchRole ) on an invalid item: (see below)";
-        kWarning() << this;
+        kmWarning() << "Called data( SearchRole ) on an invalid item: (see below)";
+        kmWarning() << this;
         return QVariant( QString() );
       }
     }
@@ -554,8 +554,8 @@ const QVariant ContactListModelItem::data( int role ) const
       else
       {
         // Avoid crashing without hints
-        kWarning() << "Called data( DisplayRole ) on an invalid item: (see below)";
-        kWarning() << this;
+        kmWarning() << "Called data( DisplayRole ) on an invalid item: (see below)";
+        kmWarning() << this;
         return QVariant( ModelDataList() );
       }
 
@@ -594,19 +594,19 @@ void ContactListModelItem::moveTo( ContactListModelItem *newParent )
 {
   if( itemType_ == ItemRoot )
   {
-    kWarning() << "Called moveTo() on a root item! Item:" << this;
+    kmWarning() << "Called moveTo() on a root item! Item:" << this;
     return;
   }
 
   if( newParent == 0 )
   {
-    kWarning() << "Called moveTo() with an empty new parent! Item:" << this;
+    kmWarning() << "Called moveTo() with an empty new parent! Item:" << this;
     return;
   }
 
   if( parentNode_ == 0 )
   {
-    kWarning() << "Called moveTo() on a parentless item! Item:" << this;
+    kmWarning() << "Called moveTo() on a parentless item! Item:" << this;
     return;
   }
 
@@ -673,7 +673,7 @@ int ContactListModelItem::row() const
 {
   if( itemType_ == ItemRoot || ! parentNode_ || parentNode_->childItems_.isEmpty() )
   {
-    kWarning() << "Called row() on a root item or an item with invalid parent! Item:" << this;
+    kmWarning() << "Called row() on a root item or an item with invalid parent! Item:" << this;
     return 0;
   }
 
