@@ -85,7 +85,7 @@ MsnObjectTransferP2P::~MsnObjectTransferP2P()
 void MsnObjectTransferP2P::contactStarted1_ContactInvitesUser(const MimeMessage &message)
 {
 #ifdef KMESSDEBUG_MSNOBJECTTRANSFER_P2P
-  kDebug();
+  kmDebug();
 #endif
 
   // Extract the fields from the message
@@ -97,7 +97,7 @@ void MsnObjectTransferP2P::contactStarted1_ContactInvitesUser(const MimeMessage
   // Just to be on the safe side, check the buffer size before we start decoding
   if( context.length() <= 24 )
   {
-    kWarning() << "MSNObject transfer context field has bad formatting, "
+    kmWarning() << "MSNObject transfer context field has bad formatting, "
                   "ignoring invite (context=" << context << ", contact=" << getContactHandle() << ").";
     sendCancelMessage( CANCEL_FAILED );
     return;
@@ -110,7 +110,7 @@ void MsnObjectTransferP2P::contactStarted1_ContactInvitesUser(const MimeMessage
   msnObject_ = MsnObject( contextString );
 
 #ifdef KMESSDEBUG_MSNOBJECTTRANSFER_P2P
-  kDebug() << "Got context \"" << contextString << "\".";
+  kmDebug() << "Got context \"" << contextString << "\".";
 // Got context <msnobj Creator="contact@hotmail.com" Size="9442" Type="3" Location="KMess.tmp" Friendly="AA==" SHA1D="FyY3n97RHXDgQujca4FVMv4VIF0=" SHA1C="qsT1Tqmtt7Z0LucXOq1pd9p7cIE="/>
 #endif
 
@@ -122,7 +122,7 @@ void MsnObjectTransferP2P::contactStarted1_ContactInvitesUser(const MimeMessage
       // Test protocol compatibility.
       if( appID != 1 && appID != 12 )    // Display pictures -  AppID 12 is used as of MSN Messenger 7.5
       {
-        kDebug() << "Received a request for a display picture, but unexpected appID was set "
+        kmDebug() << "Received a request for a display picture, but unexpected appID was set "
                     "(appid=" << appID <<
                     " type=" << msnObject_.getType() <<
                     " contact=" << getContactHandle() << " action=continue).";
@@ -138,7 +138,7 @@ void MsnObjectTransferP2P::contactStarted1_ContactInvitesUser(const MimeMessage
       if( appID != 1      // HACK: added for compatibility with Messenger for the Mac 6.0.3 and aMsn 0.97rc1
       &&  appID != 11 )   // Custom emoticons
       {
-        kDebug() << "Received a request for an emoticon, but unexpected appID was set "
+        kmDebug() << "Received a request for an emoticon, but unexpected appID was set "
                     "(appid=" << appID <<
                     " type=" << msnObject_.getType() <<
                     " contact=" << getContactHandle() << " action=continue).";
@@ -162,7 +162,7 @@ void MsnObjectTransferP2P::contactStarted1_ContactInvitesUser(const MimeMessage
   }
 
   // Unknown application type
-  kWarning() << "Received an invitation for an unexpected object type "
+  kmWarning() << "Received an invitation for an unexpected object type "
                 "(appid=" << appID <<
                 " type=" << msnObject_.getType() <<
                 " contact=" << getContactHandle() << ").";
@@ -181,7 +181,7 @@ void MsnObjectTransferP2P::contactStarted1_gotDisplayPictureRequest()
   // Send our display picture: check if the MSNObject the contact wants is the picture we've got.
   if( msnObject_.hasChanged( CurrentAccount::instance()->getMsnObjectString() ) )
   {
-    kWarning() << "Contact " << getContactHandle() << " wants a display picture we don't have!\n"
+    kmWarning() << "Contact " << getContactHandle() << " wants a display picture we don't have!\n"
                   "Requested object: " << msnObject_.objectString() << "\n"
                   "Current object:   " << CurrentAccount::instance()->getMsnObjectString() << "\n"
                   "Aborting invite.";
@@ -195,7 +195,7 @@ void MsnObjectTransferP2P::contactStarted1_gotDisplayPictureRequest()
   // Reject because there is no file to send
   if( fileName_.isEmpty() )
   {
-    kWarning() << "Got an invitation, but we don't have a picture to send.";
+    kmWarning() << "Got an invitation, but we don't have a picture to send.";
     sendCancelMessage( CANCEL_FAILED );
     return;
   }
@@ -218,7 +218,7 @@ void MsnObjectTransferP2P::contactStarted1_gotEmoticonRequest()
   if( ! pictureFile.open( QIODevice::ReadOnly ) )
   {
 #ifdef KMESSDEBUG_MSNOBJECTTRANSFER_P2P
-    kDebug() << "Couldn't open file: " << pictureFile.fileName();
+    kmDebug() << "Couldn't open file: " << pictureFile.fileName();
 #endif
     sendCancelMessage( CANCEL_FAILED );
     return;
@@ -231,14 +231,14 @@ void MsnObjectTransferP2P::contactStarted1_gotEmoticonRequest()
   MsnObject testObject( CurrentAccount::instance()->getHandle(), msnObject_.getLocation(), QString::null, MsnObject::EMOTICON, data );
 
 #ifdef KMESSDEBUG_MSNOBJECTTRANSFER_P2P
-  kDebug() << "msnObject_: " << msnObject_.objectString();
-  kDebug() << "testObject: " << testObject.objectString();
+  kmDebug() << "msnObject_: " << msnObject_.objectString();
+  kmDebug() << "testObject: " << testObject.objectString();
 #endif
 
   // Test if they're the same picture
   if( msnObject_.hasChanged( testObject.objectString() ) )
   {
-    kWarning() << "Contact " << getContactHandle()
+    kmWarning() << "Contact " << getContactHandle()
                << " wants a custom emoticon we don't have!"
                << "Requested object: " << msnObject_.objectString()
                << "Aborting invite.";
@@ -247,7 +247,7 @@ void MsnObjectTransferP2P::contactStarted1_gotEmoticonRequest()
   }
 
 #ifdef KMESSDEBUG_MSNOBJECTTRANSFER_P2P
-  kDebug() << "Picture found, accepting.";
+  kmDebug() << "Picture found, accepting.";
 #endif
 
   // Everything seems OK, accept this message
@@ -263,7 +263,7 @@ void MsnObjectTransferP2P::contactStarted1_gotWinkRequest()
   fileName_ = KMessConfig::instance()->getMsnObjectFileName( msnObject_ );
 
 #ifdef KMESSDEBUG_MSNOBJECTTRANSFER_P2P
-  kDebug() << "Requested wink, sending: " + fileName_;
+  kmDebug() << "Requested wink, sending: " + fileName_;
 #endif
 
   if( QFile::exists( fileName_ ) )
@@ -284,7 +284,7 @@ void MsnObjectTransferP2P::contactStarted1_gotWinkRequest()
 void MsnObjectTransferP2P::contactStarted2_UserAccepts()
 {
 #ifdef KMESSDEBUG_MSNOBJECTTRANSFER_P2P
-  kDebug();
+  kmDebug();
 #endif
 
 #ifdef KMESSTEST
@@ -299,14 +299,14 @@ void MsnObjectTransferP2P::contactStarted2_UserAccepts()
   if( ! success )
   {
     // Notify the user, even if debug mode is not enabled.
-    kWarning() << "Unable to open file: " << fileName_ << "!";
+    kmWarning() << "Unable to open file: " << fileName_ << "!";
 
     // Close the file (also causes gotData() to fail)
     delete file_;
     file_ = 0;
 
 #ifdef KMESSDEBUG_MSNOBJECTTRANSFER_P2P
-    kDebug() << "Cancelling session";
+    kmDebug() << "Cancelling session";
 #endif
 
     // Send 500 Internal Error back if we failed
@@ -317,7 +317,7 @@ void MsnObjectTransferP2P::contactStarted2_UserAccepts()
 
 
 #ifdef KMESSDEBUG_MSNOBJECTTRANSFER_P2P
-  kDebug() << "Sending accept message";
+  kmDebug() << "Sending accept message";
 #endif
 
   // Create the message
@@ -338,7 +338,7 @@ void MsnObjectTransferP2P::contactStarted2_UserAccepts()
 void MsnObjectTransferP2P::contactStarted3_ContactConfirmsAccept(const MimeMessage &/*message*/)
 {
 #ifdef KMESSDEBUG_MSNOBJECTTRANSFER_P2P
-  kDebug();
+  kmDebug();
 #endif
 
   // Send the data preparation message back.
@@ -354,7 +354,7 @@ void MsnObjectTransferP2P::contactStarted3_ContactConfirmsAccept(const MimeMessa
 void MsnObjectTransferP2P::contactStarted4_ContactConfirmsPreparation()
 {
 #ifdef KMESSDEBUG_MSNOBJECTTRANSFER_P2P
-  kDebug();
+  kmDebug();
 #endif
 
   // Send the file, the base class handles everything else here
@@ -393,7 +393,7 @@ void MsnObjectTransferP2P::gotData(const P2PMessage &message)
 {
   if(file_ == 0)
   {
-    kWarning() << "Unable to handle file data: no file open or already closed "
+    kmWarning() << "Unable to handle file data: no file open or already closed "
                 << "(offset="    << message.getDataOffset()
                 << " totalsize=" << message.getTotalSize()
                 << " contact="   << getContactHandle() << ")!";
@@ -454,7 +454,7 @@ void MsnObjectTransferP2P::showEventMessage(const QString &message, const ChatMe
 {
   Q_UNUSED( isIncoming );
 
-  kWarning() << "suppressed message:" << message << "(contact=" << getContactHandle() << ", contentsClass=" << contents << ")";
+  kmWarning() << "suppressed message:" << message << "(contact=" << getContactHandle() << ", contentsClass=" << contents << ")";
 }
 
 
@@ -468,7 +468,7 @@ void MsnObjectTransferP2P::showSystemMessage( const QString &message, const Chat
 {
   Q_UNUSED( isIncoming );
 
-  kWarning() << "suppressed message:" << message << "(contact=" << getContactHandle() << ", contentsClass=" << contents << ")";
+  kmWarning() << "suppressed message:" << message << "(contact=" << getContactHandle() << ", contentsClass=" << contents << ")";
 }
 
 
@@ -480,7 +480,7 @@ void MsnObjectTransferP2P::showSystemMessage( const QString &message, const Chat
 void MsnObjectTransferP2P::showTransferComplete()
 {
 #ifdef KMESSDEBUG_MSNOBJECTTRANSFER_P2P
-  kDebug() << "Last data part received, closing file";
+  kmDebug() << "Last data part received, closing file";
 #endif
 
   if( KMESS_NULL(file_) ) return;
@@ -533,7 +533,7 @@ void MsnObjectTransferP2P::showTransferComplete()
       // For pictures, see if it's broken.
       if( QImageReader::imageFormat( pictureFileName ).isEmpty() || ! success )
       {
-        kWarning() << "Received image was broken (contact=" << getContactHandle() << ").";
+        kmWarning() << "Received image was broken (contact=" << getContactHandle() << ").";
         QFile::remove( pictureFileName );
         return;
       }
@@ -599,7 +599,7 @@ void MsnObjectTransferP2P::showTransferComplete()
 void MsnObjectTransferP2P::showTransferMessage( const QString &message )
 {
 #ifdef KMESSDEBUG_MSNOBJECTTRANSFER_P2P
-  kDebug() << "suppressed message: " << message;
+  kmDebug() << "suppressed message: " << message;
 #else
   Q_UNUSED( message ); // Avoid compiler warnings
 #endif
@@ -616,7 +616,7 @@ void MsnObjectTransferP2P::showTransferMessage( const QString &message )
 void MsnObjectTransferP2P::userStarted1_UserInvitesContact()
 {
 #ifdef KMESSDEBUG_MSNOBJECTTRANSFER_P2P
-  kDebug() << "requesting display picture";
+  kmDebug() << "requesting display picture";
 #endif
 
   // Set the filename
@@ -667,7 +667,7 @@ void MsnObjectTransferP2P::userStarted1_UserInvitesContact()
 void MsnObjectTransferP2P::userStarted2_ContactAccepts(const MimeMessage & /*message*/)
 {
 #ifdef KMESSDEBUG_MSNOBJECTTRANSFER_P2P
-  kDebug();
+  kmDebug();
 #endif
 
   // We don't need to do anything else here.
@@ -684,7 +684,7 @@ void MsnObjectTransferP2P::userStarted2_ContactAccepts(const MimeMessage & /*mes
 void MsnObjectTransferP2P::userStarted3_UserPrepares()
 {
 #ifdef KMESSDEBUG_MSNOBJECTTRANSFER_P2P
-  kDebug();
+  kmDebug();
 #endif
 
 #ifdef KMESSTEST
@@ -697,7 +697,7 @@ void MsnObjectTransferP2P::userStarted3_UserPrepares()
     // TODO: Quick fix for WML8, this method is called twice because WLM8
     // initializes a Direct connection while it sent the data preparation
 #ifdef KMESSDEBUG_MSNOBJECTTRANSFER_P2P
-    kWarning() << "this method was already called before.";
+    kmWarning() << "this method was already called before.";
 #endif
     return;
   }
@@ -709,7 +709,7 @@ void MsnObjectTransferP2P::userStarted3_UserPrepares()
   if( ! success )
   {
     // Notify the user, even if debug mode is not enabled.
-    kWarning() << "Unable to open file: " << fileName_ << "!";
+    kmWarning() << "Unable to open file: " << fileName_ << "!";
 
     // Close the file (also causes gotData() to fail)
     delete file_;
