@@ -90,7 +90,7 @@ MsnConnection::~MsnConnection()
   delete socket_;
 
 #ifdef KMESSDEBUG_CONNECTION
-  kDebug() << objectName() << "- DESTROYED";
+  kmDebug() << objectName() << "- DESTROYED";
 #endif
 }
 
@@ -107,7 +107,7 @@ MsnConnection::~MsnConnection()
 void MsnConnection::addSoapClient( HttpSoapConnection *client )
 {
 #ifdef KMESSDEBUG_NOTIFICATION_GENERAL
-  kDebug() << "Adding SOAP client to list.";
+  kmDebug() << "Adding SOAP client to list.";
 #endif
 
   // Connect signals
@@ -131,7 +131,7 @@ void MsnConnection::addSoapClient( HttpSoapConnection *client )
 void MsnConnection::attachToSocketSignals()
 {
 #ifdef KMESSDEBUG_CONNECTION
-  kDebug() << objectName() << "- Connecting socket signals.";
+  kmDebug() << objectName() << "- Connecting socket signals.";
 #endif
 #ifdef KMESSTEST
   KMESS_ASSERT( socket_ != 0 );
@@ -171,11 +171,11 @@ void MsnConnection::connectToServer( const QString& server, const quint16 port )
 #ifdef KMESSDEBUG_CONNECTION_SOCKET
   if( server.isEmpty() && port == 0 )
   {
-    kDebug() << objectName() << "- Connecting to the default server.";
+    kmDebug() << objectName() << "- Connecting to the default server.";
   }
   else
   {
-    kDebug() << objectName() << "- Connecting to server at" << server << ":" << port << ".";
+    kmDebug() << objectName() << "- Connecting to server at" << server << ":" << port << ".";
   }
 #endif
 
@@ -213,7 +213,7 @@ void MsnConnection::deleteSoapClients()
   if( ! soapClients_.isEmpty() )
   {
 #ifdef KMESSDEBUG_NOTIFICATION_GENERAL
-    kDebug() << "Closing SOAP sessions.";
+    kmDebug() << "Closing SOAP sessions.";
 #endif
 
     foreach( HttpSoapConnection *soapClient, soapClients_ )
@@ -241,7 +241,7 @@ void MsnConnection::deleteSoapClients()
 void MsnConnection::disconnectFromServer( bool isTransfer )
 {
 #ifdef KMESSDEBUG_CONNECTION_SOCKET
-  kDebug() << objectName() << "- Closing the connection.";
+  kmDebug() << objectName() << "- Closing the connection.";
 #endif
 
   // Gracefully disconnect
@@ -273,7 +273,7 @@ void MsnConnection::disconnectFromServer( bool isTransfer )
 const QString MsnConnection::getLocalIp() const
 {
 #ifdef KMESSDEBUG_SWITCHBOARD_FILETRANSFER
-  kDebug() << objectName() << "- Local IP is " << socket_->getLocalIp();
+  kmDebug() << objectName() << "- Local IP is " << socket_->getLocalIp();
 #endif
 
   return socket_->getLocalIp();
@@ -294,7 +294,7 @@ bool MsnConnection::initialize()
 {
   if( initialized_ )
   {
-    kDebug() << objectName() << "- Already initialized!";
+    kmDebug() << objectName() << "- Already initialized!";
     return false;
   }
 
@@ -351,16 +351,16 @@ void MsnConnection::parseError( const QStringList &command, const QByteArray &pa
 {
   if( command[0].toInt() == 0 )
   {
-    kWarning() << "Invalid error command received:" << command;
+    kmWarning() << "Invalid error command received:" << command;
     return;
   }
 
   // Always print error codes, to ease a bit the error resolution
-  kWarning() << "Received error code" << command[0] << "from server.";
+  kmWarning() << "Received error code" << command[0] << "from server.";
   if( ! payloadData.isEmpty() )
   {
-    kWarning() << "The error also carries a payload:";
-    kWarning() << payloadData;
+    kmWarning() << "The error also carries a payload:";
+    kmWarning() << payloadData;
   }
 
   QString                  errorMessage;
@@ -630,7 +630,7 @@ void MsnConnection::parseError( const QStringList &command, const QByteArray &pa
 
     default:
       // No need to bugger the users with strange error messages
-      kWarning() << "Unknown error" << command[0] << "received from the server! Full string:" << command.join( " " );
+      kmWarning() << "Unknown error" << command[0] << "received from the server! Full string:" << command.join( " " );
 #ifdef KMESSDEBUG_NOTIFICATION_GENERAL
       slotError( i18n( "Unknown error code received from the server: %1<br/>Technical details: %2",
                        command[0],
@@ -647,7 +647,7 @@ void MsnConnection::parseError( const QStringList &command, const QByteArray &pa
   if( isNotice )
   {
 //    emit statusMessage( errorMessage, false );
-    kDebug() << errorMessage;
+    kmDebug() << errorMessage;
     return;
   }
   // We've received a warning message: show it in a dialog box, but do not disconnect
@@ -678,7 +678,7 @@ void MsnConnection::parseError( const QStringList &command, const QByteArray &pa
 void MsnConnection::parseMultiPacketMimeMessage( const QStringList &command, const MimeMessage &mimeMessage )
 {
 #ifdef KMESSDEBUG_CONNECTION_SOCKET
-  kDebug() << objectName() << "- Message is a multi-packet message, buffering.";
+  kmDebug() << objectName() << "- Message is a multi-packet message, buffering.";
 #endif
 
   // Get associated multi-packet message buffer, create one if it doesn't exist yet.
@@ -843,10 +843,10 @@ void MsnConnection::slotDataReceived( const QStringList &commandLine, const QByt
 {
 #ifdef KMESSDEBUG_SERVERMESSAGES
   // Display the received command data
-  kDebug() << objectName() << "- <<< (C) " << commandLine;
+  kmDebug() << objectName() << "- <<< (C) " << commandLine;
   if( ! payloadData.isEmpty() )
   {
-    kDebug() << objectName() << "- <<< (P) " << payloadData;
+    kmDebug() << objectName() << "- <<< (P) " << payloadData;
   }
 #endif
 
@@ -929,13 +929,13 @@ bool MsnConnection::switchToHttpSocket()
   if( qobject_cast<MsnSocketHttp*>( socket_ ) )
   {
 #ifdef KMESSDEBUG_CONNECTION_SOCKET
-    kDebug() << "Cannot switch to HTTP connection. Class is" << socket_->metaObject()->className();
+    kmDebug() << "Cannot switch to HTTP connection. Class is" << socket_->metaObject()->className();
 #endif
     return false;
   }
 
 #ifdef KMESSDEBUG_CONNECTION_SOCKET
-  kDebug() << "Attempting switch to HTTP connection.";
+  kmDebug() << "Attempting switch to HTTP connection.";
 #endif
 
   // Save the socket details to use the same ones for the new socket
@@ -980,13 +980,13 @@ bool MsnConnection::switchToTcpSocket()
   if( qobject_cast<MsnSocketTcp*>( socket_ ) )
   {
 #ifdef KMESSDEBUG_CONNECTION_SOCKET
-    kDebug() << "Cannot switch to TCP connection. Class is" << socket_->metaObject()->className();
+    kmDebug() << "Cannot switch to TCP connection. Class is" << socket_->metaObject()->className();
 #endif
     return false;
   }
 
 #ifdef KMESSDEBUG_CONNECTION_SOCKET
-  kDebug() << "Attempting to switch back to TCP connection.";
+  kmDebug() << "Attempting to switch back to TCP connection.";
 #endif
 
   // Save the socket details to use the same ones for the new socket
@@ -1019,7 +1019,7 @@ void MsnConnection::writeBinaryData( const QByteArray& data )
 {
   if( ! isConnected() )
   {
-    kWarning() << objectName() << "- Attempting to write binary data while disconnected, aborting.";
+    kmWarning() << objectName() << "- Attempting to write binary data while disconnected, aborting.";
     return;
   }
 
@@ -1028,10 +1028,10 @@ void MsnConnection::writeBinaryData( const QByteArray& data )
 /*
   QByteArray debugData( data );
   for( int i = 0; i < debugData.size(); i++ ) { if( debugData[i] < 10 ) debugData[ i ] = '?'; }
-  kDebug() << objectName() << "- >>> " << QString::fromUtf8( debugData.data(), debugData.size() );
+  kmDebug() << objectName() << "- >>> " << QString::fromUtf8( debugData.data(), debugData.size() );
 */
 // To display the first readable part: (removing the final \r\n)
-  kDebug() << objectName() << "- >>> " << QString( data ).trimmed();
+  kmDebug() << objectName() << "- >>> " << QString( data ).trimmed();
 #endif
 
   // Write to the socket
@@ -1050,12 +1050,12 @@ void MsnConnection::writeData( const QString& data )
 {
   if( ! isConnected() )
   {
-    kWarning() << objectName() << "- Attempting to write data while disconnected, aborting.";
+    kmWarning() << objectName() << "- Attempting to write data while disconnected, aborting.";
     return;
   }
 
 #ifdef KMESSDEBUG_SERVERMESSAGES
-  kDebug() << objectName() << "- >>> " << data.trimmed();
+  kmDebug() << objectName() << "- >>> " << data.trimmed();
 #endif
 
   const QByteArray binData( data.toUtf8() );
@@ -1063,7 +1063,7 @@ void MsnConnection::writeData( const QString& data )
 
   if( noBytesWritten != binData.length() ) // Note that the previous code used data.length instead of unicode.length(), but I
   {                                         // changed this since that is the string we send to the socket... (could be wrong here)
-    kWarning() << objectName() << "- Wanted to write " << data.length() << " bytes to the socket, wrote " << noBytesWritten << ".";
+    kmWarning() << objectName() << "- Wanted to write " << data.length() << " bytes to the socket, wrote " << noBytesWritten << ".";
   }
 
   // Append message to the network window
