@@ -20,6 +20,7 @@
 
 #include "../contact/msnstatus.h"
 #include "../notification/notificationmanager.h"
+#include "../network/soap/addressbookservice.h"
 #include "chatinformation.h"
 #include "msnconnection.h"
 
@@ -43,7 +44,6 @@ class AddressBookService;
 class RoamingService;
 
 
-
 /**
  * @brief The primary connection to the MSN server.
  *
@@ -276,8 +276,7 @@ class MsnNotificationConnection : public MsnConnection
     void                 slotAuthenticationFailed();
     // Unlock notifications after the first seconds of connections
     void                 unlockNotifications();
-
-        // Contact added, notify it to contactlist
+    // Contact added, notify it to contactlist
     void                 slotContactAdded( const QString &handle, const QString &contactId,
                                            const QStringList &groupsId );
     // Contact added to group
@@ -300,7 +299,7 @@ class MsnNotificationConnection : public MsnConnection
 
   private: // Private attributes
 
-        // The address book service
+    // The address book service
     AddressBookService   *addressBookService_;
     bool                 connected_;
     // Nonce received by the server on first SSO command
@@ -356,6 +355,8 @@ class MsnNotificationConnection : public MsnConnection
     QTimer               loginTimer_;
     // A timer used to unlock notifications after the last ILN is received.
     QTimer               notificationUnlockTimer_;
+    // A timer to login directly if the SOAP requests take too long.
+    QTimer               friendlyNameWaitTimer_;
     // The received offline messages.
     QList<OfflineImMessage*>  offlineImMessages_;
     // The Offline-IM SOAP client
@@ -385,6 +386,8 @@ class MsnNotificationConnection : public MsnConnection
     void                 reconnect( QString handle );
     // A new switchboard with a contact has been opened
     void                 startSwitchboard( const ChatInformation &chatInfo );
+    // Signal that a change has occurred in the AB (contact add/remove/delete, etc)
+    void addressBookChanged( const QString &id, AddressBookService::AddressBookUpdate update );
 
 };
 
