@@ -545,7 +545,7 @@ void AddressBookService::retrieveGleams()
 void AddressBookService::parseAddressBook( const QDomElement &body )
 {
 #ifdef KMESSDEBUG_ADDRESSBOOKSERVICE
-  kDebug() << "Parsing address book.";
+  kmDebug() << "Parsing address book.";
 
   int debugGroupCount = 0;
 #endif
@@ -579,6 +579,9 @@ void AddressBookService::parseAddressBook( const QDomElement &body )
   QString information;
   QStringList guidList;
 
+  QString cid;
+  int blp = 0;
+  
   for( int index = 0; index < contactsNode.count(); index++ )
   {
     const QDomNode contact( contactsNode.item( index ) );
@@ -591,11 +594,10 @@ void AddressBookService::parseAddressBook( const QDomElement &body )
     // Check if the contact type is Me: it has the information about personal profile
     if( contactType == "Me" )
     {
-      const QString cid( XmlFunctions::getNodeValue( contactInfo, "CID" ) );
+      cid = XmlFunctions::getNodeValue( contactInfo, "CID" );
 
       // Search for "<annotations>...<Annotation><name>MSN.IM.BLP<name><value>VALUE<value><Annotation>.."
       const QDomNodeList annotations( contactInfo.toElement().elementsByTagName( "Annotation" ) );
-      int blp = 0; // = 0 fixes compile time warning
       for( int index2 = 0; index2 < annotations.count(); index2++ )
       {
         const QDomNode annotation( annotations.at( index2 ) );
@@ -608,7 +610,6 @@ void AddressBookService::parseAddressBook( const QDomElement &body )
         }
       }
 
-      emit gotPersonalInformation( cid, blp );
       continue;
     }
 
@@ -640,7 +641,7 @@ void AddressBookService::parseAddressBook( const QDomElement &body )
     // easy the life of the users...for the moment..:P
     if( handle.isEmpty() || handle == "messenger@microsoft.com" )
     {
-      kWarning() << "Skipped 'messenger@microsoft.com' contact!";
+      kmWarning() << "Skipped 'messenger@microsoft.com' contact!";
       continue;
     }
 
@@ -682,11 +683,16 @@ void AddressBookService::parseAddressBook( const QDomElement &body )
   }
 
 #ifdef KMESSDEBUG_ADDRESSBOOKSERVICE
-  kDebug() << "Address book successfully parsed: found" << contacts.count() << "contacts and" << debugGroupCount << "groups.";
+  kmDebug() << "Address book successfully parsed: found" << contacts.count() << "contacts and" << debugGroupCount << "groups.";
 #endif
 
   // Signal that the of address book has been parsed
   emit gotAddressBookList( contacts );
+  
+  // adam (16 Jan 11) - shifted the signal emit for this
+  // to after the address book is parsed. This prevents SOAP timeouts
+  // with Roaming Service requests for large contact lists.
+  emit gotPersonalInformation( cid, blp );
 }
 
 
@@ -712,7 +718,7 @@ void AddressBookService::parseMembershipLists( const QDomElement &body )
 
     if( serviceType.isEmpty() )
     {
-      kWarning() << "Retrieved unknown service type!";
+      kmWarning() << "Retrieved unknown service type!";
       continue;
     }
 
@@ -744,7 +750,7 @@ void AddressBookService::parseMembershipLists( const QDomElement &body )
       else if( role == "Pending" ) roleId = Contact::MSN_LIST_PENDING;
       else
       {
-        kWarning() << "Unknown membership role" << role << "in service" << serviceType << "!";
+        kmWarning() << "Unknown membership role" << role << "in service" << serviceType << "!";
         continue;
       }
 
@@ -778,7 +784,7 @@ void AddressBookService::parseMembershipLists( const QDomElement &body )
         QString type = XmlFunctions::getNodeValue( memberNode, "Type" ).toLower();
         if ( type != "passport" )
         {
-          kDebug() << "Skipped non-passport contact" << handle;
+          kmDebug() << "Skipped non-passport contact" << handle;
           continue;
         }
 
@@ -807,7 +813,7 @@ void AddressBookService::parseSecureFault( SoapMessage *message )
   // Should never happen
   if( ! message->isFaultMessage() )
   {
-    kWarning() << "Incorrect fault detected on incoming message";
+    kmWarning() << "Incorrect fault detected on incoming message";
     return;
   }
 
@@ -829,7 +835,7 @@ void AddressBookService::parseSecureFault( SoapMessage *message )
     {
       QString email( info.toStringList().first() );
 
-      kWarning() << "Malformed email address found by the server:" << email;
+      kmWarning() << "Malformed email address found by the server:" << email;
 
       emit soapWarning( i18nc( "Warning message",
                                "The specified email address, \"%1\", is not a valid email address!",
@@ -857,7 +863,7 @@ void AddressBookService::parseSecureFault( SoapMessage *message )
     else if( errorCode == "ABDoesNotExist" )
     {
 #ifdef KMESSDEBUG_ADDRESSBOOKSERVICE
-      kDebug() << "Address book does not exist: creating new one.";
+      kmDebug() << "Address book does not exist: creating new one.";
 #endif
       createAddressBook();
       return;
@@ -920,7 +926,7 @@ void AddressBookService::parseSecureResult( SoapMessage *message )
   {
     // New address book was created: proceed with it
 #ifdef KMESSDEBUG_ADDRESSBOOKSERVICE
-    kDebug() << "Address book successfully created: retrying to obtain membership lists.";
+    kmDebug() << "Address book successfully created: retrying to obtain membership lists.";
 #endif
     retrieveMembershipLists();
     return;
@@ -942,17 +948,19 @@ void AddressBookService::parseSecureResult( SoapMessage *message )
     if( ! contactId.isEmpty() && ! handle.isEmpty() )
     {
       emit contactAdded( handle, contactId, groupsId );
+      emit addressBookChanged( handle, ContactAdded );
     }
   }
   else if( data.type == "ContactDelete" )
   {
     // A contact was deleted from the AB
-
     const QString contactId( data.value.toString() );
+    const QString handle (data.value.toString() );
 
     if( ! contactId.isEmpty() )
     {
-      emit contactDeleted( contactId );
+      emit contactDeleted( contactId, handle );
+      emit addressBookChanged( handle, ContactDeleted );
     }
   }
   else if( data.type == "ContactBlock" || data.type == "ContactUnblock" )
@@ -966,10 +974,12 @@ void AddressBookService::parseSecureResult( SoapMessage *message )
     if( role == "BL" )
     {
       emit contactBlocked( handle );
+      emit addressBookChanged( handle, ContactBlocked );
     }
     else if( role == "AL" )
     {
       emit contactUnblocked( handle );
+      emit addressBookChanged( handle, ContactUnblock );
     }
   }
   else if( data.type == "ContactAddToGroup" )
@@ -982,6 +992,7 @@ void AddressBookService::parseSecureResult( SoapMessage *message )
     if( ! contactId.isEmpty() && ! groupId.isEmpty() )
     {
       emit contactAddedToGroup( contactId, groupId );
+      emit addressBookChanged( contactId, ContactAddedToGroup );
     }
   }
   else if( data.type == "ContactDeleteFromGroup" )
@@ -995,6 +1006,7 @@ void AddressBookService::parseSecureResult( SoapMessage *message )
     if( ! contactId.isEmpty() && ! groupId.isEmpty() )
     {
       emit contactDeletedFromGroup( contactId, groupId );
+      emit addressBookChanged( contactId, ContactDeletedFromGroup );
     }
   }
   else if( data.type == "GroupAdd" )
@@ -1006,16 +1018,19 @@ void AddressBookService::parseSecureResult( SoapMessage *message )
     if( ! groupId.isEmpty() && ! name.isEmpty() )
     {
       emit groupAdded( groupId, name );
+      emit addressBookChanged( groupId, GroupAdded );
     }
   }
   else if( data.type == "GroupDelete" )
   {
     // A group was removed
     const QString groupId( data.value.toString() );
-
+    const QStringList info  ( data.value.toStringList() );
+    const QString             name( info.value( 0 ) );
     if( ! groupId.isEmpty() )
     {
-      emit groupDeleted( groupId );
+      emit groupDeleted( groupId, name );
+      emit addressBookChanged( name, GroupDeleted );
     }
   }
   else if( data.type == "GroupRename" )
@@ -1028,11 +1043,12 @@ void AddressBookService::parseSecureResult( SoapMessage *message )
     if( ! groupId.isEmpty() && ! name.isEmpty() )
     {
       emit groupRenamed( groupId, name );
+      emit addressBookChanged( name, GroupRenamed );
     }
   }
   else
   {
-    kWarning() << "Response data not recognized:" << data.type;
+    kmWarning() << "Response data not recognized:" << data.type;
   }
 }
 
