@@ -66,7 +66,7 @@ HttpSoapConnection::HttpSoapConnection( QObject *parent )
 , isSending_( false )
 {
 #ifdef KMESSDEBUG_HTTPSOAPCONNECTION_GENERAL
-  kDebug() << "CREATED.";
+  kmDebug() << "CREATED.";
 #endif
 
   // Create the network request object
@@ -101,7 +101,7 @@ HttpSoapConnection::~HttpSoapConnection()
   delete http_;
 
 #ifdef KMESSDEBUG_HTTPSOAPCONNECTION_GENERAL
-  kDebug() << "DESTROYED.";
+  kmDebug() << "DESTROYED.";
 #endif
 }
 
@@ -172,7 +172,7 @@ bool HttpSoapConnection::isIdle()
 bool HttpSoapConnection::parseHttpBody( const QByteArray &responseBody )
 {
 #ifdef KMESSDEBUG_HTTPSOAPCONNECTION_GENERAL
-  kDebug() << "Request finished, pasing body.";
+  kmDebug() << "Request finished, pasing body.";
 #endif
 
   // Attempt to convert to XML
@@ -181,7 +181,7 @@ bool HttpSoapConnection::parseHttpBody( const QByteArray &responseBody )
   QDomDocument xml;
   if( ! xml.setContent( responseBody, true, &xmlError ) )   // true for namespace processing.
   {
-    kWarning() << "Unable to parse XML "
+    kmWarning() << "Unable to parse XML "
                   "(error='" << xmlError << "' endpoint=" << endpoint_ << ")" << endl;
     return false;
   }
@@ -194,7 +194,7 @@ bool HttpSoapConnection::parseHttpBody( const QByteArray &responseBody )
   if( ! faultNode.isNull() )
   {
 #ifdef KMESSDEBUG_HTTPSOAPCONNECTION_GENERAL
-    kDebug() << "Found soap fault outside the body!";
+    kmDebug() << "Found soap fault outside the body!";
 #endif
     closeConnection();
     parseSoapFault( faultNode, headerNode );
@@ -205,7 +205,7 @@ bool HttpSoapConnection::parseHttpBody( const QByteArray &responseBody )
   QDomElement resultNode = XmlFunctions::getNode(xml, "/Envelope/Body").firstChild().toElement();
   if( resultNode.isNull() )
   {
-    kWarning() << "Unable to parse response: result node is null "
+    kmWarning() << "Unable to parse response: result node is null "
                 << "(root=" << xml.nodeName()  << " endpoint=" << endpoint_ << ")." << endl;
     return false;
   }
@@ -216,7 +216,7 @@ bool HttpSoapConnection::parseHttpBody( const QByteArray &responseBody )
   &&  resultNode.namespaceURI() == XMLNS_SOAP )
   {
 #ifdef KMESSDEBUG_HTTPSOAPCONNECTION_GENERAL
-    kDebug() << "Found soap fault.";
+    kmDebug() << "Found soap fault.";
 #endif
     closeConnection();
     parseSoapFault( resultNode, headerNode );
@@ -236,7 +236,7 @@ bool HttpSoapConnection::parseHttpBody( const QByteArray &responseBody )
 
   // Request completed, indicate derived class and listeners.
 #ifdef KMESSDEBUG_HTTPSOAPCONNECTION_GENERAL
-  kDebug() << "Request finished, signalling to start parsing of the result node "
+  kmDebug() << "Request finished, signalling to start parsing of the result node "
               "(name:"      << resultNode.nodeName()     <<
               " prefix:"    << resultNode.prefix()       <<
               " localName:" << resultNode.localName()    <<
@@ -317,7 +317,7 @@ void HttpSoapConnection::sendNextRequest()
     endpoint.setHost( redirections_[ endpoint.host() ] );
 
 #ifdef KMESSDEBUG_HTTPSOAPCONNECTION_GENERAL
-    kDebug() << "Sending with redirection from:" << endpointAddress << "to:" << endpoint;
+    kmDebug() << "Sending with redirection from:" << endpointAddress << "to:" << endpoint;
 #endif
   }
 
@@ -373,8 +373,8 @@ void HttpSoapConnection::sendNextRequest()
 #endif
 
 #ifdef KMESSDEBUG_HTTPSOAPCONNECTION_HTTPDUMP
-  kDebug() << "Request contents:";
-  kDebug() << contents;
+  kmDebug() << "Request contents:";
+  kmDebug() << contents;
 #endif
 }
 
@@ -395,11 +395,11 @@ void HttpSoapConnection::sendRequest( SoapMessage *message, bool urgent )
 #ifdef KMESSDEBUG_HTTPSOAPCONNECTION_GENERAL
   if( urgent )
   {
-    kDebug() << "Immediately sending message to endpoint:" << message->getEndPoint();
+    kmDebug() << "Immediately sending message to endpoint:" << message->getEndPoint();
   }
   else
   {
-    kDebug() << "Queueing message to endpoint:" << message->getEndPoint();
+    kmDebug() << "Queueing message to endpoint:" << message->getEndPoint();
   }
 #endif
 
@@ -426,7 +426,7 @@ void HttpSoapConnection::slotAuthenticationRequired( QNetworkReply *reply, QAuth
   // A response has arrived, stop the timeout detection timer
   responseTimer_.stop();
 
-  kWarning() << "Got http authentication request for" << authenticator->realm() <<
+  kmWarning() << "Got http authentication request for" << authenticator->realm() <<
                 "while connecting to" << reply->url();
 
   // Inform listeners that the request failed
@@ -446,7 +446,7 @@ void HttpSoapConnection::slotRequestFinished( QNetworkReply *reply )
   // An unexpected response has arrived
   if( currentRequest_ == 0 )
   {
-    kWarning() << "No request in progress!";
+    kmWarning() << "No request in progress!";
     return;
   }
 
@@ -460,17 +460,17 @@ void HttpSoapConnection::slotRequestFinished( QNetworkReply *reply )
 #ifdef KMESSDEBUG_HTTPSOAPCONNECTION_GENERAL
   bool requestSuccess = false;
   const QUrl replyUrl( reply->url() );
-  kDebug() << "Received response: code" << statusCode
+  kmDebug() << "Received response: code" << statusCode
            << reply->attribute( QNetworkRequest::HttpReasonPhraseAttribute )
            << " from" << replyUrl;
 #endif
 #ifdef KMESSDEBUG_HTTPSOAPCONNECTION_HTTPDUMP
-  kDebug() << "Reply contents:";
+  kmDebug() << "Reply contents:";
 
   // Create the document with the content of SOAP reply to indent it
   QDomDocument document;
   document.setContent( replyContents );
-  kDebug() << document.toString();
+  kmDebug() << document.toString();
 #endif
 
   // Parse the body of the HTTP response (copying the other attributes from the request)
@@ -501,7 +501,7 @@ void HttpSoapConnection::slotRequestFinished( QNetworkReply *reply )
         const QString redirectHost( redirectUrl.host() );
 
 #ifdef KMESSDEBUG_HTTPSOAPCONNECTION_GENERAL
-        kDebug() << "Received redirection from:" << originalHost << "to:" << redirectHost;
+        kmDebug() << "Received redirection from:" << originalHost << "to:" << redirectHost;
 #endif
 
         // Save the redirection target
@@ -543,7 +543,7 @@ void HttpSoapConnection::slotRequestFinished( QNetworkReply *reply )
       if( ! preferredHostName.isEmpty() && ! redirections_.contains( originalHost ) )
       {
 #ifdef KMESSDEBUG_HTTPSOAPCONNECTION_GENERAL
-        kDebug() << "Received hostname suggestion from:" << originalUrl << "to:" << preferredHostName;
+        kmDebug() << "Received hostname suggestion from:" << originalUrl << "to:" << preferredHostName;
 #endif
 
         redirectionCounts_[ originalHost ] = 0;
@@ -572,10 +572,10 @@ void HttpSoapConnection::slotRequestFinished( QNetworkReply *reply )
   else
   {
     // Display at the console for logging
-    kWarning() << "Received an unknown" << statusCode << "status code (" << error
+    kmWarning() << "Received an unknown" << statusCode << "status code (" << error
                << ") while connecting to endpoint" << reply->url();
-    kWarning() << "Reply contents:";
-    kWarning() << replyContents;
+    kmWarning() << "Reply contents:";
+    kmWarning() << replyContents;
 
     // Inform listeners that the request failed
     emit soapError( i18nc( "Error message with description (system-generated description)",
@@ -596,7 +596,7 @@ void HttpSoapConnection::slotRequestFinished( QNetworkReply *reply )
   isSending_ = false;
 
 #ifdef KMESSDEBUG_HTTPSOAPCONNECTION_GENERAL
-  kDebug() << "Completed response handling from endpoint" << replyUrl << ", with success?" << requestSuccess;
+  kmDebug() << "Completed response handling from endpoint" << replyUrl << ", with success?" << requestSuccess;
 #endif
 
   // Send the next queued message
@@ -631,7 +631,7 @@ void HttpSoapConnection::slotSslErrors( QNetworkReply *reply, const QList<QSslEr
 {
   foreach( QSslError error, sslErrors )
   {
-    kWarning() << "Got SSL error" << error.errorString() << "while connecting to endpoint" << reply->url();
+    kmWarning() << "Got SSL error" << error.errorString() << "while connecting to endpoint" << reply->url();
   }
 
   // It's needed to ignore SSL errors because rsi.hotmail.com uses an invalid certificate.
