@@ -69,7 +69,7 @@ OfflineImService::OfflineImService( const QString &authT, const QString &authP,
 , nextSequenceNum_(0)
 {
 #ifdef KMESSDEBUG_OFFLINE_IM_GENERAL
-  kDebug() << "CREATED offline IM receiver service";
+  kmDebug() << "CREATED offline IM receiver service";
 #endif
 
   setObjectName( "OfflineImService[receiver]" );
@@ -96,7 +96,7 @@ OfflineImService::OfflineImService( QObject *parent )
   , nextSequenceNum_(0)
 {
 #ifdef KMESSDEBUG_OFFLINE_IM_GENERAL
-  kDebug() << "CREATED offline IM sender service";
+  kmDebug() << "CREATED offline IM sender service";
 #endif
 
   setObjectName( "OfflineImService[sender]" );
@@ -110,7 +110,7 @@ OfflineImService::OfflineImService( QObject *parent )
 OfflineImService::~OfflineImService()
 {
 #ifdef KMESSDEBUG_OFFLINE_IM_GENERAL
-  kDebug() << "DESTROYED.";
+  kmDebug() << "DESTROYED.";
 #endif
 }
 
@@ -123,7 +123,7 @@ OfflineImService::~OfflineImService()
 void OfflineImService::deleteMessages( const QStringList &messageIds )
 {
 #ifdef KMESSDEBUG_OFFLINE_IM_GENERAL
-  kDebug() << "requesting deletion of messages:" << messageIds;
+  kmDebug() << "requesting deletion of messages:" << messageIds;
 #endif
 #ifdef KMESSTEST
   KMESS_ASSERT( ! messageIds.isEmpty() );
@@ -184,7 +184,7 @@ QString OfflineImService::extractRFC822Address( const QString &address )
 void OfflineImService::getMessage( const QString &messageId, bool markAsRead )
 {
 #ifdef KMESSDEBUG_OFFLINE_IM_GENERAL
-  kDebug() << "requesting message with ID:" << messageId;
+  kmDebug() << "requesting message with ID:" << messageId;
 #endif
 
   // Initialize the call data, which will be used in the slots to know which session this was
@@ -221,7 +221,7 @@ void OfflineImService::getMessage( const QString &messageId, bool markAsRead )
 void OfflineImService::getMetaData()
 {
 #ifdef KMESSDEBUG_OFFLINE_IM_GENERAL
-  kDebug() << "requesting Mail-Data field";
+  kmDebug() << "requesting Mail-Data field";
 #endif
 
   // Initialize the call data, which will be used in the slots to know which session this was
@@ -246,7 +246,7 @@ void OfflineImService::parseSecureFault( SoapMessage *message )
   // Should never happen
   if( ! message->isFaultMessage() )
   {
-    kWarning() << "Incorrect fault detected on incoming message";
+    kmWarning() << "Incorrect fault detected on incoming message";
     return;
   }
 
@@ -285,8 +285,8 @@ void OfflineImService::parseSecureFault( SoapMessage *message )
       currentAccount_->setOfflineImKey( handler.computeHash( lockKeyChallenge ) );
 
 #ifdef KMESSDEBUG_OFFLINE_IM_GENERAL
-      kDebug() << "Lock key to compute:" << lockKeyChallenge;
-      kDebug() << "Computed lock key:"   << currentAccount_->getOfflineImKey();
+      kmDebug() << "Lock key to compute:" << lockKeyChallenge;
+      kmDebug() << "Computed lock key:"   << currentAccount_->getOfflineImKey();
 #endif
       // Check if there is a TweenerChallenge, and if not re-send the message with the new lock key
       if( tweenerChallenge.isEmpty() )
@@ -305,7 +305,7 @@ void OfflineImService::parseSecureFault( SoapMessage *message )
     }
 
     // Any other situation means something is wrong.
-    kWarning() << "Unknown challenge type received";
+    kmWarning() << "Unknown challenge type received";
     emit sendMessageFailed( recipient, originalMessage );
   }
   else if( faultCode == "q0:SystemUnavailable"              // contact does not exist OR has blocked you (unlikely)
@@ -318,12 +318,12 @@ void OfflineImService::parseSecureFault( SoapMessage *message )
     emit sendMessageFailed( recipient, originalMessage );
 
     // Also report at the console.
-    kWarning() << "Received SOAP fault" << faultCode << "when sending an offline-im message to" << recipient;
+    kmWarning() << "Received SOAP fault" << faultCode << "when sending an offline-im message to" << recipient;
   }
   else
   {
     // Any other situation means something is wrong.
-    kWarning() << "Unknown response type received: fault code:" << faultCode
+    kmWarning() << "Unknown response type received: fault code:" << faultCode
                << "endpoint:" << message->getEndPoint();
 
     // Notify the sender if this error was
@@ -352,7 +352,7 @@ void OfflineImService::parseSecureFault( SoapMessage *message )
 void OfflineImService::parseSecureResult( SoapMessage *message )
 {
 #ifdef KMESSDEBUG_OFFLINE_IM_GENERAL
-  kDebug() << "parsing SOAP response.";
+  kmDebug() << "parsing SOAP response.";
 #endif
 
   QDomElement body      ( message->getBody().toElement() );
@@ -377,7 +377,7 @@ void OfflineImService::parseSecureResult( SoapMessage *message )
     QString     recipient( info.value( 0 ) );
     QString     contents ( info.value( 1 ) );
 
-    kDebug() << "Stored offline message for" << recipient << ":" << contents;
+    kmDebug() << "Stored offline message for" << recipient << ":" << contents;
 #endif
 
     // Reset the session ID
@@ -385,7 +385,7 @@ void OfflineImService::parseSecureResult( SoapMessage *message )
   }
   else
   {
-    kWarning() << "Unknown response type" << resultName << "received from endpoint" << message->getEndPoint();
+    kmWarning() << "Unknown response type" << resultName << "received from endpoint" << message->getEndPoint();
   }
 }
 
@@ -402,7 +402,7 @@ void OfflineImService::parseSecureResult( SoapMessage *message )
 void OfflineImService::processGetMessageResult( SoapMessage *message )
 {
 #ifdef KMESSDEBUG_OFFLINE_IM_GENERAL
-  kDebug() << "Parsing downloaded Offline-IM message.";
+  kmDebug() << "Parsing downloaded Offline-IM message.";
 #endif
 
   // Retrieve the data stored in the SOAP message
@@ -439,21 +439,21 @@ void OfflineImService::processGetMessageResult( SoapMessage *message )
   QString contentType( mimeMessage.getValue( "Content-Type" ) );
   if( contentType.toLower() != "text/plain; charset=utf-8" )
   {
-    kWarning() << "Received unexpected content type:" << contentType;
+    kmWarning() << "Received unexpected content type:" << contentType;
   }
 
   // Validate transfer encoding
   QString transferEncoding( mimeMessage.getValue( "Content-Transfer-Encoding" ) );
   if( transferEncoding != "base64" )
   {
-    kWarning() << "Received unexpected transfer encoding:" << transferEncoding;
+    kmWarning() << "Received unexpected transfer encoding:" << transferEncoding;
   }
 
   // Validate message type
   QString messageType( mimeMessage.getValue( "X-OIM-Message-Type" ) );
   if( messageType != "OfflineMessage" )
   {
-    kWarning() << "Received unexpected message type:" << messageType;
+    kmWarning() << "Received unexpected message type:" << messageType;
   }
 
   // Process the body
