@@ -86,7 +86,7 @@ PassportLoginService::~PassportLoginService()
 void PassportLoginService::login( const QString &parameters )
 {
 #ifdef KMESSDEBUG_PASSPORTLOGINSERVICE
-  kDebug() << "Logging in...";
+  kmDebug() << "Logging in...";
 #endif
 
   // Store the account and login data
@@ -113,6 +113,10 @@ void PassportLoginService::login( const QString &parameters )
   KMESS_ASSERT( ! password_.isEmpty() );
 #endif
 
+  // The Live platform doesn't accept passwords longer than 16 characters.
+  // Great security measure, good job Microsoft!
+  password_.truncate( 16 );
+
   // Send the login request
   requestMultipleSecurityTokens();
 }
@@ -201,7 +205,7 @@ void PassportLoginService::parseSecureResult( SoapMessage *message )
 {
   const QString resultType( message->getBody().firstChildElement().nodeName() );
 
-  kWarning() << "Could not parse response type" << resultType
+  kmWarning() << "Could not parse response type" << resultType
               << "from endpoint" << message->getEndPoint();
 
   emit soapError( i18nc( "Error message (sytem-generated description)",
@@ -283,7 +287,7 @@ void PassportLoginService::parseSoapFault( SoapMessage *message )
   // Should never happen
   if( ! message->isFaultMessage() )
   {
-    kWarning() << "Incorrect fault detected on incoming message";
+    kmWarning() << "Incorrect fault detected on incoming message";
     return;
   }
 
@@ -294,7 +298,7 @@ void PassportLoginService::parseSoapFault( SoapMessage *message )
   if( faultCode == "wsse:FailedAuthentication" )
   {
 #ifdef KMESSDEBUG_PASSPORTLOGINSERVICE
-    kDebug() << "Authentication failed!";
+    kmDebug() << "Authentication failed!";
 #endif
 
     emit loginIncorrect();
@@ -436,8 +440,8 @@ void PassportLoginService::parseSoapResult( SoapMessage *message )
   }
 
 #ifdef KMESSDEBUG_PASSPORTLOGINSERVICE
-  kDebug() << "Current date:" << QDateTime::currentDateTime();
-  kDebug() << "Obtaining security tokens..";
+  kmDebug() << "Current date:" << QDateTime::currentDateTime();
+  kmDebug() << "Obtaining security tokens..";
 #endif
 
   const QDomNodeList authTokens( body.childNodes() );
@@ -450,7 +454,7 @@ void PassportLoginService::parseSoapResult( SoapMessage *message )
 
   const QDateTime &now = QDateTime::currentDateTime();
 #ifdef KMESSDEBUG_PASSPORTLOGINSERVICE
-  kDebug() << "Current date and time:" << now;
+  kmDebug() << "Current date and time:" << now;
 #endif
 
   // Set the token and proof for hotmail live services (mail, spaces etc..)
@@ -490,7 +494,7 @@ void PassportLoginService::parseSoapResult( SoapMessage *message )
     if( ! creationDate.isValid() || ! expirationDate.isValid() )
     {
 #ifdef KMESSDEBUG_PASSPORTLOGINSERVICE
-      kDebug() << "Invalid token creation/expiration dates. Defaulting to 8 hours duration for token on next line:";
+      kmDebug() << "Invalid token creation/expiration dates. Defaulting to 8 hours duration for token on next line:";
 #endif
       ticketDuration = 3600 * 8;
     }
@@ -502,11 +506,11 @@ void PassportLoginService::parseSoapResult( SoapMessage *message )
     const QDateTime &localExpirationDate = now.addSecs( ticketDuration );
 
 #ifdef KMESSDEBUG_PASSPORTLOGINSERVICE
-    kDebug() << "--";
-    kDebug() << "Found token for endpoint:" << referenceEndPoint << "with a duration of" << ticketDuration << "seconds.";
-    kDebug() << "Created:" << creationString
+    kmDebug() << "--";
+    kmDebug() << "Found token for endpoint:" << referenceEndPoint << "with a duration of" << ticketDuration << "seconds.";
+    kmDebug() << "Created:" << creationString
              << "Expires:" << expirationString;
-    kDebug() << "Expires at local time:" << localExpirationDate;
+    kmDebug() << "Expires at local time:" << localExpirationDate;
 #endif
 
     if( referenceEndPoint == "http://Passport.NET/tb" )
@@ -560,7 +564,7 @@ void PassportLoginService::parseSoapResult( SoapMessage *message )
   }
 
 #ifdef KMESSDEBUG_PASSPORTLOGINSERVICE
-  kDebug() << "Obtained" << tokens.count() << "security tokens:" << tokens.keys();
+  kmDebug() << "Obtained" << tokens.count() << "security tokens:" << tokens.keys();
 #endif
 
   // Save the tokens
@@ -576,7 +580,7 @@ void PassportLoginService::parseSoapResult( SoapMessage *message )
     sendSecureRequest( it.key(), it.value() );
   }
 #ifdef KMESSDEBUG_PASSPORTLOGINSERVICE
-  kDebug() << "Sent" << queuedRequests_.count() << "queued messages.";
+  kmDebug() << "Sent" << queuedRequests_.count() << "queued messages.";
 #endif
 
 
@@ -644,7 +648,7 @@ void PassportLoginService::parseSoapResult( SoapMessage *message )
 void PassportLoginService::requestMultipleSecurityTokens()
 {
 #ifdef KMESSDEBUG_PASSPORTLOGINSERVICE
-  kDebug() << "Requesting security tokens";
+  kmDebug() << "Requesting security tokens";
 #endif
 
   const QString authParams( KMessShared::htmlEscape( QUrl::fromPercentEncoding( authenticationParameters_.toUtf8() )
@@ -775,7 +779,7 @@ void PassportLoginService::sendSecureRequest( SoapMessage *message, const QStrin
   }
 
 #ifdef KMESSDEBUG_PASSPORTLOGINSERVICE
-  kDebug() << "Sending secure request with token:" << requiredTokenName;
+  kmDebug() << "Sending secure request with token:" << requiredTokenName;
 #endif
 
   const QString tokenValue( currentAccount_->getToken( requiredTokenName ) );
@@ -784,16 +788,16 @@ void PassportLoginService::sendSecureRequest( SoapMessage *message, const QStrin
   int timeDifference = QDateTime::currentDateTime().secsTo( tokenExpiration );
 
 #ifdef KMESSDEBUG_PASSPORTLOGINSERVICE
-  kDebug() << "Token has a value?" << (!tokenValue.isEmpty());
-  kDebug() << "Current time:" << QDateTime::currentDateTime();
-  kDebug() << "Token expires on:" << tokenExpiration << ", that is within seconds:" << timeDifference;
+  kmDebug() << "Token has a value?" << (!tokenValue.isEmpty());
+  kmDebug() << "Current time:" << QDateTime::currentDateTime();
+  kmDebug() << "Token expires on:" << tokenExpiration << ", that is within seconds:" << timeDifference;
 #endif
 
   // If there is no value for this token, or the token is about to expire, ask a new one
   if( tokenValue.isEmpty() || timeDifference < 10 )
   {
 #ifdef KMESSDEBUG_PASSPORTLOGINSERVICE
-    kDebug() << "Token is expired or invalid.";
+    kmDebug() << "Token is expired or invalid.";
 #endif
 
     // Queue the message
@@ -806,13 +810,13 @@ void PassportLoginService::sendSecureRequest( SoapMessage *message, const QStrin
     if( isWaitingForNewTokens_ )
     {
 #ifdef KMESSDEBUG_PASSPORTLOGINSERVICE
-      kDebug() << "Already requesting new tokens.";
+      kmDebug() << "Already requesting new tokens.";
 #endif
       return;
     }
 
 #ifdef KMESSDEBUG_PASSPORTLOGINSERVICE
-    kDebug() << "Asking for new tokens.";
+    kmDebug() << "Asking for new tokens.";
 #endif
 
     // Ask for new tokens, altogether instead of just one at a time,
@@ -822,7 +826,7 @@ void PassportLoginService::sendSecureRequest( SoapMessage *message, const QStrin
   }
 
 #ifdef KMESSDEBUG_PASSPORTLOGINSERVICE
-  kDebug() << "Token is valid, adding it to the request.";
+  kmDebug() << "Token is valid, adding it to the request.";
 #endif
 
   // Insert the token value within the SOAP message header
@@ -840,7 +844,7 @@ void PassportLoginService::sendSecureRequest( SoapMessage *message, const QStrin
   // None of the ticket token tags were found, send the message as is
   if( list.isEmpty() )
   {
-    kWarning() << "Token tag not found! Sending the request as is.";
+    kmWarning() << "Token tag not found! Sending the request as is.";
 
     sendRequest( message );
     return;
@@ -854,7 +858,7 @@ void PassportLoginService::sendSecureRequest( SoapMessage *message, const QStrin
     if( item.tagName() == "TicketToken" )
     {
 #ifdef KMESSDEBUG_PASSPORTLOGINSERVICE
-      kDebug() << "TicketToken tag found!";
+      kmDebug() << "TicketToken tag found!";
 #endif
 
       // If there is a child text node, simply replace its text
@@ -874,7 +878,7 @@ void PassportLoginService::sendSecureRequest( SoapMessage *message, const QStrin
     if( item.tagName() == "Ticket" )
     {
 #ifdef KMESSDEBUG_PASSPORTLOGINSERVICE
-      kDebug() << "Ticket tag found!";
+      kmDebug() << "Ticket tag found!";
 #endif
       item.setAttribute( "passport", tokenValue );
       break;
@@ -889,7 +893,7 @@ void PassportLoginService::sendSecureRequest( SoapMessage *message, const QStrin
   inProgressRequests_.insert( message, requiredTokenName );
 
 #ifdef KMESSDEBUG_PASSPORTLOGINSERVICE
-  kDebug() << "Sending authenticated request.";
+  kmDebug() << "Sending authenticated request.";
 #endif
 
   // Send the changed message
