@@ -138,7 +138,7 @@ void RoamingService::updateProfile()
 
   if( profileResourceId_.isEmpty() )
   {
-    kWarning() << "Missing profileResourceId, not updating profile";
+    kmWarning() << "Missing profileResourceId, not updating profile";
     return;
   }
 
@@ -146,7 +146,7 @@ void RoamingService::updateProfile()
       currentAccount->getFriendlyName( STRING_ORIGINAL ) == lastKnownFriendlyName_ )
   {
 #ifdef KMESSDEBUG_ROAMINGSERVICE
-    kDebug() << "Personal message and friendly name are same as on server; not uploading changes.";
+    kmDebug() << "Personal message and friendly name are same as on server; not uploading changes.";
 #endif
     return;
   }
@@ -157,7 +157,7 @@ void RoamingService::updateProfile()
   lastKnownFriendlyName_    = currentAccount->getFriendlyName( STRING_ORIGINAL );
 
 #ifdef KMESSDEBUG_ROAMINGSERVICE
-  kDebug() << "Uploading personal message, profile ID:" << profileResourceId_;
+  kmDebug() << "Uploading personal message, profile ID:" << profileResourceId_;
 #endif
   QString body( "<UpdateProfile xmlns=\"http://www.msn.com/webservices/storage/w10\">\n"
                 "<profile>\n"
@@ -194,7 +194,7 @@ void RoamingService::updateDisplayPicture()
 
   if( profileResourceId_.isEmpty() )
   {
-    kWarning() << "Missing profileResourceId, not updating display picture";
+    kmWarning() << "Missing profileResourceId, not updating display picture";
     return;
   }
 
@@ -202,7 +202,7 @@ void RoamingService::updateDisplayPicture()
   if( path == lastKnownDisplayPicturePath_ )
   {
 #ifdef KMESSDEBUG_ROAMINGSERVICE
-    kDebug() << "Not updating display picture, already the same as on the server.";
+    kmDebug() << "Not updating display picture, already the same as on the server.";
 #endif
     return;
   }
@@ -212,7 +212,7 @@ void RoamingService::updateDisplayPicture()
   if( ! displayPictureResourceId_.isEmpty() )
   {
 #ifdef KMESSDEBUG_ROAMINGSERVICE
-    kDebug() << "Deleting the previous display picture on the server.";
+    kmDebug() << "Deleting the previous display picture on the server.";
 #endif
     deleteRelationships( "", displayPictureResourceId_ );
     deleteRelationships( profileResourceId_, displayPictureResourceId_ );
@@ -220,7 +220,7 @@ void RoamingService::updateDisplayPicture()
 
   // upload new picture
 #ifdef KMESSDEBUG_ROAMINGSERVICE
-  kDebug() << "Uploading new display picture.";
+  kmDebug() << "Uploading new display picture.";
 #endif
   QFile file( currentAccount->getPicturePath() );
   if( file.open( QIODevice::ReadOnly ) )
@@ -236,7 +236,7 @@ void RoamingService::updateDisplayPicture()
   }
   else
   {
-    kWarning() << "Failed to read display picture from file" << currentAccount->getPicturePath();
+    kmWarning() << "Failed to read display picture from file" << currentAccount->getPicturePath();
   }
 }
 
@@ -248,7 +248,7 @@ void RoamingService::parseSecureFault( SoapMessage *message )
   // Should never happen
   if( ! message->isFaultMessage() )
   {
-    kWarning() << "Incorrect fault detected on incoming message";
+    kmWarning() << "Incorrect fault detected on incoming message";
     return;
   }
 
@@ -263,19 +263,19 @@ void RoamingService::parseSecureFault( SoapMessage *message )
     if( errorCode == "ItemDoesNotExist" )
     {
 #ifdef KMESSDEBUG_ROAMINGSERVICE
-      kDebug() << "The profile of the user does not exist: creating one.";
+      kmDebug() << "The profile of the user does not exist: creating one.";
 #endif
       createProfile();
       return;
     }
     else if( errorCode == "ItemAlreadyExists" )
     {
-      kWarning() << "The profile of the user already exists";
+      kmWarning() << "The profile of the user already exists";
     }
   }
   else
   {
-    kWarning() << "Invalid web service request:" << message->getFaultDescription();
+    kmWarning() << "Invalid web service request:" << message->getFaultDescription();
   }
 }
 
@@ -290,14 +290,14 @@ void RoamingService::parseSecureResult( SoapMessage *message )
   if( resultName == "GetProfileResponse" )
   {
 #ifdef KMESSDEBUG_ROAMINGSERVICE
-    kDebug() << "Getting profile response:" << profileResourceId_;
+    kmDebug() << "Getting profile response:" << profileResourceId_;
 #endif
     processProfileResult( body );
   }
   else if( resultName == "UpdateProfileResponse" )
   {
 #ifdef KMESSDEBUG_ROAMINGSERVICE
-    kDebug() << "Updated profile:" << profileResourceId_;
+    kmDebug() << "Updated profile:" << profileResourceId_;
 #endif
     return;
   }
@@ -306,7 +306,7 @@ void RoamingService::parseSecureResult( SoapMessage *message )
     profileResourceId_ = XmlFunctions::getNodeValue( body, "CreateProfileResponse/CreateProfileResult" );
 
 #ifdef KMESSDEBUG_ROAMINGSERVICE
-    kDebug() << "Created profile:" << profileResourceId_;
+    kmDebug() << "Created profile:" << profileResourceId_;
 #endif
     // Empty profile was created, update it
     updateProfile();
@@ -314,7 +314,7 @@ void RoamingService::parseSecureResult( SoapMessage *message )
   else if( resultName == "DeleteRelationshipsResponse" )
   {
 #ifdef KMESSDEBUG_ROAMINGSERVICE
-    kDebug() << "Relationship deleted";
+    kmDebug() << "Relationship deleted";
 #endif
 
     return;
@@ -322,7 +322,7 @@ void RoamingService::parseSecureResult( SoapMessage *message )
   else if( resultName == "CreateDocumentResponse" )
   {
 #ifdef KMESSDEBUG_ROAMINGSERVICE
-    kDebug() << "Document created";
+    kmDebug() << "Document created";
 #endif
 
     displayPictureResourceId_ = XmlFunctions::getNodeValue( body, "CreateDocumentResponse/CreateDocumentResult" );
@@ -332,13 +332,13 @@ void RoamingService::parseSecureResult( SoapMessage *message )
   else if( resultName == "CreateRelationshipsResponse" )
   {
 #ifdef KMESSDEBUG_ROAMINGSERVICE
-    kDebug() << "Relationship created";
+    kmDebug() << "Relationship created";
 #endif
     return;
   }
   else
   {
-    kWarning() << "Unknown response type" << resultName << "received from endpoint" << message->getEndPoint();
+    kmWarning() << "Unknown response type" << resultName << "received from endpoint" << message->getEndPoint();
   }
 }
 
@@ -351,9 +351,29 @@ void RoamingService::processProfileResult( const QDomElement &body )
 
   const QDomNode expressionProfile( XmlFunctions::getNode( body, "GetProfileResponse/GetProfileResult/ExpressionProfile" ) );
 
-  QString fullPictureUrl( XmlFunctions::getNodeValue( expressionProfile, "StaticUserTilePublicURL" ) );
-  QString pictureLastModified( XmlFunctions::getNodeValue( expressionProfile, "Photo/DateModified" ) );
-  QString pictureName( XmlFunctions::getNodeValue( expressionProfile, "Photo/Name" ) );
+  // adam (23 Dec 10): if this node is missing, something is fubar with the profile.
+  // solution is to create a new one.
+  if ( expressionProfile.isNull() )
+  {
+    createProfile();
+    return;
+  }
+
+  const QDomNodeList streams( XmlFunctions::getNode( expressionProfile, "Photo" ).toElement().elementsByTagName( "DocumentStream" ) );
+  QString fullPictureUrl;
+  QString remotePictureHash;
+  for( int i = 0; i < streams.count(); i++ )
+  {
+    const QDomNode node( streams.at(i) );
+    QString name( XmlFunctions::getNodeValue( node, "DocumentStreamName" ) );
+    if ( name == "UserTileStatic" )
+    {
+      fullPictureUrl = XmlFunctions::getNodeValue( node, "PreAuthURL" );
+      break;
+    }
+  }
+
+  QString pictureLastModified( XmlFunctions::getNodeValue( expressionProfile, "DateModified" ) );
   // This message also contains DisplayName
 
   profileResourceId_        = XmlFunctions::getNodeValue( expressionProfile, "ResourceID" );
@@ -366,13 +386,13 @@ void RoamingService::processProfileResult( const QDomElement &body )
   lastKnownPersonalMessage_ = QString::fromUtf8( lastKnownPersonalMessage_.toAscii() );
 
 #ifdef KMESSDEBUG_ROAMINGSERVICE
-  kDebug() << "Got profile result:" << profileResourceId_;
+  kmDebug() << "Got profile result:" << profileResourceId_;
 #endif
 
 #ifdef KMESSDEBUG_ROAMINGSERVICE
-  kDebug() << "Received friendly name from Storage:" << lastKnownFriendlyName_;
-  kDebug() << "Received personalMessage from Storage:" << lastKnownPersonalMessage_;
-  kDebug() << "Received displayPicture location from server:" << fullPictureUrl;
+  kmDebug() << "Received friendly name from Storage:" << lastKnownFriendlyName_;
+  kmDebug() << "Received personalMessage from Storage:" << lastKnownPersonalMessage_;
+  kmDebug() << "Received displayPicture location from server:" << fullPictureUrl;
 #endif
 
   // Don't update the details if they're not valid
@@ -389,25 +409,11 @@ void RoamingService::processProfileResult( const QDomElement &body )
   if( fullPictureUrl.isEmpty() || ! currentAccount->getShowPicture() )
   {
 #ifdef KMESSDEBUG_ROAMINGSERVICE
-    kDebug() << "Display picture disabled, not using received picture:" << fullPictureUrl;
+    kmDebug() << "Display picture disabled, not using received picture:" << fullPictureUrl;
 #endif
     return;
   }
 
-  // check if we don't have a picture with the same name (the msn server converts the image to jpeg and compresses it when storing,
-  // so the hash changes and kmess can't see that the image is actually the same as one he uploaded earlier)
-  const QString pictureDir( KMessConfig::instance()->getAccountDirectory( currentAccount->getHandle() ) + "/displaypics/" );
-  const QString localPicture( pictureDir + pictureName + ".png" ); // accountpage always saves the images in png format
-  if( QFile::exists( localPicture ) )
-  {
-#ifdef KMESSDEBUG_ROAMINGSERVICE
-    kDebug() << "Have a local picture with the same name (" << localPicture << "), not downloading display picture";
-#endif
-    lastKnownDisplayPicturePath_ = localPicture;
-    currentAccount->setPicturePath( localPicture );
-    return;
-  }
-
   // Check if the picture on the server is newer
   const QString displayPicturePath( currentAccount->getPicturePath( false /* don't fallback to the kmess default pic */ ) );
   QFileInfo info( displayPicturePath );
@@ -418,7 +424,7 @@ void RoamingService::processProfileResult( const QDomElement &body )
   ||  info.lastModified() < KDateTime::fromString( pictureLastModified, KDateTime::ISODate ).toClockTime().dateTime() )
   {
 #ifdef KMESSDEBUG_ROAMINGSERVICE
-    kDebug() << "Downloading display picture from storage";
+    kmDebug() << "Downloading display picture from storage";
 #endif
     // Download the picture from the server into a temporary file
     QNetworkAccessManager *manager = new QNetworkAccessManager( this );
@@ -431,13 +437,13 @@ void RoamingService::processProfileResult( const QDomElement &body )
   else
   {
 #ifdef KMESSDEBUG_ROAMINGSERVICE
-	kDebug() << "DP path:" << displayPicturePath << " Last modification date:" << info.lastModified()
+	kmDebug() << "DP path:" << displayPicturePath << " Last modification date:" << info.lastModified()
 		<< "vs. server dp's date:" << KDateTime::fromString( pictureLastModified, KDateTime::ISODate ).toClockTime().dateTime();
 #endif
   }
 
 #ifdef KMESSDEBUG_ROAMINGSERVICE
-    kDebug() << "Done.";
+    kmDebug() << "Done.";
 #endif
 }
 
@@ -449,13 +455,13 @@ void RoamingService::receivedDisplayPicture( QNetworkReply *reply )
   CurrentAccount *currentAccount = CurrentAccount::instance();
 
 #ifdef KMESSDEBUG_ROAMINGSERVICE
-  kDebug() << "Saving received display picture of size" << reply->size();
+  kmDebug() << "Saving received display picture of size" << reply->size();
 #endif
 
   if( reply->size() == 0 )
   {
 #ifdef KMESSDEBUG_ROAMINGSERVICE
-    kDebug() << "Received empty content, ignoring response.";
+    kmDebug() << "Received empty content, ignoring response.";
 #endif
     return;
   }
@@ -463,8 +469,8 @@ void RoamingService::receivedDisplayPicture( QNetworkReply *reply )
   if( ! reply->header( QNetworkRequest::LocationHeader ).toString().isEmpty() )
   {
 #ifdef KMESSDEBUG_ROAMINGSERVICE
-    kDebug() << "Received Location: header, ignoring response.";
-    kDebug() << "Location:" << reply->header( QNetworkRequest::LocationHeader ).toString();
+    kmDebug() << "Received Location: header, ignoring response.";
+    kmDebug() << "Location:" << reply->header( QNetworkRequest::LocationHeader ).toString();
 #endif
     return;
   }
@@ -526,12 +532,12 @@ void RoamingService::receivedDisplayPicture( QNetworkReply *reply )
   if( ! pictureFolder.exists( pictureName )
   &&  ! pictureFolder.rename( tempPicturePath, pictureName ) )
   {
-    kWarning() << "The display picture file could not be renamed from" << tempPicturePath << "to" << pictureName << ".";
+    kmWarning() << "The display picture file could not be renamed from" << tempPicturePath << "to" << pictureName << ".";
   }
 #ifdef KMESSDEBUG_ROAMINGSERVICE
   else
   {
-    kDebug() << "Saved display picture as" << ( pictureDir + pictureName );
+    kmDebug() << "Saved display picture as" << ( pictureDir + pictureName );
   }
 #endif
 
