@@ -337,7 +337,7 @@ void AccountPage::saveSettings( Account *account )
         }
         else
         {
-          kWarning() << "The display picture file could not be renamed from" << tempPictureFile_ << "to" << pictureName << ".";
+          kmWarning() << "The display picture file could not be renamed from" << tempPictureFile_ << "to" << pictureName << ".";
         }
       }
     }
@@ -539,7 +539,7 @@ void AccountPage::selectPicture( bool resize, QString picturePath )
 
   if( ! dir.mkpath( file.absolutePath() ) )
   {
-    kWarning() << "Making the account folder failed! Path was" << file.absolutePath();
+    kmWarning() << "Making the account folder failed! Path was" << file.absolutePath();
   }
 
   if( pictureData.save( tempPictureFile_, "PNG" ) )
@@ -595,7 +595,7 @@ void AccountPage::switchToTab( int tabIndex )
 {
   if( ( tabIndex < 0 ) || tabIndex > tabWidget_->count() )
   {
-    kWarning() << "Invalid tab index" << tabIndex << "selected!";
+    kmWarning() << "Invalid tab index" << tabIndex << "selected!";
     return;
   }
 
